@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 2002 - The Freeciv Project
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,17 +17,26 @@
 
 /* common */
 #include "game.h"
+#include "government.h"
 #include "map.h"
+#include "multipliers.h"
+#include "research.h"
+
+/* server */
+#include "cityturn.h"
+#include "plrhand.h"
 
 /* server/advisors */
 #include "advdata.h"
 
-/* ai */
-#include "advdiplomacy.h"
+/* ai/default */
+#include "aicity.h"
 #include "aiferry.h"
 #include "aiplayer.h"
 #include "aisettler.h"
 #include "aiunit.h"
+#include "daidiplomacy.h"
+#include "daieffects.h"
 
 #include "aidata.h"
 
@@ -53,8 +62,6 @@ void dai_data_init(struct ai_type *ait, struct player *pplayer)
   ai->last_num_continents = -1;
   ai->last_num_oceans = -1;
 
-  ai->channels = NULL;
-
   ai->diplomacy.player_intel_slots
     = fc_calloc(player_slot_count(),
                 sizeof(*ai->diplomacy.player_intel_slots));
@@ -133,7 +140,7 @@ void dai_data_phase_begin(struct ai_type *ait, struct player *pplayer,
                           bool is_new_phase)
 {
   struct ai_plr *ai = def_ai_player_data(pplayer, ait);
-  bool close;
+  bool caller_closes;
 
   /* Note that this refreshes advisor data if needed. ai_plr_data_get()
      is expected to refresh advisor data if needed, and ai_plr_data_get()
@@ -141,7 +148,6 @@ void dai_data_phase_begin(struct ai_type *ait, struct player *pplayer,
      ai_plr_data_get()->ai_data_phase_begin()->adv_data_get() to do it.
      If you change this, you may need to adjust ai_plr_data_get() also. */
   struct adv_data *adv;
-  int i;
 
   if (ai->phase_initialized) {
     return;
@@ -149,7 +155,7 @@ void dai_data_phase_begin(struct ai_type *ait, struct player *pplayer,
 
   ai->phase_initialized = TRUE;
 
-  adv = adv_data_get(pplayer, &close);
+  adv = adv_data_get(pplayer, &caller_closes);
 
   /* Store current number of known continents and oceans so we can compare
      against it later in order to see if ai data needs refreshing. */
@@ -192,64 +198,28 @@ void dai_data_phase_begin(struct ai_type *ait, struct player *pplayer,
     } players_iterate_end;
   } players_iterate_end;
 
-  /*** Channels ***/
-
-  /* Ways to cross from one ocean to another through a city. */
-  ai->channels = fc_calloc((adv->num_oceans + 1) * (adv->num_oceans + 1), sizeof(int));
-  players_iterate(aplayer) {
-    if (pplayers_allied(pplayer, aplayer)) {
-      city_list_iterate(aplayer->cities, pcity) {
-        adjc_iterate(pcity->tile, tile1) {
-          if (is_ocean_tile(tile1)) {
-            adjc_iterate(pcity->tile, tile2) {
-              if (is_ocean_tile(tile2) 
-                  && tile_continent(tile1) != tile_continent(tile2)) {
-                ai->channels[(-tile_continent(tile1)) * adv->num_oceans
-                             + (-tile_continent(tile2))] = TRUE;
-                ai->channels[(-tile_continent(tile2)) * adv->num_oceans
-                             + (-tile_continent(tile1))] = TRUE;
-              }
-            } adjc_iterate_end;
-          }
-        } adjc_iterate_end;
-      } city_list_iterate_end;
-    }
-  } players_iterate_end;
-
-  /* If we can go i -> j and j -> k, we can also go i -> k. */
-  for(i = 1; i <= adv->num_oceans; i++) {
-    int j;
-
-    for(j = 1; j <= adv->num_oceans; j++) {
-      if (ai->channels[i * adv->num_oceans + j]) {
-        int k;
-
-        for(k = 1; k <= adv->num_oceans; k++) {
-          ai->channels[i * adv->num_oceans + k] |= 
-            ai->channels[j * adv->num_oceans + k];
-        }
-      }
-    }
-  }
-
-  if (game.server.debug[DEBUG_FERRIES]) {
-    for(i = 1; i <= adv->num_oceans; i++) {
-      int j;
-
-      for(j = 1; j <= adv->num_oceans; j++) {
-        if (ai->channels[i * adv->num_oceans + j]) {
-          log_test("%s: oceans %d and %d are connected",
-                   player_name(pplayer), i, j);
-       }
-      }
-    }
-  }
-
   /*** Statistics ***/
 
+  ai->stats.workers = fc_calloc(adv->num_continents + 1, sizeof(int));
+  unit_list_iterate(pplayer->units, punit) {
+    struct tile *ptile = unit_tile(punit);
+
+    if (!is_ocean_tile(ptile) && unit_has_type_flag(punit, UTYF_SETTLERS)) {
+      ai->stats.workers[(int)tile_continent(unit_tile(punit))]++;
+    }
+  } unit_list_iterate_end;
+
   BV_CLR_ALL(ai->stats.diplomat_reservations);
   unit_list_iterate(pplayer->units, punit) {
-    if (unit_has_type_flag(punit, UTYF_DIPLOMAT)
+    if ((unit_can_do_action(punit, ACTION_SPY_POISON)
+         || unit_can_do_action(punit, ACTION_SPY_SABOTAGE_CITY)
+         || unit_can_do_action(punit, ACTION_SPY_TARGETED_SABOTAGE_CITY)
+         || unit_can_do_action(punit, ACTION_SPY_INCITE_CITY)
+         || unit_can_do_action(punit, ACTION_ESTABLISH_EMBASSY)
+         || unit_can_do_action(punit, ACTION_SPY_STEAL_TECH)
+         || unit_can_do_action(punit, ACTION_SPY_TARGETED_STEAL_TECH)
+         || unit_can_do_action(punit, ACTION_SPY_INVESTIGATE_CITY)
+         || unit_can_do_action(punit, ACTION_SPY_STEAL_GOLD))
         && def_ai_unit_data(punit, ait)->task == AIUNIT_ATTACK) {
 
       fc_assert_msg(punit->goto_tile != NULL, "No target city for spy action");
@@ -292,7 +262,7 @@ void dai_data_phase_begin(struct ai_type *ait, struct player *pplayer,
     } unit_list_iterate_end;
   } players_iterate_alive_end;
 
-  if (close) {
+  if (caller_closes) {
     adv_data_phase_done(pplayer);
   }
 }
@@ -308,8 +278,8 @@ void dai_data_phase_finished(struct ai_type *ait, struct player *pplayer)
     return;
   }
 
-  free(ai->channels);
-  ai->channels = NULL;
+  free(ai->stats.workers);
+  ai->stats.workers = NULL;
 
   ai->phase_initialized = FALSE;
 }
@@ -321,7 +291,7 @@ void dai_data_phase_finished(struct ai_type *ait, struct player *pplayer)
   closing.
 ****************************************************************************/
 struct ai_plr *dai_plr_data_get(struct ai_type *ait, struct player *pplayer,
-                                bool *close)
+                                bool *caller_closes)
 {
   struct ai_plr *ai = def_ai_player_data(pplayer, ait);
 
@@ -329,16 +299,16 @@ struct ai_plr *dai_plr_data_get(struct ai_type *ait, struct player *pplayer,
 
   /* This assert really is required. See longer comment
      in adv_data_get() for equivalent code. */
-#if defined(DEBUG) || defined(IS_DEVEL_VERSION)
-  fc_assert(close != NULL || ai->phase_initialized);
+#if defined(FREECIV_DEBUG) || defined(IS_DEVEL_VERSION)
+  fc_assert(caller_closes != NULL || ai->phase_initialized);
 #endif
 
-  if (close != NULL) {
-    *close = FALSE;
+  if (caller_closes != NULL) {
+    *caller_closes = FALSE;
   }
 
-  if (ai->last_num_continents != map.num_continents
-      || ai->last_num_oceans != map.num_oceans) {
+  if (ai->last_num_continents != game.map.num_continents
+      || ai->last_num_oceans != game.map.num_oceans) {
     /* We have discovered more continents, recalculate! */
 
     /* See adv_data_get() */
@@ -350,39 +320,22 @@ struct ai_plr *dai_plr_data_get(struct ai_type *ait, struct player *pplayer,
       log_debug("%s ai data phase closed when dai_plr_data_get() called",
                 player_name(pplayer));
       dai_data_phase_begin(ait, pplayer, FALSE);
-      if (close != NULL) {
-        *close = TRUE;
+      if (caller_closes != NULL) {
+        *caller_closes = TRUE;
       } else {
         dai_data_phase_finished(ait, pplayer);
       }
     }
   } else {
-    if (!ai->phase_initialized && close != NULL) {
+    if (!ai->phase_initialized && caller_closes != NULL) {
       dai_data_phase_begin(ait, pplayer, FALSE);
-      *close = TRUE;
+      *caller_closes = TRUE;
     }
   }
 
   return ai;
 }
 
-/**************************************************************************
-  Is there a channel going from ocean c1 to ocean c2?
-  Returns FALSE if either is not an ocean.
-**************************************************************************/
-bool dai_channel(struct ai_type *ait, struct player *pplayer,
-                 Continent_id c1, Continent_id c2)
-{
-  struct ai_plr *ai = dai_plr_data_get(ait, pplayer, NULL);
-  struct adv_data *adv = adv_data_get(pplayer, NULL);
-
-  if (c1 >= 0 || c2 >= 0) {
-    return FALSE;
-  }
-
-  return (c1 == c2 || ai->channels[(-c1) * adv->num_oceans + (-c2)]);
-}
-
 /****************************************************************************
   Allocate new ai diplomacy slot
 ****************************************************************************/
@@ -467,3 +420,179 @@ static void dai_diplomacy_destroy(struct ai_type *ait,
 
   *player_intel_slot = NULL;
 }
+
+/****************************************************************************
+  Adjust multiplier values.
+****************************************************************************/
+void dai_adjust_policies(struct ai_type *ait, struct player *pplayer)
+{
+  bool needs_back_rearrange = FALSE; 
+  struct adv_data *adv;
+
+  adv = adv_data_get(pplayer, NULL);
+
+  multipliers_iterate(ppol) {
+    int orig_value = 0;
+    int mp_val = player_multiplier_value(pplayer, ppol);
+    int pidx = multiplier_index(ppol);
+    bool better_found = FALSE;
+
+    city_list_iterate(pplayer->cities, pcity) {
+      orig_value += dai_city_want(pplayer, pcity, adv, NULL);
+    } city_list_iterate_end;
+
+    /* Consider reducing policy value */
+    if (mp_val > ppol->start) {
+      int new_value = 0;
+
+      pplayer->multipliers[pidx] = MAX(mp_val - ppol->step, ppol->start);
+
+      city_list_iterate(pplayer->cities, acity) {
+        auto_arrange_workers(acity);
+      } city_list_iterate_end;
+
+      city_list_iterate(pplayer->cities, pcity) {
+        new_value += dai_city_want(pplayer, pcity, adv, NULL);
+      } city_list_iterate_end;
+
+      if (new_value > orig_value) {
+        /* This is step to right direction, leave it in effect. */
+        pplayer->multipliers_target[pidx] = pplayer->multipliers[pidx];
+
+        needs_back_rearrange = FALSE;
+        better_found = TRUE;
+      }
+    }
+
+    /* Consider increasing policy value */
+    if (!better_found && mp_val < ppol->stop) {
+      int new_value = 0;
+
+      pplayer->multipliers[pidx] = MIN(mp_val + ppol->step, ppol->stop);
+
+      city_list_iterate(pplayer->cities, acity) {
+        auto_arrange_workers(acity);
+      } city_list_iterate_end;
+
+      city_list_iterate(pplayer->cities, pcity) {
+        new_value += dai_city_want(pplayer, pcity, adv, NULL);
+      } city_list_iterate_end;
+
+      if (new_value > orig_value) {
+        /* This is step to right direction, leave it in effect. */
+        pplayer->multipliers_target[pidx] = pplayer->multipliers[pidx];
+
+        needs_back_rearrange = FALSE;
+        better_found = TRUE;
+      }
+    }
+
+    if (!better_found) {
+      /* Restore original multiplier value */
+      pplayer->multipliers[pidx] = mp_val;
+      needs_back_rearrange = TRUE;
+    }
+  } multipliers_iterate_end;
+
+  if (needs_back_rearrange) {
+    city_list_iterate(pplayer->cities, acity) {
+      auto_arrange_workers(acity);
+    } city_list_iterate_end;
+  }
+}
+
+/****************************************************************************
+  Set value of the government.
+****************************************************************************/
+void dai_gov_value(struct ai_type *ait, struct player *pplayer,
+                   struct government *gov, adv_want *val, bool *override)
+{
+  int dist;
+  int bonus = 0; /* in percentage */
+  int revolution_turns;
+  struct universal source = { .kind = VUT_GOVERNMENT, .value.govern = gov };
+  struct adv_data *adv;
+  int turns = 9999; /* TODO: Set to correct value */
+  int nplayers;
+  const struct research *presearch;
+
+  /* Use default handling of no-cities case */
+  if (city_list_size(pplayer->cities) == 0) {
+    *override = FALSE;
+    return;
+  }
+
+  adv = adv_data_get(pplayer, NULL);
+  nplayers = normal_player_count();
+  presearch = research_get(pplayer);
+
+  pplayer->government = gov;
+  /* Ideally we should change tax rates here, but since
+   * this is a rather big CPU operation, we'd rather not. */
+  check_player_max_rates(pplayer);
+  city_list_iterate(pplayer->cities, acity) {
+    auto_arrange_workers(acity);
+  } city_list_iterate_end;
+  city_list_iterate(pplayer->cities, pcity) {
+    bool capital;
+
+    *val += dai_city_want(pplayer, pcity, adv, NULL);
+    capital = is_capital(pcity);
+
+    effect_list_iterate(get_req_source_effects(&source), peffect) {
+      bool present = TRUE;
+      bool active = TRUE;
+
+      requirement_vector_iterate(&peffect->reqs, preq) {
+        /* Check if all the requirements for the currently evaluated effect
+         * are met, except for having the tech that we are evaluating.
+         * TODO: Consider requirements that could be met later. */
+        if (VUT_GOVERNMENT == preq->source.kind
+            && preq->source.value.govern == gov) {
+          present = preq->present;
+          continue;
+        }
+        if (!is_req_active(pplayer, NULL, pcity, NULL, NULL, NULL, NULL,
+                           NULL, NULL, preq, RPT_POSSIBLE)) {
+          active = FALSE;
+          break; /* presence doesn't matter for inactive effects. */
+        }
+
+      } requirement_vector_iterate_end;
+
+      if (active) {
+        adv_want v1;
+
+        v1 = dai_effect_value(pplayer, gov, adv, pcity, capital,
+                              turns, peffect, 1,
+                              nplayers);
+
+        if (!present) {
+          /* Tech removes the effect */
+          *val -= v1;
+        } else {
+          *val += v1;
+        }
+      }
+    } effect_list_iterate_end;
+  } city_list_iterate_end;
+
+  revolution_turns = get_player_bonus(pplayer, EFT_REVOLUTION_UNHAPPINESS);
+  if (revolution_turns > 0) {
+    bonus -= 6 / revolution_turns;
+  }
+
+  *val += (*val * bonus) / 100;
+
+  /* FIXME: handle reqs other than technologies. */
+  dist = 0;
+  requirement_vector_iterate(&gov->reqs, preq) {
+    if (VUT_ADVANCE == preq->source.kind) {
+      dist += MAX(1, research_goal_unknown_techs(presearch,
+                                                 advance_number(preq->source.value.advance)));
+    }
+  } requirement_vector_iterate_end;
+  *val = amortize(*val, dist);
+
+  *override = TRUE;
+}
