@@ -1011,7 +1011,7 @@ void dai_auto_settler_init(struct ai_plr *ai)
 void dai_auto_settler_run(struct ai_type *ait, struct player *pplayer,
                           struct unit *punit, struct settlermap *state)
 {
-  int best_impr = 0;            /* best terrain improvement we can do */
+  adv_want best_impr = 0; /* value of best terrain improvement we can do */
   enum unit_activity best_act;
   struct extra_type *best_target;
   struct tile *best_tile = NULL;
@@ -1096,7 +1096,7 @@ BUILD_CITY:
         completion_time = pf_path_last_position(path)->turn;
       }
     }
-    UNIT_LOG(LOG_DEBUG, punit, "impr want %d", best_impr);
+    UNIT_LOG(LOG_DEBUG, punit, "impr want " ADV_WANT_PRINTF, best_impr);
     TIMING_LOG(AIT_WORKERS, TIMER_STOP);
   }
 
