@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 2001 - R. Falke
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -92,7 +92,7 @@ static struct {
  Returns TRUE iff the two results are equal. Both results have to be
  results for the given city.
 *****************************************************************************/
-static bool my_results_are_equal(const struct cm_result *result1,
+static bool fc_results_are_equal(const struct cm_result *result1,
                                  const struct cm_result *result2)
 {
 #define T(x) if (result1->x != result2->x) { \
@@ -106,8 +106,8 @@ static bool my_results_are_equal(const struct cm_result *result1,
     T(specialists[sp]);
   } specialist_type_iterate_end;
 
-  output_type_iterate(stat) {
-    T(surplus[stat]);
+  output_type_iterate(ot) {
+    T(surplus[ot]);
   } output_type_iterate_end;
 
   fc_assert_ret_val(result1->city_radius_sq == result2->city_radius_sq,
@@ -172,7 +172,7 @@ static bool apply_result_on_server(struct city *pcity,
   fc_assert_ret_val(result->found_a_valid, FALSE);
   cm_result_from_main_map(current_state, pcity);
 
-  if (my_results_are_equal(current_state, result)
+  if (fc_results_are_equal(current_state, result)
       && !ALWAYS_APPLY_AT_SERVER) {
     stats.apply_result_ignored++;
     return TRUE;
@@ -181,7 +181,7 @@ static bool apply_result_on_server(struct city *pcity,
   /* Do checks */
   if (city_size_get(pcity) != cm_result_citizens(result)) {
     log_error("apply_result_on_server(city %d=\"%s\") bad result!",
-              pcity->id, city_name(pcity));
+              pcity->id, city_name_get(pcity));
     cm_print_city(pcity);
     cm_print_result(result);
     return FALSE;
@@ -190,15 +190,15 @@ static bool apply_result_on_server(struct city *pcity,
   stats.apply_result_applied++;
 
   log_apply_result("apply_result_on_server(city %d=\"%s\")",
-                   pcity->id, city_name(pcity));
+                   pcity->id, city_name_get(pcity));
 
   connection_do_buffer(&client.conn);
 
   /* Remove all surplus workers */
-  city_tile_iterate_skip_free_worked(city_radius_sq, pcenter, ptile, index,
+  city_tile_iterate_skip_free_worked(city_radius_sq, pcenter, ptile, idx,
                                      x, y) {
     if (tile_worked(ptile) == pcity
-        && !result->worker_positions[index]) {
+        && !result->worker_positions[idx]) {
       log_apply_result("Removing worker at {%d,%d}.", x, y);
 
       last_request_id =
@@ -231,10 +231,10 @@ static bool apply_result_on_server(struct city *pcity,
   /* Set workers */
   /* FIXME: This code assumes that any toggled worker will turn into a
    * DEFAULT_SPECIALIST! */
-  city_tile_iterate_skip_free_worked(city_radius_sq, pcenter, ptile, index,
+  city_tile_iterate_skip_free_worked(city_radius_sq, pcenter, ptile, idx,
                                      x, y) {
     if (NULL == tile_worked(ptile)
-     && result->worker_positions[index]) {
+     && result->worker_positions[idx]) {
       log_apply_result("Putting worker at {%d,%d}.", x, y);
       fc_assert_action(city_can_work_tile(pcity, ptile), break);
 
@@ -267,7 +267,7 @@ static bool apply_result_on_server(struct city *pcity,
   if (last_request_id == 0 || ALWAYS_APPLY_AT_SERVER) {
       /*
        * If last_request is 0 no change request was send. But it also
-       * means that the results are different or the my_results_are_equal()
+       * means that the results are different or the fc_results_are_equal()
        * test at the start of the function would be true. So this
        * means that the client has other results for the same
        * allocation of citizen than the server. We just send a
@@ -293,21 +293,21 @@ static bool apply_result_on_server(struct city *pcity,
   /* Return. */
   cm_result_from_main_map(current_state, pcity);
 
-  success = my_results_are_equal(current_state, result);
+  success = fc_results_are_equal(current_state, result);
   if (!success) {
     cm_clear_cache(pcity);
 
 #if SHOW_APPLY_RESULT_ON_SERVER_ERRORS
       log_error("apply_result_on_server(city %d=\"%s\") no match!",
-                pcity->id, city_name(pcity));
+                pcity->id, city_name_get(pcity));
 
       log_test("apply_result_on_server(city %d=\"%s\") have:",
-               pcity->id, city_name(pcity));
+               pcity->id, city_name_get(pcity));
       cm_print_city(pcity);
       cm_print_result(current_state);
 
       log_test("apply_result_on_server(city %d=\"%s\") want:",
-               pcity->id, city_name(pcity));
+               pcity->id, city_name_get(pcity));
       cm_print_result(result);
 #endif /* SHOW_APPLY_RESULT_ON_SERVER_ERRORS */
   }
@@ -361,11 +361,11 @@ static void handle_city(struct city *pcity)
   int i, city_id = pcity->id;
 
   log_handle_city("handle_city(city %d=\"%s\") pos=(%d,%d) owner=%s",
-                  pcity->id, city_name(pcity), TILE_XY(pcity->tile),
+                  pcity->id, city_name_get(pcity), TILE_XY(pcity->tile),
                   nation_rule_name(nation_of_city(pcity)));
 
   log_handle_city2("START handle city %d=\"%s\"",
-                   pcity->id, city_name(pcity));
+                   pcity->id, city_name_get(pcity));
 
   handled = FALSE;
   for (i = 0; i < 5; i++) {
@@ -378,7 +378,7 @@ static void handle_city(struct city *pcity)
       break;
     }
 
-    cm_query_result(pcity, &parameter, result);
+    cm_query_result(pcity, &parameter, result, FALSE);
     if (!result->found_a_valid) {
       log_handle_city2("  no valid found result");
 
@@ -421,7 +421,7 @@ static void handle_city(struct city *pcity)
     cma_release_city(pcity);
 
     log_error("handle_city() CMA: %s has changed multiple times.",
-              city_name(pcity));
+              city_name_get(pcity));
     /* TRANS: No full stop after the URL, could cause confusion. */
     log_error(_("Please report this message at %s"), BUG_URL);
   }
@@ -506,10 +506,10 @@ bool cma_apply_result(struct city *pcity, const struct cm_result *result)
   Put city under governor control
 *****************************************************************************/
 void cma_put_city_under_agent(struct city *pcity,
-			      const struct cm_parameter *const parameter)
+                              const struct cm_parameter *const parameter)
 {
   log_debug("cma_put_city_under_agent(city %d=\"%s\")",
-            pcity->id, city_name(pcity));
+            pcity->id, city_name_get(pcity));
 
   fc_assert_ret(city_owner(pcity) == client.conn.playing);
 
