@@ -36,7 +36,7 @@
 #include "client_main.h"
 #include "options.h"
 
-/* client/gui-gtk-3.0 */
+/* client/gui-gtk-2.0 */
 #include "gui_main.h"
 #include "gui_stuff.h"
 #include "mapview.h"
@@ -168,7 +168,7 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
 {
   struct intel_dialog *pdialog;
 
-  GtkWidget *shell, *notebook, *label, *sw, *view, *table;
+  GtkWidget *shell, *notebook, *label, *sw, *view, *table, *alignment;
   GtkCellRenderer *rend;
   GtkTreeViewColumn *col;
 
@@ -195,33 +195,37 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
 
   notebook = gtk_notebook_new();
   gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_BOTTOM);
-  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(shell))), notebook);
+  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(shell)->vbox), notebook);
  
   /* overview tab. */
-  table = gtk_grid_new();
-  g_object_set(table, "margin", 6, NULL);
+  table = gtk_table_new(ARRAY_SIZE(table_text), 2, FALSE);
 
-  gtk_grid_set_row_spacing(GTK_GRID(table), 2);
-  gtk_grid_set_column_spacing(GTK_GRID(table), 12);
+  gtk_table_set_row_spacings(GTK_TABLE(table), 2);
+  gtk_table_set_col_spacings(GTK_TABLE(table), 12);
+
+  alignment = gtk_alignment_new(0.0, 0.0, 0.0, 0.0);
+  gtk_container_set_border_width(GTK_CONTAINER(alignment), 6);
+  gtk_container_add(GTK_CONTAINER(alignment), table);
 
   /* TRANS: Overview tab of foreign intelligence report dialog */
   label = gtk_label_new_with_mnemonic(_("_Overview"));
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table, label);
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), alignment, label);
 
   for (i = 0; i < ARRAY_SIZE(table_text); i++) {
     if (table_text[i]) {
       label = gtk_label_new(_(table_text[i]));
-      gtk_widget_set_halign(label, GTK_ALIGN_START);
-      gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-      gtk_grid_attach(GTK_GRID(table), label, 0, i, 1, 1);
+      gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+      gtk_table_attach(GTK_TABLE(table), label,
+	  0, 1, i, i+1, GTK_FILL, GTK_FILL|GTK_EXPAND, 0, 0);
 
       label = gtk_label_new(NULL);
       pdialog->table_labels[i] = label;
-      gtk_widget_set_halign(label, GTK_ALIGN_START);
-      gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-      gtk_grid_attach(GTK_GRID(table), label, 1, i, 1, 1);
+      gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+      gtk_table_attach(GTK_TABLE(table), label,
+	  1, 2, i, i+1, GTK_FILL, GTK_FILL|GTK_EXPAND, 0, 0);
     } else {
       pdialog->table_labels[i] = NULL;
+      gtk_table_set_row_spacing(GTK_TABLE(table), i, 12);
     }
   }
 
@@ -229,9 +233,6 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   pdialog->diplstates = gtk_tree_store_new(1, G_TYPE_STRING);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pdialog->diplstates));
-  g_object_set(view, "margin", 6, NULL);
-  gtk_widget_set_hexpand(view, TRUE);
-  gtk_widget_set_vexpand(view, TRUE);
   g_object_unref(pdialog->diplstates);
   gtk_container_set_border_width(GTK_CONTAINER(view), 6);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), FALSE);
@@ -251,8 +252,12 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 	GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
+  alignment = gtk_alignment_new(0.0, 0.0, 1.0, 1.0);
+  gtk_container_set_border_width(GTK_CONTAINER(alignment), 6);
+  gtk_container_add(GTK_CONTAINER(alignment), sw);
+
   label = gtk_label_new_with_mnemonic(_("_Diplomacy"));
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, label);
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), alignment, label);
 
   /* techs tab. */
   pdialog->techs = gtk_list_store_new(2, G_TYPE_BOOLEAN, G_TYPE_STRING);
@@ -260,9 +265,6 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
       1, GTK_SORT_ASCENDING);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pdialog->techs));
-  g_object_set(view, "margin", 6, NULL);
-  gtk_widget_set_hexpand(view, TRUE);
-  gtk_widget_set_vexpand(view, TRUE);
   g_object_unref(pdialog->techs);
   gtk_container_set_border_width(GTK_CONTAINER(view), 6);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), FALSE);
@@ -285,10 +287,14 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 	GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-  label = gtk_label_new_with_mnemonic(_("_Techs"));
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, label);
+  alignment = gtk_alignment_new(0.0, 0.0, 1.0, 1.0);
+  gtk_container_set_border_width(GTK_CONTAINER(alignment), 6);
+  gtk_container_add(GTK_CONTAINER(alignment), sw);
 
-  gtk_widget_show_all(gtk_dialog_get_content_area(GTK_DIALOG(shell)));
+  label = gtk_label_new_with_mnemonic(_("_Techs"));
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), alignment, label);
+
+  gtk_widget_show_all(GTK_DIALOG(shell)->vbox);
 
   dialog_list_prepend(dialog_list, pdialog);
 
@@ -329,13 +335,13 @@ void update_intel_dialog(struct player *p)
       diplstates[i] = it;
     }
 
-    players_iterate(other) {
+    players_iterate_alive(other) {
       const struct player_diplstate *state;
       GtkTreeIter it;
       GValue v = { 0, };
 
-      if (other == p || !other->is_alive) {
-	continue;
+      if (other == p) {
+        continue;
       }
       state = player_diplstate_get(p, other);
       gtk_tree_store_append(pdialog->diplstates, &it,
@@ -344,7 +350,7 @@ void update_intel_dialog(struct player *p)
       g_value_set_static_string(&v, player_name(other));
       gtk_tree_store_set_value(pdialog->diplstates, &it, 0, &v);
       g_value_unset(&v);
-    } players_iterate_end;
+    } players_iterate_alive_end;
 
     /* techs tab. */
     gtk_list_store_clear(pdialog->techs);
