@@ -40,7 +40,7 @@
 #include "options.h"
 #include "tilespec.h"
 
-/* client/gui-gtk-3.22 */
+/* gui-gtk-2.0 */
 #include "canvas.h"
 #include "citydlg.h"
 #include "graphics.h"
@@ -217,37 +217,31 @@ static GtkWidget *create_worklists_report(void)
   GtkCellRenderer *rend;
 
   shell = gtk_dialog_new_with_buttons(_("Edit worklists"),
-                                      NULL,
-                                      0,
-                                      _("_New"),
-                                      WORKLISTS_NEW,
-                                      _("_Delete"),
-                                      WORKLISTS_DELETE,
-                                      _("_Properties"),
-                                      WORKLISTS_PROPERTIES,
-                                      _("_Close"),
-                                      WORKLISTS_CLOSE,
-                                      NULL);
+				      NULL,
+				      0,
+				      GTK_STOCK_NEW,
+				      WORKLISTS_NEW,
+				      GTK_STOCK_DELETE,
+				      WORKLISTS_DELETE,
+				      GTK_STOCK_PROPERTIES,
+				      WORKLISTS_PROPERTIES,
+				      GTK_STOCK_CLOSE,
+				      WORKLISTS_CLOSE,
+				      NULL);
   setup_dialog(shell, toplevel);
   gtk_window_set_position(GTK_WINDOW(shell), GTK_WIN_POS_MOUSE);
-
+  
   g_signal_connect(shell, "response",
-                   G_CALLBACK(worklists_response), NULL);
+		   G_CALLBACK(worklists_response), NULL);
   g_signal_connect(shell, "destroy",
-                   G_CALLBACK(worklists_destroy_callback), NULL);
+		   G_CALLBACK(worklists_destroy_callback), NULL);
 
-  vbox = gtk_grid_new();
-  gtk_grid_set_row_spacing(GTK_GRID(vbox), 2);
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
-                                 GTK_ORIENTATION_VERTICAL);
-  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(shell))), vbox);
+  vbox = gtk_vbox_new(FALSE, 2);
+  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(shell)->vbox), vbox);
 
   worklists_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
 
   list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(worklists_store));
-  gtk_widget_set_hexpand(list, TRUE);
-  gtk_widget_set_vexpand(list, TRUE);
-
   g_object_unref(worklists_store);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(list), FALSE);
 
@@ -261,21 +255,22 @@ static GtkWidget *create_worklists_report(void)
     rend, "text", 0, NULL);
 
   sw = gtk_scrolled_window_new(NULL, NULL);
-  gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(sw), 200);
   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
 				      GTK_SHADOW_ETCHED_IN);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 				 GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
   gtk_container_add(GTK_CONTAINER(sw), list);
 
+  gtk_widget_set_size_request(sw, -1, 200);
+
   label = g_object_new(GTK_TYPE_LABEL,
 		       "use-underline", TRUE,
 		       "mnemonic-widget", list,
 		       "label", _("_Worklists:"),
 		       "xalign", 0.0, "yalign", 0.5, NULL);
 
-  gtk_container_add(GTK_CONTAINER(vbox), label);
-  gtk_container_add(GTK_CONTAINER(vbox), sw);
+  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), sw, TRUE, TRUE, 0);
   gtk_widget_show_all(vbox);
 
   return shell;
@@ -401,19 +396,19 @@ static void popup_worklist(struct global_worklist *pgwl)
     shell = gtk_dialog_new_with_buttons(global_worklist_name(pgwl),
                                         GTK_WINDOW(worklists_shell),
                                         GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        _("_Close"),
+                                        GTK_STOCK_CLOSE,
                                         GTK_RESPONSE_CLOSE,
                                         NULL);
     gtk_window_set_role(GTK_WINDOW(shell), "worklist");
     gtk_window_set_position(GTK_WINDOW(shell), GTK_WIN_POS_MOUSE);
     g_signal_connect(shell, "response", G_CALLBACK(worklist_response), NULL);
     gtk_window_set_default_size(GTK_WINDOW(shell), 500, 400);
-
+  
     editor = create_worklist();
     reset_global_worklist(editor, pgwl);
     insert_worklist(global_worklist_id(pgwl), editor);
 
-    gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(shell))), editor);
+    gtk_container_add(GTK_CONTAINER(GTK_DIALOG(shell)->vbox), editor);
     gtk_widget_show(editor);
 
     refresh_worklist(editor);
@@ -473,7 +468,7 @@ static void menu_item_callback(GtkMenuItem *item, struct worklist_data *ptr)
   }
   pwl = global_worklist_get(pgwl);
 
-  for (i = 0; i < (size_t) worklist_length(pwl); i++) {
+  for (i = 0; i < worklist_length(pwl); i++) {
     GtkTreeIter it;
     cid id;
 
@@ -600,7 +595,7 @@ static void queue_bubble_up(struct worklist_data *ptr)
   GtkTreeViewColumn *col;
   GtkTreeModel *model;
 
-  if (!gtk_widget_is_sensitive(ptr->dst_view)) {
+  if (!GTK_WIDGET_IS_SENSITIVE(ptr->dst_view)) {
     return;
   }
 
@@ -647,7 +642,7 @@ static void queue_bubble_down(struct worklist_data *ptr)
   GtkTreeViewColumn *col;
   GtkTreeModel *model;
 
-  if (!gtk_widget_is_sensitive(ptr->dst_view)) {
+  if (!GTK_WIDGET_IS_SENSITIVE(ptr->dst_view)) {
     return;
   }
 
@@ -682,7 +677,7 @@ static void queue_insert(struct worklist_data *ptr, bool prepend)
   GtkTreeIter src_it, dst_it;
   gint i, ncols;
 
-  if (!gtk_widget_is_sensitive(ptr->dst_view)) {
+  if (!GTK_WIDGET_IS_SENSITIVE(ptr->dst_view)) {
     return;
   }
 
@@ -744,7 +739,7 @@ static void src_row_callback(GtkTreeView *view, GtkTreePath *path,
 
   ptr = data;
 
-  if (!gtk_widget_is_sensitive(ptr->dst_view)) {
+  if (!GTK_WIDGET_IS_SENSITIVE(ptr->dst_view)) {
     return;
   }
   
@@ -794,14 +789,14 @@ static gboolean src_key_press_callback(GtkWidget *w, GdkEventKey *ev,
     
   ptr = data;
 
-  if (!gtk_widget_is_sensitive(ptr->dst_view)) {
+  if (!GTK_WIDGET_IS_SENSITIVE(ptr->dst_view)) {
     return FALSE;
   }
   
-  if ((ev->state & GDK_SHIFT_MASK) && ev->keyval == GDK_KEY_Insert) {
+  if ((ev->state & GDK_SHIFT_MASK) && ev->keyval == GDK_Insert) {
     queue_prepend(ptr);
     return TRUE;
-  } else if (ev->keyval == GDK_KEY_Insert) {
+  } else if (ev->keyval == GDK_Insert) {
     queue_append(ptr);
     return TRUE;
   } else {
@@ -821,7 +816,7 @@ static gboolean dst_key_press_callback(GtkWidget *w, GdkEventKey *ev,
   ptr = data;
   model = GTK_TREE_MODEL(ptr->dst);
 
-  if (ev->keyval == GDK_KEY_Delete) {
+  if (ev->keyval == GDK_Delete) {
     GtkTreeIter it, it_next;
     bool deleted = FALSE;
 
@@ -846,11 +841,11 @@ static gboolean dst_key_press_callback(GtkWidget *w, GdkEventKey *ev,
     }
     return TRUE;
 
-  } else if ((ev->state & GDK_MOD1_MASK) && ev->keyval == GDK_KEY_Up) {
+  } else if ((ev->state & GDK_MOD1_MASK) && ev->keyval == GDK_Up) {
     queue_bubble_up(ptr);
     return TRUE;
 
-  } else if ((ev->state & GDK_MOD1_MASK) && ev->keyval == GDK_KEY_Down) {
+  } else if ((ev->state & GDK_MOD1_MASK) && ev->keyval == GDK_Down) {
     queue_bubble_down(ptr);
     return TRUE;
 
@@ -948,29 +943,31 @@ static void cell_render_func(GtkTreeViewColumn *col, GtkCellRenderer *rend,
 
   if (GTK_IS_CELL_RENDERER_PIXBUF(rend)) {
     GdkPixbuf *pix;
-    struct sprite *sprite;
 
     if (VUT_UTYPE == target.kind) {
-      sprite = sprite_scale(get_unittype_sprite(tileset, target.value.utype,
-                                                direction8_invalid(), TRUE),
-                            max_unit_width, max_unit_height);
+      struct canvas store;
 
+      pix = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8,
+                           max_unit_width, max_unit_height);
+
+      store.type = CANVAS_PIXBUF;
+      store.v.pixbuf = pix;
+      create_overlay_unit(&store, target.value.utype, direction8_invalid());
+
+      g_object_set(rend, "pixbuf", pix, NULL);
+      g_object_unref(pix);
     } else {
-      sprite = get_building_sprite(tileset, target.value.building);
+      struct sprite *sprite = get_building_sprite(tileset, target.value.building);
 
-    }
-    pix = sprite_get_pixbuf(sprite);
-    g_object_set(rend, "pixbuf", pix, NULL);
-    g_object_unref(G_OBJECT(pix));
-    if (VUT_UTYPE == target.kind) {
-      free_sprite(sprite);
+      pix = sprite_get_pixbuf(sprite);
+      g_object_set(rend, "pixbuf", pix, NULL);
     }
   } else {
     struct city **pcity = data;
     gint column;
     char *row[4];
     char buf[4][64];
-    guint i;
+    int i;
     gboolean useless;
 
     for (i = 0; i < ARRAY_SIZE(row); i++) {
@@ -1002,7 +999,7 @@ static void populate_view(GtkTreeView *view, struct city **ppcity,
   { N_("Type"), N_("Name"), N_("Info"), N_("Cost"), N_("Turns") };
 
   static bool titles_done;
-  guint i;
+  gint i;
   GtkCellRenderer *rend;
   GtkTreeViewColumn *col;
 
@@ -1019,14 +1016,14 @@ static void populate_view(GtkTreeView *view, struct city **ppcity,
                    i, titles[i], rend, cell_render_func, ppcity, NULL);
   col = gtk_tree_view_get_column(view, i);
 
-  if (GUI_GTK_OPTION(show_task_icons)) {
+  if (gui_options.gui_gtk2_show_task_icons) {
     if (max_unit_width == -1 || max_unit_height == -1) {
       update_max_unit_size();
     }
   } else {
     g_object_set(col, "visible", FALSE, NULL);
   }
-  if (GUI_GTK_OPTION(show_task_icons)) {
+  if (gui_options.gui_gtk2_show_task_icons) {
     g_object_set(rend, "height", max_unit_height, NULL);
   }
 
@@ -1049,7 +1046,7 @@ static void populate_view(GtkTreeView *view, struct city **ppcity,
     if (pos == 3) {
       *pcol = col;
     }
-    if (GUI_GTK_OPTION(show_task_icons)){
+    if (gui_options.gui_gtk2_show_task_icons) {
       g_object_set(rend, "height", max_unit_height, NULL);
     }
   }
@@ -1062,7 +1059,7 @@ GtkWidget *create_worklist(void)
 {
   GtkWidget *editor, *table, *sw, *bbox;
   GtkWidget *src_view, *dst_view, *label, *button;
-  GtkWidget *menubar, *item, *menu;
+  GtkWidget *menubar, *item, *menu, *image;
   GtkWidget *table2, *arrow, *check;
   GtkSizeGroup *group;
   GtkListStore *src_store, *dst_store;
@@ -1079,32 +1076,29 @@ GtkWidget *create_worklist(void)
   ptr->dst = dst_store;
   ptr->future = FALSE;
 
+
   /* create shell. */ 
-  editor = gtk_grid_new();
-  gtk_grid_set_row_spacing(GTK_GRID(editor), 6);
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(editor),
-                                 GTK_ORIENTATION_VERTICAL);
+  editor = gtk_vbox_new(FALSE, 6);
   g_signal_connect(editor, "destroy", G_CALLBACK(worklist_destroy), ptr);
   g_object_set_data(G_OBJECT(editor), "data", ptr);
 
   ptr->editor = editor;
 
   /* add source and target lists.  */
-  table = gtk_grid_new();
-  gtk_container_add(GTK_CONTAINER(editor), table);
+  table = gtk_table_new(2, 5, FALSE);
+  gtk_box_pack_start(GTK_BOX(editor), table, TRUE, TRUE, 0);
 
   group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 
   sw = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
-                                      GTK_SHADOW_ETCHED_IN);
+				      GTK_SHADOW_ETCHED_IN);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
-                                 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  gtk_grid_attach(GTK_GRID(table), sw, 3, 1, 2, 1);
+				 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+  gtk_table_attach(GTK_TABLE(table), sw, 3, 5, 1, 2,
+		   GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
   src_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(src_store));
-  gtk_widget_set_hexpand(src_view, TRUE);
-  gtk_widget_set_vexpand(src_view, TRUE);
   g_object_unref(src_store);
   gtk_size_group_add_widget(group, src_view);
   gtk_widget_set_name(src_view, "small_font");
@@ -1117,71 +1111,72 @@ GtkWidget *create_worklist(void)
 		       "mnemonic-widget", src_view,
 		       "label", _("Source _Tasks:"),
 		       "xalign", 0.0, "yalign", 0.5, NULL);
-  gtk_grid_attach(GTK_GRID(table), label, 3, 0, 1, 1);
+  gtk_table_attach(GTK_TABLE(table), label, 3, 4, 0, 1,
+		   GTK_FILL, GTK_FILL, 0, 0);
 
   check = gtk_check_button_new_with_mnemonic(_("Show _Future Targets"));
-  gtk_grid_attach(GTK_GRID(table), check, 4, 0, 1, 1);
+  gtk_table_attach(GTK_TABLE(table), check, 4, 5, 0, 1,
+		   0, GTK_FILL, 0, 0);
   g_signal_connect(check, "toggled", G_CALLBACK(future_callback), ptr);
 
-  table2 = gtk_grid_new();
-  gtk_grid_attach(GTK_GRID(table), table2, 2, 1, 1, 1);
+
+  table2 = gtk_table_new(5, 1, FALSE);
+  gtk_table_attach(GTK_TABLE(table), table2, 2, 3, 1, 2,
+		   GTK_FILL, GTK_FILL, 0, 0);
 
   button = gtk_button_new();
-  gtk_widget_set_margin_top(button, 24);
-  gtk_widget_set_margin_bottom(button, 24);
   ptr->prepend_cmd = button;
   gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
-  gtk_grid_attach(GTK_GRID(table2), button, 0, 0, 1, 1);
+  gtk_table_attach(GTK_TABLE(table2), button, 0, 1, 0, 1,
+      0, GTK_EXPAND|GTK_FILL, 0, 24);
 
-  arrow = gtk_image_new_from_icon_name("pan-start-symbolic", GTK_ICON_SIZE_MENU);
+  arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_NONE);
   gtk_container_add(GTK_CONTAINER(button), arrow);
   g_signal_connect_swapped(button, "clicked",
-                           G_CALLBACK(queue_prepend), ptr);
+			   G_CALLBACK(queue_prepend), ptr);
   gtk_widget_set_sensitive(ptr->prepend_cmd, FALSE);
 
   button = gtk_button_new();
   ptr->up_cmd = button;
   gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
-  gtk_grid_attach(GTK_GRID(table2), button, 0, 1, 1, 1);
+  gtk_table_attach(GTK_TABLE(table2), button, 0, 1, 1, 2, 0, 0, 0, 0);
 
-  arrow = gtk_image_new_from_icon_name("pan-up-symbolic", GTK_ICON_SIZE_MENU);
+  arrow = gtk_arrow_new(GTK_ARROW_UP, GTK_SHADOW_NONE);
   gtk_container_add(GTK_CONTAINER(button), arrow);
   g_signal_connect_swapped(button, "clicked",
-                           G_CALLBACK(queue_bubble_up), ptr);
+			   G_CALLBACK(queue_bubble_up), ptr);
   gtk_widget_set_sensitive(ptr->up_cmd, FALSE);
 
   button = gtk_button_new();
   ptr->down_cmd = button;
   gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
-  gtk_grid_attach(GTK_GRID(table2), button, 0, 2, 1, 1);
+  gtk_table_attach(GTK_TABLE(table2), button, 0, 1, 2, 3, 0, 0, 0, 0);
 
-  arrow = gtk_image_new_from_icon_name("pan-down-symbolic", GTK_ICON_SIZE_MENU);
+  arrow = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_IN);
   gtk_container_add(GTK_CONTAINER(button), arrow);
   g_signal_connect_swapped(button, "clicked",
-                           G_CALLBACK(queue_bubble_down), ptr);
+			   G_CALLBACK(queue_bubble_down), ptr);
   gtk_widget_set_sensitive(ptr->down_cmd, FALSE);
 
   button = gtk_button_new();
-  gtk_widget_set_margin_top(button, 24);
-  gtk_widget_set_margin_bottom(button, 24);
   ptr->append_cmd = button;
   gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
-  gtk_grid_attach(GTK_GRID(table2), button, 0, 3, 1, 1);
+  gtk_table_attach(GTK_TABLE(table2), button, 0, 1, 3, 4,
+      0, GTK_EXPAND|GTK_FILL, 0, 24);
 
-  arrow = gtk_image_new_from_icon_name("pan-start-symbolic", GTK_ICON_SIZE_MENU);
+  arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_NONE);
   gtk_container_add(GTK_CONTAINER(button), arrow);
   g_signal_connect_swapped(button, "clicked",
-                           G_CALLBACK(queue_append), ptr);
+			   G_CALLBACK(queue_append), ptr);
   gtk_widget_set_sensitive(ptr->append_cmd, FALSE);
 
   button = gtk_button_new();
-  gtk_widget_set_margin_top(button, 24);
-  gtk_widget_set_margin_bottom(button, 24);
   ptr->remove_cmd = button;
   gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
-  gtk_grid_attach(GTK_GRID(table2), button, 0, 4, 1, 1);
-
-  arrow = gtk_image_new_from_icon_name("pan-end-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_table_attach(GTK_TABLE(table2), button, 0, 1, 4, 5,
+      0, GTK_EXPAND|GTK_FILL, 0, 24);
+  
+  arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_IN);
   gtk_container_add(GTK_CONTAINER(button), arrow);
   g_signal_connect_swapped(button, "clicked",
                            G_CALLBACK(queue_remove), ptr);
@@ -1192,11 +1187,10 @@ GtkWidget *create_worklist(void)
 				      GTK_SHADOW_ETCHED_IN);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 				 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  gtk_grid_attach(GTK_GRID(table), sw, 0, 1, 2, 1);
+  gtk_table_attach(GTK_TABLE(table), sw, 0, 2, 1, 2,
+		   GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
   dst_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(dst_store));
-  gtk_widget_set_hexpand(dst_view, TRUE);
-  gtk_widget_set_vexpand(dst_view, TRUE);
   g_object_unref(dst_store);
   gtk_size_group_add_widget(group, dst_view);
   gtk_widget_set_name(dst_view, "small_font");
@@ -1209,13 +1203,14 @@ GtkWidget *create_worklist(void)
 		       "mnemonic-widget", dst_view,
 		       "label", _("Target _Worklist:"),
 		       "xalign", 0.0, "yalign", 0.5, NULL);
-  gtk_grid_attach(GTK_GRID(table), label, 0, 0, 1, 1);
+  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
+		   GTK_FILL, GTK_FILL, 0, 0);
 
   /* add bottom menu and buttons. */
-  bbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
+  bbox = gtk_hbutton_box_new();
   gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
   gtk_box_set_spacing(GTK_BOX(bbox), 10);
-  gtk_container_add(GTK_CONTAINER(editor), bbox);
+  gtk_box_pack_start(GTK_BOX(editor), bbox, FALSE, FALSE, 0);
 
   menubar = gtk_aux_menu_bar_new();
   gtk_container_add(GTK_CONTAINER(bbox), menubar);
@@ -1223,7 +1218,9 @@ GtkWidget *create_worklist(void)
 
   menu = gtk_menu_new();
 
-  item = gtk_menu_item_new_with_mnemonic(_("_Add Global Worklist"));
+  image = gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU);
+  item = gtk_image_menu_item_new_with_mnemonic(_("_Add Global Worklist"));
+  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), image);
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), menu);
   gtk_menu_shell_append(GTK_MENU_SHELL(menubar), item);
   g_signal_connect(menu, "show",
@@ -1231,7 +1228,7 @@ GtkWidget *create_worklist(void)
   ptr->add_cmd = item;
   gtk_widget_set_sensitive(ptr->add_cmd, FALSE);
 
-  button = icon_label_button_new("help-browser", _("Help"));
+  button = gtk_button_new_from_stock(GTK_STOCK_HELP);
   gtk_container_add(GTK_CONTAINER(bbox), button);
   g_signal_connect(button, "clicked",
 		   G_CALLBACK(help_callback), ptr);
