@@ -32,7 +32,7 @@
 /* client */
 #include "options.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "colors.h"
 #include "gui_main.h"
 
@@ -43,8 +43,6 @@ static GList *dialog_list;
 
 static GtkSizeGroup *gui_action;
 
-static GtkCssProvider *dlg_tab_provider = NULL;
-
 
 /**************************************************************************
   Draw widget now
@@ -71,20 +69,16 @@ void set_relative_window_position(GtkWindow *ref, GtkWindow *w, int px, int py)
 }
 
 /**************************************************************************
-  Create new icon button with label
+  Create new stock button
 **************************************************************************/
-GtkWidget *icon_label_button_new(const gchar *icon_name,
-                                 const gchar *label_text)
+GtkWidget *gtk_stockbutton_new(const gchar *stock, const gchar *label_text)
 {
   GtkWidget *button;
   GtkWidget *image;
-
+  
   button = gtk_button_new_with_mnemonic(label_text);
-
-  if (icon_name != NULL) {
-    image = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_BUTTON);
-    gtk_button_set_image(GTK_BUTTON(button), image);
-  }
+  image = gtk_image_new_from_stock(stock, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image(GTK_BUTTON(button), image);
 
   return button;
 }
@@ -284,7 +278,7 @@ static void close_callback(GtkDialog *dialog, gpointer data)
 ***********************************************************************/
 void setup_dialog(GtkWidget *shell, GtkWidget *parent)
 {
-  if (GUI_GTK_OPTION(dialogs_on_top) || GUI_GTK_OPTION(fullscreen)) {
+  if (gui_options.gui_gtk3_dialogs_on_top || gui_options.gui_gtk3_fullscreen) {
     gtk_window_set_transient_for(GTK_WINDOW(shell),
                                  GTK_WINDOW(parent));
     gtk_window_set_type_hint(GTK_WINDOW(shell),
@@ -431,8 +425,7 @@ static void gui_dialog_switch_page_handler(GtkNotebook *notebook,
   n = gtk_notebook_page_num(GTK_NOTEBOOK(dlg->v.tab.notebook), dlg->vbox);
 
   if (n == num) {
-    gtk_style_context_remove_class(gtk_widget_get_style_context(dlg->v.tab.label),
-                                   "alert");
+    gtk_widget_override_color(dlg->v.tab.label, GTK_STATE_FLAG_NORMAL, NULL);
   }
 }
 
@@ -523,7 +516,7 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
   dlg->default_width = 200;
   dlg->default_height = 300;
 
-  if (GUI_GTK_OPTION(enable_tabs)) {
+  if (gui_options.gui_gtk3_enable_tabs) {
     dlg->type = GUI_DIALOG_TAB;
   } else {
     dlg->type = GUI_DIALOG_WINDOW;
@@ -538,9 +531,9 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
   action_area = gtk_grid_new();
   gtk_grid_set_row_spacing(GTK_GRID(action_area), 4);
   gtk_grid_set_column_spacing(GTK_GRID(action_area), 4);
-  if (GUI_GTK_OPTION(enable_tabs)
-      && (check_top && notebook != GTK_NOTEBOOK(top_notebook))
-      && !GUI_GTK_OPTION(small_display_layout)) {
+  if (gui_options.gui_gtk3_enable_tabs &&
+      (check_top && notebook != GTK_NOTEBOOK(top_notebook))
+      && !gui_options.gui_gtk3_small_display_layout) {
     /* We expect this to be short (as opposed to tall); maximise usable
      * height by putting buttons down the right hand side */
     gtk_orientable_set_orientation(GTK_ORIENTABLE(action_area),
@@ -586,8 +579,8 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
       label = gtk_label_new(NULL);
       gtk_widget_set_halign(label, GTK_ALIGN_START);
       gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-      gtk_widget_set_margin_start(label, 4);
-      gtk_widget_set_margin_end(label, 4);
+      gtk_widget_set_margin_left(label, 4);
+      gtk_widget_set_margin_right(label, 4);
       gtk_widget_set_margin_top(label, 0);
       gtk_widget_set_margin_bottom(label, 0);
       gtk_container_add(GTK_CONTAINER(hbox), label);
@@ -601,9 +594,9 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
       gtk_widget_set_tooltip_text(button, buf);
       g_free(buf);
 
-      image = gtk_image_new_from_icon_name("window-close", GTK_ICON_SIZE_MENU);
-      gtk_widget_set_margin_start(image, 0);
-      gtk_widget_set_margin_end(image, 0);
+      image = gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+      gtk_widget_set_margin_left(image, 0);
+      gtk_widget_set_margin_right(image, 0);
       gtk_widget_set_margin_top(image, 0);
       gtk_widget_set_margin_bottom(image, 0);
       gtk_button_set_image(GTK_BUTTON(button), image);
@@ -622,9 +615,6 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
                          G_CALLBACK(gui_dialog_switch_page_handler), dlg);
       dlg->v.tab.child = vbox;
 
-      gtk_style_context_add_provider(gtk_widget_get_style_context(label),
-                                     GTK_STYLE_PROVIDER(dlg_tab_provider),
-                                     GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
       dlg->v.tab.label = label;
       dlg->v.tab.notebook = GTK_WIDGET(notebook);
 
@@ -669,7 +659,7 @@ static void action_widget_activated(GtkWidget *button, GtkWidget *vbox)
   Places a button into a dialog, taking care of setting up signals, etc.
 **************************************************************************/
 static void gui_dialog_pack_button(struct gui_dialog *dlg, GtkWidget *button,
-                                   int response)
+				   int response)
 {
   gint signal_id;
 
@@ -692,15 +682,30 @@ static void gui_dialog_pack_button(struct gui_dialog *dlg, GtkWidget *button,
 }
 
 /**************************************************************************
-  Adds a button to a dialog.
+  Adds a button to a dialog, allowing the choice of a special stock item.
 **************************************************************************/
-GtkWidget *gui_dialog_add_button(struct gui_dialog *dlg,
-                                 const char *icon_name,
-                                 const char *text, int response)
+GtkWidget *gui_dialog_add_stockbutton(struct gui_dialog *dlg,
+				      const char *stock,
+				      const char *text, int response)
 {
   GtkWidget *button;
 
-  button = icon_label_button_new(icon_name, text);
+  button = gtk_stockbutton_new(stock, text);
+  gtk_widget_set_can_default(button, TRUE);
+  gui_dialog_pack_button(dlg, button, response);
+
+  return button;
+}
+
+/**************************************************************************
+  Adds a button to a dialog.
+**************************************************************************/
+GtkWidget *gui_dialog_add_button(struct gui_dialog *dlg,
+				 const char *text, int response)
+{
+  GtkWidget *button;
+
+  button = gtk_button_new_from_stock(text);
   gtk_widget_set_can_default(button, TRUE);
   gui_dialog_pack_button(dlg, button, response);
 
@@ -841,9 +846,9 @@ void gui_dialog_present(struct gui_dialog *dlg)
 
       if (current != n) {
 	GtkWidget *label = dlg->v.tab.label;
+	GdkRGBA color = {.red = 1.0, .green = 0, .blue = 0, .alpha = 1.0};
 
-        gtk_style_context_add_class(gtk_widget_get_style_context(label),
-                                    "alert");
+	gtk_widget_override_color(label, GTK_STATE_FLAG_NORMAL, &color);
       }
     }
     break;
@@ -893,9 +898,9 @@ void gui_dialog_alert(struct gui_dialog *dlg)
 
       if (current != n) {
         GtkWidget *label = dlg->v.tab.label;
+        GdkRGBA color = {.red = 0, .green = 0, .blue =1.0, .alpha = 1.0};
 
-        gtk_style_context_add_class(gtk_widget_get_style_context(label),
-                                    "alert");
+        gtk_widget_override_color(label, GTK_STATE_FLAG_NORMAL, &color);
       }
     }
     break;
@@ -1129,20 +1134,5 @@ GtkTreeViewColumn *add_treeview_column(GtkWidget *view, const char *title,
   col = gtk_tree_view_column_new_with_attributes(title, rend, attr,
                                                  model_index, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(view), col);
-
   return col;
 }
-
-/**************************************************************************
-  Prepare dialog tab style provider.
-**************************************************************************/
-void dlg_tab_provider_prepare(void)
-{
-  dlg_tab_provider = gtk_css_provider_new();
-
-  gtk_css_provider_load_from_data(dlg_tab_provider,
-                                  ".alert {\n"
-                                  "color: rgba(255, 0, 0, 255);\n"
-                                  "}\n",
-                                  -1, NULL);
-}
