@@ -1,4 +1,4 @@
-/***********************************************************************
+/********************************************************************** 
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@
 #include "options.h"
 #include "text.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "chatline.h"
 #include "dialogs.h"
 #include "gui_main.h"
@@ -122,9 +122,11 @@ GdkPixbuf *create_player_icon(const struct player *plr)
     return NULL;
   }
 
-  gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &width, &height);
+  gtk_icon_size_lookup_for_settings(
+      gtk_settings_get_for_screen(gtk_widget_get_screen(top_notebook)), 
+      GTK_ICON_SIZE_MENU, &width, &height);
   surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, width, height);
-
+  
   cr = cairo_create(surface);
 
   color = get_color(tileset, COLOR_PLAYER_COLOR_BACKGROUND);
@@ -425,8 +427,8 @@ void create_players_dialog(void)
   /* TRANS: Nations report title */
   gui_dialog_set_title(players_dialog_shell, _("Nations"));
 
-  gui_dialog_add_button(players_dialog_shell, "window-close", _("_Close"),
-                        GTK_RESPONSE_CLOSE);
+  gui_dialog_add_button(players_dialog_shell,
+      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
   gui_dialog_set_default_size(players_dialog_shell, -1, 270);
 
