@@ -42,8 +42,9 @@
 #include "gui_stuff.h"
 #include "mapview.h"
 #include "packhand.h"
+#include "text.h"
 
-/* client/gui-gtk-3.0 */
+/* client/gui-gtk-3.22 */
 #include "citydlg.h"
 #include "dialogs.h"
 #include "unitselunitdlg.h"
@@ -225,25 +226,6 @@ static void caravan_help_build_wonder_callback(GtkWidget *w, gpointer data)
   free(args);
 }
 
-/**************************************************************************
-  Returns a string with how many shields remains of the current production.
-  This is useful as custom information on the help build wonder button.
-**************************************************************************/
-static const gchar *city_prod_remaining(struct city* destcity)
-{
-  if (destcity == NULL
-      || city_owner(destcity) != client.conn.playing) {
-    /* Can't give remaining production for a foreign or non existing
-     * city. */
-    return NULL;
-  }
-
-  return g_strdup_printf(_("%d remaining"),
-                         impr_build_shield_cost(
-                           destcity->production.value.building)
-                         - destcity->shield_stock);
-}
-
 /**********************************************************************
   User responded to bribe dialog
 **********************************************************************/
@@ -508,13 +490,10 @@ static void create_advances_list(struct player *pplayer,
   struct unit *actor_unit = game_unit_by_number(args->actor_unit_id);
 
   spy_tech_shell = gtk_dialog_new_with_buttons(_("Steal Technology"),
-    NULL,
-    0,
-    GTK_STOCK_CANCEL,
-    GTK_RESPONSE_CANCEL,
-    _("_Steal"),
-    GTK_RESPONSE_ACCEPT,
-    NULL);
+                                               NULL, 0,
+                                               _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                               _("_Steal"), GTK_RESPONSE_ACCEPT,
+                                               NULL);
   setup_dialog(spy_tech_shell, toplevel);
   gtk_window_set_position(GTK_WINDOW(spy_tech_shell), GTK_WIN_POS_MOUSE);
 
@@ -693,13 +672,10 @@ static void create_improvements_list(struct player *pplayer,
   struct unit *actor_unit = game_unit_by_number(args->actor_unit_id);
   
   spy_sabotage_shell = gtk_dialog_new_with_buttons(_("Sabotage Improvements"),
-    NULL,
-    0,
-    GTK_STOCK_CANCEL,
-    GTK_RESPONSE_CANCEL,
-    _("_Sabotage"), 
-    GTK_RESPONSE_ACCEPT,
-    NULL);
+                                                   NULL, 0,
+                                                   _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                   _("_Sabotage"), GTK_RESPONSE_ACCEPT,
+                                                   NULL);
   setup_dialog(spy_sabotage_shell, toplevel);
   gtk_window_set_position(GTK_WINDOW(spy_sabotage_shell), GTK_WIN_POS_MOUSE);
 
@@ -1129,7 +1105,7 @@ static const GCallback af_map[ACTION_COUNT] = {
 static void action_entry(GtkWidget *shl,
                          int act_id,
                          const struct act_prob *act_probs,
-                         const gchar *custom,
+                         const char *custom,
                          struct action_data *handler_args)
 {
   const gchar *label;
@@ -1174,7 +1150,7 @@ static void action_entry(GtkWidget *shl,
 static void action_entry_update(GtkWidget *shl,
                                 int act_id,
                                 const struct act_prob *act_probs,
-                                const gchar *custom,
+                                const char *custom,
                                 struct action_data *handler_args)
 {
   const gchar *label;
@@ -1290,8 +1266,10 @@ void popup_action_selection(struct unit *actor_unit,
       action_entry(shl,
                    (enum gen_action)act,
                    act_probs,
-                   act == ACTION_HELP_WONDER ?
-                     city_prod_remaining(target_city) : NULL,
+                   get_act_sel_action_custom_text(action_by_number(act),
+                                                  act_probs[act],
+                                                  actor_unit,
+                                                  target_city),
                    data);
     }
   } action_iterate_end;
@@ -1304,7 +1282,10 @@ void popup_action_selection(struct unit *actor_unit,
       action_entry(shl,
                    (enum gen_action)act,
                    act_probs,
-                   NULL,
+                   get_act_sel_action_custom_text(action_by_number(act),
+                                                  act_probs[act],
+                                                  actor_unit,
+                                                  target_city),
                    data);
     }
   } action_iterate_end;
@@ -1343,7 +1324,7 @@ void popup_action_selection(struct unit *actor_unit,
 
   action_button_map[BUTTON_CANCEL] =
       choice_dialog_get_number_of_buttons(shl);
-  choice_dialog_add(shl, GTK_STOCK_CANCEL,
+  choice_dialog_add(shl, _("_Cancel"),
                     (GCallback)act_sel_cancel_callback, data,
                     FALSE, NULL);
 
@@ -1439,20 +1420,17 @@ void action_selection_refresh(struct unit *actor_unit,
                   0);
 
   action_iterate(act) {
-    const gchar *custom;
+    const char *custom;
 
     if (action_id_get_actor_kind(act) != AAK_UNIT) {
       /* Not relevant. */
       continue;
     }
 
-    if (action_prob_possible(act_probs[act])
-        && act == ACTION_HELP_WONDER) {
-      /* Add information about how far along the wonder is. */
-      custom = city_prod_remaining(target_city);
-    } else {
-      custom = NULL;
-    }
+    custom = get_act_sel_action_custom_text(action_by_number(act),
+                                            act_probs[act],
+                                            actor_unit,
+                                            target_city);
 
     if (BUTTON_NOT_THERE == action_button_map[act]) {
       /* Add the button (unless its probability is 0). */
