@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996-2005 - Freeciv Development Team
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,14 +17,13 @@
 
 #include "canvas_g.h"
 
-#include "gtkpixcomm.h"
-
 struct canvas
 {
   cairo_surface_t *surface;
   cairo_t *drawable;
+  float zoom;
 };
 
-#define FC_STATIC_CANVAS_INIT { NULL, NULL }
+#define FC_STATIC_CANVAS_INIT { NULL, NULL, 1.0 }
 
 #endif  /* FC__CANVAS_H */
