@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,4 +17,7 @@
 
 #include "diplodlg_g.h"
 
+void diplomacy_dialog_init(void);
+void diplomacy_dialog_done(void);
+
 #endif  /* FC__DIPLODLG_H */
