@@ -27,6 +27,10 @@
 #include "audio.h"
 #include "client_main.h"
 
+/* client/gui-gtk-3.22 */
+#include "gui_main.h"
+#include "gui_stuff.h"
+
 #include "dialogs_g.h"
 
 static void soundset_suggestion_callback(GtkWidget *dlg, gint arg);
@@ -39,7 +43,8 @@ static void soundset_suggestion_callback(GtkWidget *dlg, gint arg)
 {
   if (arg == GTK_RESPONSE_YES) {
     /* User accepted soundset loading */
-    audio_restart(game.control.preferred_soundset, music_set_name);
+    audio_restart(game.control.preferred_soundset,
+                  music_set_name);
   }
 }
 
@@ -60,6 +65,7 @@ void popup_soundset_suggestion_dialog(void)
                                        _("_Keep current soundset"),
                                        GTK_RESPONSE_NO,
                                        NULL);
+  setup_dialog(dialog, toplevel);
   gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_YES);
   gtk_window_set_destroy_with_parent(GTK_WINDOW(dialog), TRUE);
 
@@ -70,7 +76,7 @@ void popup_soundset_suggestion_dialog(void)
               game.control.preferred_soundset, sound_set_name);
 
   label = gtk_label_new(buf);
-  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), label);
+  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))), label);
   gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
   gtk_widget_show(label);
 
@@ -123,7 +129,7 @@ void popup_musicset_suggestion_dialog(void)
               game.control.preferred_musicset, music_set_name);
 
   label = gtk_label_new(buf);
-  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), label);
+  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))), label);
   gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
   gtk_widget_show(label);
 
