@@ -643,10 +643,13 @@ void hud_units::update_actions(unit_list *punits)
                                       " (Selected %1 units)", n))
                .arg(n);
   } else if (num > 1) {
+    QByteArray ut_bytes;
+
+    ut_bytes = snum.toLocal8Bit();
     /* TRANS: preserve leading space */
     text_str = text_str + QString(PL_(" +%1 unit",
                                       " +%1 units", num-1))
-                                  .arg(snum.toLocal8Bit().data());
+                                  .arg(ut_bytes.data());
   }
   text_label.setTextFormat(Qt::PlainText);
   text_label.setText(text_str);
@@ -993,10 +996,8 @@ int unit_actions::update_actions()
     actions.append(a);
     if (pterrain->mining_result != T_NONE
         && pterrain->mining_result != pterrain) {
-      if (!strcmp(terrain_rule_name(pterrain), "Jungle")
-          || !strcmp(terrain_rule_name(pterrain), "Plains")
-          || !strcmp(terrain_rule_name(pterrain), "Grassland")
-          || !strcmp(terrain_rule_name(pterrain), "Swamp")) {
+      /* FIXME get rid of this ruleset-specific hardcoding */
+      if (!strcmp(terrain_rule_name(pterrain->mining_result), "Forest")) {
         a->set_pixmap(fc_icons::instance()->get_pixmap("plantforest"));
       } else {
         a->set_pixmap(fc_icons::instance()->get_pixmap("transform"));
@@ -1012,6 +1013,7 @@ int unit_actions::update_actions()
     a->action_shortcut = SC_BUILDIRRIGATION;
     if (pterrain->irrigation_result != T_NONE
         && pterrain->irrigation_result != pterrain) {
+      /* FIXME get rid of this ruleset-specific hardcoding */
       if ((!strcmp(terrain_rule_name(pterrain), "Forest") ||
            !strcmp(terrain_rule_name(pterrain), "Jungle"))) {
         a->set_pixmap(fc_icons::instance()->get_pixmap("chopchop"));
@@ -1039,8 +1041,7 @@ int unit_actions::update_actions()
       if (can_build_road(proad, current_unit, unit_tile(current_unit))) {
         ok = true;
       }
-    }
-    extra_type_by_cause_iterate_end;
+    } extra_type_by_cause_iterate_end;
     if (ok) {
       a = new hud_action(this);
       a->action_shortcut = SC_BUILDROAD;
@@ -1649,6 +1650,7 @@ void show_new_turn_info()
   QList<hud_text *> close_list;
   struct research *research;
   int i;
+  char buf[25];
 
   if (!client_has_player()
       || !gui()->qt_settings.show_new_turn_text) {
@@ -1674,9 +1676,14 @@ void show_new_turn_info()
         + QString::number(research->client.researching_cost) + ")";
   }
   s = s + "\n" + science_dialog_text() + "\n";
-  s = s + QString(_("Gold: %1 (+%2)"))
+
+  /* Can't use QString().sprintf() as msys libintl.h defines sprintf() as a macro */
+  fc_snprintf(buf, sizeof(buf), "%+d", player_get_expected_income(client.conn.playing));
+
+  /* TRANS: current gold, then loss/gain per turn */
+  s = s + QString(_("Gold: %1 (%2)"))
       .arg(client.conn.playing->economic.gold)
-      .arg(player_get_expected_income(client.conn.playing));
+      .arg(buf);
   ht = new hud_text(s, 5, gui()->mapview_wdg);
   ht->show_me();
 }
