@@ -58,7 +58,11 @@ extern QApplication *qapp;
 #define MAX_DIRTY_RECTS 20
 static int num_dirty_rects = 0;
 static QRect dirty_rects[MAX_DIRTY_RECTS];
-static int last_turn = 0;
+
+extern int last_center_enemy;
+extern int last_center_capital;
+extern int last_center_player_city;
+extern int last_center_enemy_city;
 
 /**************************************************************************
   Check if point x, y is in area (px -> pxe, py - pye)
@@ -155,7 +159,7 @@ mr_idle::mr_idle()
 **************************************************************************/
 mr_idle::~mr_idle()
 {
-  call_me_back* cb;
+  call_me_back *cb;
 
   while (!callback_list.isEmpty()) {
     cb = callback_list.dequeue();
@@ -164,11 +168,11 @@ mr_idle::~mr_idle()
 }
 
 /**************************************************************************
-  slot used to execute 1 callback from callabcks stored in idle list
+  Slot used to execute 1 callback from callbacks stored in idle list
 **************************************************************************/
 void mr_idle::idling()
 {
-  call_me_back* cb;
+  call_me_back *cb;
 
   while (!callback_list.isEmpty()) {
     cb = callback_list.dequeue();
@@ -180,7 +184,7 @@ void mr_idle::idling()
 /**************************************************************************
   Adds one callback to execute later
 **************************************************************************/
-void mr_idle::add_callback(call_me_back* cb)
+void mr_idle::add_callback(call_me_back *cb)
 {
   callback_list.enqueue(cb);
 }
@@ -1082,10 +1086,6 @@ void qtg_update_timeout_label(void)
 {
   gui()->sw_endturn->set_custom_labels(QString(get_timeout_label_text()));
   gui()->sw_endturn->update_final_pixmap();
-  if (last_turn != game.info.turn) {
-    qt_start_turn();
-  }
-  last_turn = game.info.turn;
 }
 
 /****************************************************************************
@@ -1438,3 +1438,16 @@ void info_tile::update_font(const QString &name, const QFont &font)
     update();
   }
 }
+
+/**************************************************************************
+  New turn callback
+**************************************************************************/
+void qtg_start_turn()
+{
+  gui()->rallies.run();
+  show_new_turn_info();
+  last_center_enemy = 0;
+  last_center_capital = 0;
+  last_center_player_city = 0;
+  last_center_enemy_city = 0;
+}
