@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,8 +35,6 @@ class QSignalMapper;
 class QScrollArea;
 struct fc_shortcut;
 
-void qt_start_turn();
-
 /** used for indicating menu about current option - for renaming
  * and enabling, disabling */
 enum munit {
