@@ -15,11 +15,20 @@
 #include <fc_config.h>
 #endif
 
-/* common */
+// Qt
+#include <QGridLayout>
+#include <QLabel>
+
+// common
 #include "game.h"
+#include "victory.h"
+
+// client
+#include "client_main.h"
 
 // gui-qt
 #include "canvas.h"
+#include "fc_client.h"
 #include "qtg_cxxside.h"
 #include "spaceshipdlg.h"
 
@@ -32,7 +41,6 @@ class QGridLayout;
 ss_report::ss_report(struct player *pplayer)
 {
   int w, h;
-  QSize size;
 
   setAttribute(Qt::WA_DeleteOnClose);
   player = pplayer;
@@ -46,7 +54,7 @@ ss_report::ss_report(struct player *pplayer)
   ss_label = new QLabel;
   layout->addWidget(ss_label, 0, 3, 3, 1);
   launch_button = new QPushButton(_("Launch"));
-  connect(launch_button, SIGNAL(clicked()), SLOT(launch()));
+  connect(launch_button, &QAbstractButton::clicked, this, &ss_report::launch);
   layout->addWidget(launch_button, 4, 3, 1, 1);
   setLayout(layout);
   update_report();
@@ -68,7 +76,7 @@ void ss_report::init()
 {
   int index;
   gui()->gimme_place(this, "SPS");
-  index = gui()->add_game_tab(this, _("Spaceship"));
+  index = gui()->add_game_tab(this);
   gui()->game_tab_widget->setCurrentIndex(index);
   update_report();
 }
@@ -83,9 +91,8 @@ void ss_report::update_report()
 
   pship = &(player->spaceship);
 
-  if (game.info.spacerace && player == client.conn.playing
+  if (victory_enabled(VC_SPACERACE) && player == client.conn.playing
       && pship->state == SSHIP_STARTED && pship->success_rate > 0.0) {
-
     launch_button->setEnabled(true);
   } else {
     launch_button->setEnabled(false);
