@@ -1,4 +1,4 @@
-/**********************************************************************
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,15 +44,17 @@ const char **gfx_fileextensions(void)
 
   gfx_ext = QImageReader::supportedImageFormats();
 
-  gfx_array_extensions = new const char *[gfx_ext.count()];
-  while (gfx_ext.isEmpty() == false) {
+  gfx_array_extensions = new const char *[gfx_ext.count() + 1];
+  while (!gfx_ext.isEmpty()) {
     char *ext;
+
     cp = gfx_ext.takeFirst();
     ext = static_cast<char *>(fc_malloc(sizeof(cp)));
     strncpy(ext, cp.data(), sizeof(cp));
     gfx_array_extensions[j] = ext;
     j++;
   }
+  gfx_array_extensions[j] = NULL;
 
   return gfx_array_extensions;
 }
