@@ -1,4 +1,4 @@
-/**********************************************************************
+/***********************************************************************
  Freeciv - Copyright (C) 2001 - R. Falke, M. Kaufman
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,7 +15,8 @@
 #include <fc_config.h>
 #endif
 
-#include "SDL/SDL.h"
+/* SDL */
+#include <SDL/SDL.h>
 
 /* utility */
 #include "fcintl.h"
@@ -340,17 +341,17 @@ static int save_cma_callback(struct widget *pWidget)
     add_to_gui_list(ID_EDIT, pBuf);
     /* ============================================================= */
 
-    pBuf = create_themeicon_button_from_chars(pTheme->OK_Icon, pWindow->dst,
-                                                _("Yes"), adj_font(12), 0);
-  
+    pBuf = create_themeicon_button_from_chars(current_theme->OK_Icon, pWindow->dst,
+                                              _("Yes"), adj_font(12), 0);
+
     pBuf->action = ok_save_cma_callback;
     set_wstate(pBuf, FC_WS_NORMAL);
     pBuf->key = SDLK_RETURN;
     add_to_gui_list(ID_BUTTON, pBuf);
     pBuf->data.ptr = (void *)pBuf->next;
-    
-    pBuf = create_themeicon_button_from_chars(pTheme->CANCEL_Icon,
-                              pWindow->dst, _("No"), adj_font(12), 0);
+
+    pBuf = create_themeicon_button_from_chars(current_theme->CANCEL_Icon,
+                                              pWindow->dst, _("No"), adj_font(12), 0);
     pBuf->action = cancel_SLD_cma_callback;
     set_wstate(pBuf, FC_WS_NORMAL);
     pBuf->key = SDLK_ESCAPE;
@@ -496,7 +497,7 @@ static void popup_load_del_presets_dialog(bool load, struct widget *pButton)
   
   /* ---------- */
   /* create exit button */
-  pBuf = create_themeicon(pTheme->Small_CANCEL_Icon, pWindow->dst,
+  pBuf = create_themeicon(current_theme->Small_CANCEL_Icon, pWindow->dst,
                           WF_WIDGET_HAS_INFO_LABEL | WF_RESTORE_BACKGROUND);
   pBuf->info_label = create_str16_from_char(_("Close Dialog (Esc)"),
                                             adj_font(12));
@@ -638,10 +639,11 @@ static int run_cma_once_callback(struct widget *pWidget)
     update_city_cma_dialog();
     /* fill in result label */
     result = cm_result_new(pCma->pCity);
-    cm_query_result(pCma->pCity, &pCma->edited_cm_parm, result);
+    cm_query_result(pCma->pCity, &pCma->edited_cm_parm, result, FALSE);
     cma_apply_result(pCma->pCity, result);
     cm_result_destroy(result);
   }
+
   return -1;
 }
 
@@ -890,13 +892,13 @@ void popup_city_cma_dialog(struct city *pCity)
   cmafec_get_fe_parameter(pCity, &pCma->edited_cm_parm);
   
   /* --------------------------- */
-    
+
   fc_snprintf(cBuf, sizeof(cBuf),
-	      _("City of %s (Population %s citizens) : %s"),
-	      city_name(pCity),
-	      population_to_text(city_population(pCity)),
-	      _("Citizen Governor"));
-  
+              _("City of %s (Population %s citizens) : %s"),
+              city_name_get(pCity),
+              population_to_text(city_population(pCity)),
+              _("Citizen Governor"));
+
   pStr = create_str16_from_char(cBuf, adj_font(12));
   pStr->style |= TTF_STYLE_BOLD;
 
@@ -911,7 +913,7 @@ void popup_city_cma_dialog(struct city *pCity)
   
   /* ---------- */
   /* create exit button */
-  pBuf = create_themeicon(pTheme->Small_CANCEL_Icon, pWindow->dst,
+  pBuf = create_themeicon(current_theme->Small_CANCEL_Icon, pWindow->dst,
                           WF_WIDGET_HAS_INFO_LABEL | WF_RESTORE_BACKGROUND);
   pBuf->info_label = create_str16_from_char(_("Close Dialog (Esc)"),
                                             adj_font(12));
@@ -946,8 +948,8 @@ void popup_city_cma_dialog(struct city *pCity)
     add_to_gui_list(ID_LABEL, pBuf);
 
     /* minimal scrollbar */
-    pBuf = create_horizontal(pTheme->Horiz, pWindow->dst, adj_size(30),
-			(WF_RESTORE_BACKGROUND));
+    pBuf = create_horizontal(current_theme->Horiz, pWindow->dst, adj_size(30),
+                             (WF_RESTORE_BACKGROUND));
 
     pBuf->action = min_horiz_cma_callback;
     pBuf->data.ptr = &pCma->edited_cm_parm.minimal_surplus[i];
@@ -964,8 +966,8 @@ void popup_city_cma_dialog(struct city *pCity)
     add_to_gui_list(ID_LABEL, pBuf);
     
     /* factor scrollbar */
-    pBuf = create_horizontal(pTheme->Horiz, pWindow->dst, adj_size(30),
-			(WF_RESTORE_BACKGROUND));
+    pBuf = create_horizontal(current_theme->Horiz, pWindow->dst, adj_size(30),
+                             (WF_RESTORE_BACKGROUND));
 
     pBuf->action = factor_horiz_cma_callback;
     pBuf->data.ptr = &pCma->edited_cm_parm.factor[i];
@@ -987,8 +989,8 @@ void popup_city_cma_dialog(struct city *pCity)
   add_to_gui_list(ID_LABEL, pBuf);
   
   /* happy factor scrollbar */
-  pBuf = create_horizontal(pTheme->Horiz, pWindow->dst, adj_size(30),
-			(WF_RESTORE_BACKGROUND));
+  pBuf = create_horizontal(current_theme->Horiz, pWindow->dst, adj_size(30),
+                           (WF_RESTORE_BACKGROUND));
 
   pBuf->action = factor_horiz_cma_callback;
   pBuf->data.ptr = &pCma->edited_cm_parm.happy_factor;
@@ -1006,7 +1008,7 @@ void popup_city_cma_dialog(struct city *pCity)
   add_to_gui_list(ID_CHECKBOX, pBuf);
     
   /* save as ... */
-  pBuf = create_themeicon(pTheme->SAVE_Icon, pWindow->dst,
+  pBuf = create_themeicon(current_theme->SAVE_Icon, pWindow->dst,
                           WF_RESTORE_BACKGROUND |WF_WIDGET_HAS_INFO_LABEL);
   pBuf->action = save_cma_callback;
   pBuf->info_label = create_str16_from_char(_("Save settings as..."),
@@ -1015,7 +1017,7 @@ void popup_city_cma_dialog(struct city *pCity)
   add_to_gui_list(ID_ICON, pBuf);
   
   /* load settings */
-  pBuf = create_themeicon(pTheme->LOAD_Icon, pWindow->dst,
+  pBuf = create_themeicon(current_theme->LOAD_Icon, pWindow->dst,
                           WF_RESTORE_BACKGROUND | WF_WIDGET_HAS_INFO_LABEL);
   pBuf->action = load_cma_callback;
   pBuf->info_label = create_str16_from_char(_("Load settings"),
@@ -1024,7 +1026,7 @@ void popup_city_cma_dialog(struct city *pCity)
   add_to_gui_list(ID_ICON, pBuf);
   
   /* del settings */
-  pBuf = create_themeicon(pTheme->DELETE_Icon, pWindow->dst,
+  pBuf = create_themeicon(current_theme->DELETE_Icon, pWindow->dst,
                           WF_RESTORE_BACKGROUND | WF_WIDGET_HAS_INFO_LABEL);
   pBuf->action = del_cma_callback;
   pBuf->info_label = create_str16_from_char(_("Delete settings"),
@@ -1033,7 +1035,7 @@ void popup_city_cma_dialog(struct city *pCity)
   add_to_gui_list(ID_ICON, pBuf);
     
   /* run cma */
-  pBuf = create_themeicon(pTheme->QPROD_Icon, pWindow->dst,
+  pBuf = create_themeicon(current_theme->QPROD_Icon, pWindow->dst,
                           WF_RESTORE_BACKGROUND | WF_WIDGET_HAS_INFO_LABEL);
   pBuf->action = run_cma_callback;
   pBuf->info_label = create_str16_from_char(_("Control city"), adj_font(10));
@@ -1041,7 +1043,7 @@ void popup_city_cma_dialog(struct city *pCity)
   add_to_gui_list(ID_ICON, pBuf);
   
   /* run cma onece */
-  pBuf = create_themeicon(pTheme->FindCity_Icon, pWindow->dst,
+  pBuf = create_themeicon(current_theme->FindCity_Icon, pWindow->dst,
                           WF_RESTORE_BACKGROUND | WF_WIDGET_HAS_INFO_LABEL);
   pBuf->action = run_cma_once_callback;
   pBuf->info_label = create_str16_from_char(_("Apply once"), adj_font(10));
@@ -1049,7 +1051,7 @@ void popup_city_cma_dialog(struct city *pCity)
   add_to_gui_list(ID_ICON, pBuf);
   
   /* del settings */
-  pBuf = create_themeicon(pTheme->Support_Icon, pWindow->dst,
+  pBuf = create_themeicon(current_theme->Support_Icon, pWindow->dst,
                           WF_RESTORE_BACKGROUND | WF_WIDGET_HAS_INFO_LABEL);
   pBuf->action = stop_cma_callback;
   pBuf->info_label = create_str16_from_char(_("Release city"), adj_font(10));
