@@ -78,7 +78,7 @@ static void popdown_sdip_dialog(void);
 /****************************************************************
   Initialialize diplomacy dialog system.
 *****************************************************************/
-void diplomacy_dialog_init()
+void diplomacy_dialog_init(void)
 {
   dialog_list = dialog_list_new();
 }
@@ -86,7 +86,7 @@ void diplomacy_dialog_init()
 /****************************************************************
   Free resources allocated for diplomacy dialog system.
 *****************************************************************/
-void diplomacy_dialog_done()
+void diplomacy_dialog_done(void)
 {
   dialog_list_destroy(dialog_list);
 }
