@@ -15,7 +15,8 @@
 #include <fc_config.h>
 #endif
 
-#include "SDL/SDL.h"
+/* SDL */
+#include <SDL/SDL.h>
 
 /* utility */
 #include "log.h"
@@ -91,13 +92,12 @@ static SDL_Cursor *SurfaceToCursor(SDL_Surface *image, int hx, int hy) {
 /**************************************************************************
   Draw current cursor.
 **************************************************************************/
-void draw_mouse_cursor(void)
-{
+void draw_mouse_cursor(void) {
   int cursor_x = 0;
   int cursor_y = 0;
   static SDL_Rect area = {0, 0, 0, 0};
 
-  if (gui_sdl_use_color_cursors) {
+  if (gui_options.gui_sdl_use_color_cursors) {
     /* restore background */
     if (area.w != 0) {
       flush_rect(area, TRUE);
@@ -182,12 +182,12 @@ void animate_mouse_cursor(void)
   }
 
   if (mouse_cursor_type != CURSOR_DEFAULT) {
-    if (!gui_sdl_do_cursor_animation
+    if (!gui_options.gui_sdl_do_cursor_animation
         || (cursor_frame == NUM_CURSOR_FRAMES)) {
       cursor_frame = 0;
     }
 
-    if (gui_sdl_use_color_cursors) {
+    if (gui_options.gui_sdl_use_color_cursors) {
       current_color_cursor.cursor = GET_SURF(get_cursor_sprite(tileset,
                                     mouse_cursor_type,
                                     &current_color_cursor.hot_x,
@@ -213,12 +213,12 @@ void update_mouse_cursor(enum cursor_type new_cursor_type)
   
   if (mouse_cursor_type == CURSOR_DEFAULT) {
     SDL_SetCursor(pStd_Cursor);
-    if (gui_sdl_use_color_cursors) {
+    if (gui_options.gui_sdl_use_color_cursors) {
       current_color_cursor.cursor = NULL;
     }
     mouse_cursor_changed = FALSE;    
   } else {
-    if (gui_sdl_use_color_cursors) {
+    if (gui_options.gui_sdl_use_color_cursors) {
       SDL_SetCursor(pDisabledCursor);
     }
     mouse_cursor_changed = TRUE;
