@@ -22,11 +22,12 @@
 #ifndef FC__GUISTRING_H
 #define FC__GUISTRING_H
 
-#include "SDL/SDL.h"
+/* SDL */
+#include <SDL/SDL.h>
+#include <SDL/SDL_ttf.h>
 
 #include "fc_types.h"
 
-#include "SDL_ttf.h"
 #include "gui_main.h"
 
 #define SF_CENTER	0x10
