@@ -31,6 +31,7 @@
 #include "log.h"
 
 /* common */
+#include "clientutils.h"
 #include "game.h"
 #include "road.h"
 #include "traderoutes.h"
@@ -60,8 +61,11 @@ extern struct widget *pOptions_Button;
   
 static struct widget *pBeginOrderWidgetList;
 static struct widget *pEndOrderWidgetList;
-  
-static struct widget *pOrder_Automate_Unit_Button;
+
+static struct widget *pOrder_Fallout_Button;
+static struct widget *pOrder_Pollution_Button;
+static struct widget *pOrder_Airbase_Button;
+static struct widget *pOrder_Fortress_Button;
 static struct widget *pOrder_Build_AddTo_City_Button;
 static struct widget *pOrder_Mine_Button;
 static struct widget *pOrder_Irrigation_Button;
@@ -396,8 +400,6 @@ void create_units_order_widgets(void)
 {
   struct widget *pBuf = NULL;
   char cBuf[128];
-  Uint16 *unibuf;  
-  size_t len;
   struct road_type *proad;
   struct road_type *prail;
 
@@ -619,25 +621,16 @@ void create_units_order_widgets(void)
   add_to_gui_list(ID_UNIT_ORDER_AUTO_EXPLORE, pBuf);
   /* --------- */
 
-  /* Auto-Attack / Auto-Settler */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Attack"), "A");
-  len = strlen(cBuf);
+  /* Auto-Settler */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Settler"), "A");
-  len = MAX(len, strlen(cBuf));
-
   pBuf = create_themeicon(current_theme->OAutoSett_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
   pBuf->action = unit_order_callback;
-  len = (len + 1) * sizeof(Uint16);
-  unibuf = fc_calloc(1, len);
-  convertcopy_to_utf16(unibuf, len, cBuf);
-  pBuf->info_label = create_string16(unibuf, len, adj_font(10));
+  pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_a;
   add_to_gui_list(ID_UNIT_ORDER_AUTO_SETTLER, pBuf);
-  
-  pOrder_Automate_Unit_Button = pBuf;
   /* --------- */
 
   /* Wake Up Others */
@@ -728,7 +721,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Clean Nuclear Fallout */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Clean Nuclear Fallout"), "N");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OFallout_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -736,6 +730,7 @@ void create_units_order_widgets(void)
   pBuf->action = unit_order_callback;
   pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_n;
+  pOrder_Fallout_Button = pBuf;
   add_to_gui_list(ID_UNIT_ORDER_FALLOUT, pBuf);
   /* --------- */
 
@@ -752,7 +747,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Clean Pollution */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Clean Pollution"), "P");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OPollution_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -760,11 +756,13 @@ void create_units_order_widgets(void)
   pBuf->action = unit_order_callback;
   pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_p;
+  pOrder_Pollution_Button = pBuf;
   add_to_gui_list(ID_UNIT_ORDER_POLLUTION, pBuf);
   /* --------- */
 
   /* Build Airbase */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Airbase"), "Shift+E");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OAirBase_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -772,6 +770,8 @@ void create_units_order_widgets(void)
   pBuf->action = unit_order_callback;
   pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_e;
+  pBuf->mod = KMOD_SHIFT;
+  pOrder_Airbase_Button = pBuf;
   add_to_gui_list(ID_UNIT_ORDER_AIRBASE, pBuf);
   /* --------- */
 
@@ -788,7 +788,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Build Fortress */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Fortress"), "Shift+F");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OFortress_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -796,11 +797,14 @@ void create_units_order_widgets(void)
   pBuf->action = unit_order_callback;
   pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_f;
+  pBuf->mod = KMOD_SHIFT;
+  pOrder_Fortress_Button = pBuf;
   add_to_gui_list(ID_UNIT_ORDER_FORTRESS, pBuf);
   /* --------- */
 
   /* Transform Tile */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Transform Tile"), "O");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OTransform_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -813,7 +817,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Build Mine */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Mine"), "M");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OMine_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -827,22 +832,23 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Build Irrigation */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Irrigation"), "I");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OIrrigation_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
   pBuf->action = unit_order_callback;
-  pBuf->key = SDLK_i;
   pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
+  pBuf->key = SDLK_i;
   add_to_gui_list(ID_UNIT_ORDER_IRRIGATE, pBuf);
 
   pOrder_Irrigation_Button = pBuf;
   /* --------- */
 
-  /* Form Trade route */
-  fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)",
-              action_id_name_translation(ACTION_TRADE_ROUTE), "R");
+  /* Establish Trade route */
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OTrade_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -856,30 +862,14 @@ void create_units_order_widgets(void)
   /* --------- */    
 
   /* Build (Rail-)Road */
-  /* TRANS: "Build Railroad (R) 999 turns" */
-  if (prail != NULL) {
-    fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
-                extra_name_translation(road_extra_get(prail)), "R", 999,
-                PL_("turn", "turns", 999));
-    len = strlen(cBuf);
-  }
-  /* TRANS: "Build Road (R) 999 turns" */
-  if (proad != NULL) {
-    fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
-                extra_name_translation(road_extra_get(proad)), "R", 999,
-                PL_("turn", "turns", 999));
-    len = MAX(len, strlen(cBuf));
-  }
-
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->ORoad_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
   pBuf->action = unit_order_callback;
-  len = (len + 1) * sizeof(Uint16);
-  unibuf = fc_calloc(1, len);
-  convertcopy_to_utf16(unibuf, len, cBuf);
-  pBuf->info_label = create_string16(unibuf, len, adj_font(10));
+  pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_r;
   add_to_gui_list(ID_UNIT_ORDER_ROAD, pBuf);
 
@@ -900,20 +890,14 @@ void create_units_order_widgets(void)
   /* --------- */  
 
   /* Add to City / Build New City */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Add to City"), "B");
-  len = strlen(cBuf);
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build City"), "B");
-  len = MAX(len, strlen(cBuf));
-
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OBuildCity_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
   pBuf->action = unit_order_callback;
-  len = (len + 1) * sizeof(Uint16);
-  unibuf = fc_calloc(1, len);
-  convertcopy_to_utf16(unibuf, len, cBuf);
-  pBuf->info_label = create_string16(unibuf, len, adj_font(10));
+  pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_b;
   add_to_gui_list(ID_UNIT_ORDER_BUILD_CITY, pBuf);
   
@@ -1082,8 +1066,7 @@ void real_menus_update(void)
       struct city *pCity = tile_city(pTile);
       struct terrain *pTerrain = tile_terrain(pTile);
       struct base_type *pbase;
-      struct extra_type *pextra = next_extra_for_tile(pTile, EC_ROAD,
-                                                      unit_owner(pUnit), pUnit);
+      struct extra_type *pextra;
 
       if (!counter) {
 	local_show(ID_UNIT_ORDER_GOTO);
@@ -1115,11 +1098,14 @@ void real_menus_update(void)
 	local_hide(ID_UNIT_ORDER_BUILD_WONDER);
       }
 
-      if (pextra != NULL) {
+      pextra = next_extra_for_tile(pTile, EC_ROAD,
+                                   unit_owner(pUnit), pUnit);
+      if (pextra != NULL
+          && can_unit_do_activity_targeted(pUnit, ACTIVITY_GEN_ROAD, pextra)) {
         struct road_type *proad = extra_road_get(pextra);
         enum road_compat compat = road_compat_special(proad);
 
-        time = tile_activity_time(ACTIVITY_GEN_ROAD, pTile, road_extra_get(proad));
+        time = turns_to_activity_done(pTile, ACTIVITY_GEN_ROAD, pextra, pUnit);
 
         /* TRANS: "Build Railroad (R) 3 turns" */
 	fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
@@ -1168,73 +1154,95 @@ void real_menus_update(void)
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_IRRIGATE)) {
-        time = tile_activity_time(ACTIVITY_IRRIGATE, unit_tile(pUnit), NULL);
+        if (is_build_activity(ACTIVITY_IRRIGATE, pTile)) {
+          /* Activity results in extra */
+          struct extra_type *irrig_extra = next_extra_for_tile(pTile, EC_IRRIGATION,
+                                                               unit_owner(pUnit),
+                                                               pUnit);
 
-        if (!strcmp(terrain_rule_name(pTerrain), "Forest") ||
-          !strcmp(terrain_rule_name(pTerrain), "Jungle")) {
-	  /* set Crop Forest Icon */
-	  fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
-			_("Cut Down to"),
-                terrain_name_translation(pTerrain->irrigation_result)
-			,"I", time , PL_("turn", "turns", time));
-	  pOrder_Irrigation_Button->theme = current_theme->OCutDownForest_Icon;
-        }	else if (!strcmp(terrain_rule_name(pTerrain), "Swamp")) {
-	  fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
-			_("Irrigate to"),
-                terrain_name_translation(pTerrain->irrigation_result)
-			,"I", time , PL_("turn", "turns", time));
-	  pOrder_Irrigation_Button->theme = current_theme->OIrrigation_Icon;
+          time = turns_to_activity_done(pTile, ACTIVITY_IRRIGATE,
+                                        irrig_extra, pUnit);
+          /* TRANS: "Build Irrigation (I) 5 turns" */
+          fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
+                      extra_name_translation(irrig_extra), "I", time,
+                      PL_("turn", "turns", time));
+          pOrder_Irrigation_Button->theme = current_theme->OIrrigation_Icon;
         } else {
-	  /* set Irrigation Icon */
-	  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s) %d %s",
-			_("Build Irrigation"), "I", time , 
-			PL_("turn", "turns", time));
-	  pOrder_Irrigation_Button->theme = current_theme->OIrrigation_Icon;
-	}
+          /* Activity results in terrain change */
+          time = turns_to_activity_done(pTile, ACTIVITY_IRRIGATE,
+                                        NULL, pUnit);
+
+          /* FIXME: get rid of this ruleset-specific hardcoding */
+          if (!strcmp(terrain_rule_name(pTerrain), "Forest")
+              || !strcmp(terrain_rule_name(pTerrain), "Jungle")) {
+            /* set Crop Forest Icon */
+            fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
+                        _("Cut Down to"),
+                        terrain_name_translation(pTerrain->irrigation_result),
+                        "I", time , PL_("turn", "turns", time));
+            pOrder_Irrigation_Button->theme = current_theme->OCutDownForest_Icon;
+          } else {
+            /* TRANS: "Change to Grassland (I) 10 turns" */
+            fc_snprintf(cBuf, sizeof(cBuf), _("Change to %s (%s) %d %s"),
+                        terrain_name_translation(pTerrain->irrigation_result),
+                        "I", time , PL_("turn", "turns", time));
+            pOrder_Irrigation_Button->theme = current_theme->OIrrigation_Icon;
+          }
+        }
 
         copy_chars_to_string16(pOrder_Irrigation_Button->info_label, cBuf);
-	clear_wflag(pOrder_Irrigation_Button, WF_HIDDEN);
+        clear_wflag(pOrder_Irrigation_Button, WF_HIDDEN);
       } else {
 	set_wflag(pOrder_Irrigation_Button, WF_HIDDEN);
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_MINE)) {
-        time = tile_activity_time(ACTIVITY_MINE, unit_tile(pUnit), NULL);
+        if (is_build_activity(ACTIVITY_MINE, pTile)) {
+          /* Activity results in extra */
+          struct extra_type *mine_extra = next_extra_for_tile(pTile, EC_MINE,
+                                                              unit_owner(pUnit),
+                                                              pUnit);
 
-	/* FIXME: THIS CODE IS WRONG */
-   if (!strcmp(terrain_rule_name(pTerrain), "Forest")) {  
-	  /* set Irrigate Icon -> make swamp */
-	  fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
-			_("Irrigate to"),
-			terrain_name_translation(pTerrain->mining_result)
-			,"M", time , PL_("turn", "turns", time));
-	  pOrder_Mine_Button->theme = current_theme->OIrrigation_Icon;
-   } else if (!strcmp(terrain_rule_name(pTerrain), "Jungle") ||
-              !strcmp(terrain_rule_name(pTerrain), "Plains") ||
-              !strcmp(terrain_rule_name(pTerrain), "Grassland") ||
-              !strcmp(terrain_rule_name(pTerrain), "Swamp")) {
-	  /* set Forest Icon -> plant Forrest*/
-	  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s) %d %s",
-			_("Plant Forest"), "M", time , 
-			PL_("turn", "turns", time));
-	  pOrder_Mine_Button->theme = current_theme->OPlantForest_Icon;
+          time = turns_to_activity_done(pTile, ACTIVITY_MINE, mine_extra, pUnit);
+          /* TRANS: "Build Mine (M) 5 turns" */
+          fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
+                      extra_name_translation(mine_extra), "M", time,
+                      PL_("turn", "turns", time));
+          pOrder_Mine_Button->theme = current_theme->OMine_Icon;
+        } else {
+          /* Activity results in terrain change */
+          time = turns_to_activity_done(pTile, ACTIVITY_MINE, NULL, pUnit);
 
-   } else {
-	  /* set Mining Icon */
-	  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s) %d %s",
-			_("Build Mine"), "M", time , 
-			PL_("turn", "turns", time));
-	  pOrder_Mine_Button->theme = current_theme->OMine_Icon;
-	}
+          /* FIXME: get rid of this ruleset-specific hardcoding */
+          if (!strcmp(terrain_rule_name(pTerrain->mining_result), "Forest")) {
+            /* set Forest Icon -> plant Forest */
+            fc_snprintf(cBuf, sizeof(cBuf), "%s (%s) %d %s",
+                        _("Plant Forest"), "M", time,
+                        PL_("turn", "turns", time));
+            pOrder_Mine_Button->theme = current_theme->OPlantForest_Icon;
+          } else {
+            /* TRANS: "Change to Swamp (M) 10 turns" */
+            fc_snprintf(cBuf, sizeof(cBuf), _("Change to %s (%s) %d %s"),
+                        terrain_name_translation(pTerrain->mining_result),
+                        "M", time , PL_("turn", "turns", time));
+            if (!strcmp(terrain_rule_name(pTerrain->mining_result), "Swamp")) {
+              /* set Irrigate Icon -> make swamp */
+              pOrder_Mine_Button->theme = current_theme->OIrrigation_Icon;
+            } else {
+              pOrder_Mine_Button->theme = current_theme->OPlantForest_Icon;
+            }
+          }
+        }
 
         copy_chars_to_string16(pOrder_Mine_Button->info_label, cBuf);
-	clear_wflag(pOrder_Mine_Button, WF_HIDDEN);
+        clear_wflag(pOrder_Mine_Button, WF_HIDDEN);
       } else {
 	set_wflag(pOrder_Mine_Button, WF_HIDDEN);
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_TRANSFORM)) {
-        time = tile_activity_time(ACTIVITY_TRANSFORM, unit_tile(pUnit), NULL);
+        /* Activity always results in terrain change */
+        time = turns_to_activity_done(pTile, ACTIVITY_TRANSFORM, NULL, pUnit);
         fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
                     _("Transform to"),
                     terrain_name_translation(pTerrain->transform_result),
@@ -1246,11 +1254,19 @@ void real_menus_update(void)
 	set_wflag(pOrder_Transform_Button, WF_HIDDEN);
       }
 
-      pbase = get_base_by_gui_type(BASE_GUI_FORTRESS, pUnit, unit_tile(pUnit));
+      pbase = get_base_by_gui_type(BASE_GUI_FORTRESS, pUnit, pTile);
       if (pbase != NULL) {
-        local_show(ID_UNIT_ORDER_FORTRESS);
+        struct extra_type *base_extra = base_extra_get(pbase);
+
+        time = turns_to_activity_done(pTile, ACTIVITY_BASE, base_extra, pUnit);
+        /* TRANS: "Build Fortress (Shift+F) 5 turns" */
+        fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
+                    extra_name_translation(base_extra), "Shift+F", time,
+                    PL_("turn", "turns", time));
+        copy_chars_to_string16(pOrder_Fortress_Button->info_label, cBuf);
+        clear_wflag(pOrder_Fortress_Button, WF_HIDDEN);
       } else {
-        local_hide(ID_UNIT_ORDER_FORTRESS);
+        set_wflag(pOrder_Fortress_Button, WF_HIDDEN);
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_FORTIFYING)) {
@@ -1259,17 +1275,35 @@ void real_menus_update(void)
 	local_hide(ID_UNIT_ORDER_FORTIFY);
       }
 
-      pbase = get_base_by_gui_type(BASE_GUI_AIRBASE, pUnit, unit_tile(pUnit));
+      pbase = get_base_by_gui_type(BASE_GUI_AIRBASE, pUnit, pTile);
       if (pbase != NULL) {
-        local_show(ID_UNIT_ORDER_AIRBASE);
+        struct extra_type *base_extra = base_extra_get(pbase);
+
+        time = turns_to_activity_done(pTile, ACTIVITY_BASE, base_extra, pUnit);
+        /* TRANS: "Build Airbase (Shift+E) 5 turns" */
+        fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
+                    extra_name_translation(base_extra), "Shift+E", time,
+                    PL_("turn", "turns", time));
+        copy_chars_to_string16(pOrder_Airbase_Button->info_label, cBuf);
+        clear_wflag(pOrder_Airbase_Button, WF_HIDDEN);
       } else {
-        local_hide(ID_UNIT_ORDER_AIRBASE);
+        set_wflag(pOrder_Airbase_Button, WF_HIDDEN);
       }
 
-      if (can_unit_do_activity(pUnit, ACTIVITY_POLLUTION)) {
-	local_show(ID_UNIT_ORDER_POLLUTION);
+      pextra = prev_extra_in_tile(pTile, ERM_CLEANPOLLUTION,
+                                  unit_owner(pUnit), pUnit);
+      if (pextra != NULL
+          && can_unit_do_activity_targeted(pUnit, ACTIVITY_POLLUTION, pextra)) {
+        time = turns_to_activity_done(pTile, ACTIVITY_POLLUTION, pextra,
+                                      pUnit);
+        /* TRANS: "Clean Pollution (P) 3 turns" */
+        fc_snprintf(cBuf, sizeof(cBuf), _("Clean %s (%s) %d %s"),
+                    extra_name_translation(pextra), "P", time,
+                    PL_("turn", "turns", time));
+        copy_chars_to_string16(pOrder_Pollution_Button->info_label, cBuf);
+        clear_wflag(pOrder_Pollution_Button, WF_HIDDEN);
       } else {
-	local_hide(ID_UNIT_ORDER_POLLUTION);
+        set_wflag(pOrder_Pollution_Button, WF_HIDDEN);
       }
 
       if (can_unit_paradrop(pUnit)) {
@@ -1278,10 +1312,20 @@ void real_menus_update(void)
 	local_hide(ID_UNIT_ORDER_PARADROP);
       }
 
-      if (can_unit_do_activity(pUnit, ACTIVITY_FALLOUT)) {
-	local_show(ID_UNIT_ORDER_FALLOUT);
+      pextra = prev_extra_in_tile(pTile, ERM_CLEANFALLOUT,
+                                  unit_owner(pUnit), pUnit);
+      if (pextra != NULL
+          && can_unit_do_activity_targeted(pUnit, ACTIVITY_FALLOUT, pextra)) {
+        time = turns_to_activity_done(pTile, ACTIVITY_FALLOUT, pextra,
+                                      pUnit);
+        /* TRANS: "Clean Fallout (N) 3 turns" */
+        fc_snprintf(cBuf, sizeof(cBuf), _("Clean %s (%s) %d %s"),
+                    extra_name_translation(pextra), "N", time,
+                    PL_("turn", "turns", time));
+        copy_chars_to_string16(pOrder_Fallout_Button->info_label, cBuf);
+        clear_wflag(pOrder_Fallout_Button, WF_HIDDEN);
       } else {
-	local_hide(ID_UNIT_ORDER_FALLOUT);
+        set_wflag(pOrder_Fallout_Button, WF_HIDDEN);
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_SENTRY)) {
@@ -1328,24 +1372,9 @@ void real_menus_update(void)
       }
 
       if (can_unit_do_autosettlers(pUnit)) {
-	if (unit_has_type_flag(pUnit, UTYF_SETTLERS)) {
-	  if(pOrder_Automate_Unit_Button->theme != current_theme->OAutoSett_Icon) {
-	    fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Settler"), "A");
-	    pOrder_Automate_Unit_Button->theme = current_theme->OAutoSett_Icon;
-            copy_chars_to_string16(pOrder_Automate_Unit_Button->info_label,
-                                   cBuf);
-	  }
-	} else {
-	  if(pOrder_Automate_Unit_Button->theme != current_theme->OAutoAtt_Icon) {
-	    fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Attack"), "A");
-	    pOrder_Automate_Unit_Button->theme = current_theme->OAutoAtt_Icon;
-            copy_chars_to_string16(pOrder_Automate_Unit_Button->info_label,
-                                   cBuf);
-	  }
-	}
-	clear_wflag(pOrder_Automate_Unit_Button, WF_HIDDEN);
+	local_show(ID_UNIT_ORDER_AUTO_SETTLER);
       } else {
-	set_wflag(pOrder_Automate_Unit_Button, WF_HIDDEN);
+	local_hide(ID_UNIT_ORDER_AUTO_SETTLER);
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_EXPLORE)) {
