@@ -64,27 +64,29 @@ static int exit_players_dlg_callback(struct widget *pWidget)
 static int player_callback(struct widget *pWidget)
 {
   struct player *pPlayer = pWidget->data.player;
-  switch(Main.event.button.button) {
+  if (Main.event.type == SDL_MOUSEBUTTONDOWN) {
+    switch (Main.event.button.button) {
 #if 0    
-      case SDL_BUTTON_LEFT:
-      
+    case SDL_BUTTON_LEFT:
+        
       break;
-      case SDL_BUTTON_MIDDLE:
-  
+    case SDL_BUTTON_MIDDLE:
+    
       break;
 #endif    
     case SDL_BUTTON_RIGHT:
       if (can_intel_with_player(pPlayer)) {
-	popdown_players_dialog();
+        popdown_players_dialog();
         popup_intel_dialog(pPlayer);
-	return -1;
+        return -1;
       }
-    break;
+      break;
     default:
       popdown_players_dialog();
       popup_diplomacy_dialog(pPlayer);
       return -1;
-    break;
+      break;
+    }
   }
     
   return -1;
@@ -569,7 +571,8 @@ static int player_nation_callback(struct widget *pWidget)
 {
   struct player *pPlayer = pWidget->data.player;
   popdown_players_nations_dialog();
-  switch(Main.event.button.button) {
+  if (Main.event.type == SDL_MOUSEBUTTONDOWN) {
+    switch (Main.event.button.button) {
 #if 0    
       case SDL_BUTTON_LEFT:
       
@@ -578,18 +581,19 @@ static int player_nation_callback(struct widget *pWidget)
   
       break;
 #endif    
-    case SDL_BUTTON_RIGHT:
-      if (can_intel_with_player(pPlayer)) {
-        popup_intel_dialog(pPlayer);
-      } else {
-	flush_dirty();
-      }
-    break;
-    default:
-      if (pPlayer != client.conn.playing) {
-        popup_diplomacy_dialog(pPlayer);
-      }
-    break;
+      case SDL_BUTTON_RIGHT:
+        if (can_intel_with_player(pPlayer)) {
+          popup_intel_dialog(pPlayer);
+        } else {
+          flush_dirty();
+        }
+      break;
+      default:
+        if (pPlayer != client.conn.playing) {
+          popup_diplomacy_dialog(pPlayer);
+        }
+      break;
+    }
   }
   
   return -1;
