@@ -22,6 +22,7 @@
 /* common */
 #include "game.h"
 #include "packets.h"
+#include "victory.h"
 
 /* client */
 #include "client_main.h"
@@ -100,15 +101,16 @@ void refresh_spaceship_dialog(struct player *pPlayer)
   struct SMALL_DLG *pSpaceShp;
   struct widget *pBuf;
     
-  if(!(pSpaceShp = get_spaceship_dialog(pPlayer)))
+  if (!(pSpaceShp = get_spaceship_dialog(pPlayer))) {
     return;
+  }
   
   /* launch button */
   pBuf = pSpaceShp->pEndWidgetList->prev->prev;
-  if(game.info.spacerace
-     && pPlayer == client.conn.playing
-     && pPlayer->spaceship.state == SSHIP_STARTED
-     && pPlayer->spaceship.success_rate > 0.0) {
+  if (victory_enabled(VC_SPACERACE)
+      && pPlayer == client.conn.playing
+      && pPlayer->spaceship.state == SSHIP_STARTED
+      && pPlayer->spaceship.success_rate > 0.0) {
     set_wstate(pBuf, FC_WS_NORMAL);
   }
   
@@ -155,10 +157,10 @@ void popup_spaceship_dialog(struct player *pPlayer)
     pSpaceShp->pEndWidgetList = pWindow;
 
     area = pWindow->area;
-    
+
     /* ---------- */
     /* create exit button */
-    pBuf = create_themeicon(pTheme->Small_CANCEL_Icon, pWindow->dst,
+    pBuf = create_themeicon(current_theme->Small_CANCEL_Icon, pWindow->dst,
                             WF_WIDGET_HAS_INFO_LABEL
                             | WF_RESTORE_BACKGROUND);
     pBuf->info_label = create_str16_from_char(_("Close Dialog (Esc)"),
@@ -170,10 +172,10 @@ void popup_spaceship_dialog(struct player *pPlayer)
     area.w = MAX(area.w, (pBuf->size.w + adj_size(10)));
   
     add_to_gui_list(ID_BUTTON, pBuf);
-  
-    pBuf = create_themeicon_button_from_chars(pTheme->OK_Icon, pWindow->dst,
-					      _("Launch"), adj_font(12), 0);
-        
+
+    pBuf = create_themeicon_button_from_chars(current_theme->OK_Icon, pWindow->dst,
+                                              _("Launch"), adj_font(12), 0);
+
     pBuf->action = launch_spaceship_callback;
     area.w = MAX(area.w, pBuf->size.w);
     area.h += pBuf->size.h + adj_size(20);
