@@ -947,10 +947,12 @@ static void refresh_production_label(int stock)
   pEditor->pProduction_Name->size.x = pEditor->pEndWidgetList->area.x +
     (adj_size(130) - pEditor->pProduction_Name->size.w) / 2;
 
-  area.x = pEditor->pEndWidgetList->area.x;
+  /* Can't just widget_mark_dirty(), as it may have reduced in size */
+  area.x = pEditor->pEndWidgetList->area.x;  /* left edge of client area */
   area.y = pEditor->pProduction_Name->size.y;
   area.w = adj_size(130);
   area.h = pEditor->pProduction_Name->size.h;
+  layer_rect_to_screen_rect(pEditor->pEndWidgetList->dst, &area);
 
   if (get_wflags(pEditor->pProduction_Name) & WF_RESTORE_BACKGROUND) {
     refresh_widget_background(pEditor->pProduction_Name);
@@ -980,17 +982,15 @@ static void refresh_worklist_count_label(void)
 {
   char cBuf[64];
   SDL_Rect area;
-  int external_entries;
+  int len = worklist_length(&pEditor->worklist_copy);
 
   if (pEditor->pCity != NULL) {
-    external_entries = 1; /* Current production */
-  } else {
-    external_entries = 0;
+    len += 1;  /* External entry from current production */
   }
 
-  /* TRANS: length of worklist */
-  fc_snprintf(cBuf, sizeof(cBuf), _("( %d entries )"),
-              worklist_length(&pEditor->worklist_copy) + external_entries);
+  fc_snprintf(cBuf, sizeof(cBuf),
+              /* TRANS: length of worklist */
+              PL_("( %d entry )", "( %d entries )", len), len);
   copy_chars_to_string16(pEditor->pWorkList_Counter->string16, cBuf);
 
   widget_undraw(pEditor->pWorkList_Counter);
@@ -1005,10 +1005,12 @@ static void refresh_worklist_count_label(void)
   
   widget_redraw(pEditor->pWorkList_Counter);
 
-  area.x = pEditor->pEndWidgetList->area.x;
+  /* Can't just widget_mark_dirty(), as it may have reduced in size */
+  area.x = pEditor->pEndWidgetList->area.x;  /* left edge of client area */
   area.y = pEditor->pWorkList_Counter->size.y;
   area.w = adj_size(130);
   area.h = pEditor->pWorkList_Counter->size.h;
+  layer_rect_to_screen_rect(pEditor->pEndWidgetList->dst, &area);
   sdl_dirty_rect(area);
 }
 
@@ -1018,7 +1020,7 @@ static void refresh_worklist_count_label(void)
 
 /*
  * Global/City worklist editor.
- * if pCity == NULL then fucnction take pWorklist as global worklist.
+ * if pCity == NULL then function takes pWorklist as global worklist.
  * pWorklist must be not NULL.
  */
 void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
@@ -1035,12 +1037,12 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
   SDL_Surface *pIcon;
   SDL_Rect dst;
   char cBuf[128];
-  struct unit_type *pUnit = NULL;
+  struct unit_type *punittype = NULL;
   char *state = NULL;
   bool advanced_tech;
   bool can_build, can_eventually_build;
   SDL_Rect area;
-  int external_entries;
+  int len;
 
   if (pEditor) {
     return;
@@ -1066,6 +1068,7 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
     return;
   }
 
+  len = worklist_length(&pEditor->worklist_copy);
   advanced_tech = (pCity == NULL);
 
   /* --------------- */
@@ -1090,10 +1093,9 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
   /* ---------------- */
   if (pCity) {
     fc_snprintf(cBuf, sizeof(cBuf), _("Worklist of\n%s"), city_name_get(pCity));
-    external_entries = 1; /* Current production */
+    len += 1;  /* External entry from current production */
   } else {
     fc_snprintf(cBuf, sizeof(cBuf), "%s", global_worklist_name(gwl));
-    external_entries = 0;
   }
 
   pStr = create_str16_from_char(cBuf, adj_font(12));
@@ -1104,9 +1106,9 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
   add_to_gui_list(ID_LABEL, pBuf);
   /* --------------------------- */
 
-  /* TRANS: length of worklist */
-  fc_snprintf(cBuf, sizeof(cBuf), _("( %d entries )"),
-              worklist_length(&pEditor->worklist_copy) + external_entries);
+  fc_snprintf(cBuf, sizeof(cBuf),
+              /* TRANS: length of worklist */
+              PL_("( %d entry )", "( %d entries )", len), len);
   pStr = create_str16_from_char(cBuf, adj_font(10));
   pStr->bgcol = (SDL_Color) {0, 0, 0, 0};
   pBuf = create_iconlabel(NULL, pWindow->dst, pStr, WF_RESTORE_BACKGROUND);
@@ -1430,7 +1432,7 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
             } else {
               fc_snprintf(cBuf, sizeof(cBuf), _("%d/%d %s\n%s"),
                           pCity->shield_stock, impr_build_shield_cost(pImprove),
-                          PL_("shield","shields",
+                          PL_("shield", "shields",
                               impr_build_shield_cost(pImprove)), _("never"));
             }
           } else {
@@ -1438,13 +1440,13 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
               fc_snprintf(cBuf, sizeof(cBuf), _("(%s)\n%d/%d %s\n%d %s"),
                           state, pCity->shield_stock,
                           impr_build_shield_cost(pImprove),
-                          PL_("shield","shields",
+                          PL_("shield", "shields",
                               impr_build_shield_cost(pImprove)),
                           turns, PL_("turn", "turns", turns));
             } else {
               fc_snprintf(cBuf, sizeof(cBuf), _("%d/%d %s\n%d %s"),
                           pCity->shield_stock, impr_build_shield_cost(pImprove),
-                          PL_("shield","shields",
+                          PL_("shield", "shields",
                               impr_build_shield_cost(pImprove)),
                           turns, PL_("turn", "turns", turns));
             }
@@ -1463,12 +1465,12 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
           if (state) {
             fc_snprintf(cBuf, sizeof(cBuf), _("(%s)\n%d %s"),
 			state, impr_build_shield_cost(pImprove),
-			PL_("shield","shields",
+			PL_("shield", "shields",
 			    impr_build_shield_cost(pImprove)));
           } else {
 	    fc_snprintf(cBuf, sizeof(cBuf), _("%d %s"),
 			impr_build_shield_cost(pImprove),
-			PL_("shield","shields",
+			PL_("shield", "shields",
 			    impr_build_shield_cost(pImprove)));
           }
         } else {
@@ -1534,11 +1536,11 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
 	  		can_city_build_unit_later(pCity, un);
     }
 
-    if ((advanced_tech && can_eventually_build) ||
-	(!advanced_tech && can_build)) {
-	  
-      pUnit = un;
-	
+    if ((advanced_tech && can_eventually_build)
+        || (!advanced_tech && can_build)) {
+
+      punittype = un;
+
       pIcon = crop_rect_from_surface(pMain, NULL);
       
       fc_snprintf(cBuf, sizeof(cBuf), "%s", utype_name_translation(un));
@@ -1555,29 +1557,29 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
         if (turns == FC_INFINITY) {
           fc_snprintf(cBuf, sizeof(cBuf),
                       _("(%d/%d/%s)\n%d/%d %s\nnever"),
-                      pUnit->attack_strength,
-                      pUnit->defense_strength,
-                      move_points_text(pUnit->move_rate, TRUE),
+                      punittype->attack_strength,
+                      punittype->defense_strength,
+                      move_points_text(punittype->move_rate, TRUE),
                       pCity->shield_stock, utype_build_shield_cost(un),
-                      PL_("shield","shields", utype_build_shield_cost(un)));
+                      PL_("shield", "shields", utype_build_shield_cost(un)));
         } else {
           fc_snprintf(cBuf, sizeof(cBuf),
                       _("(%d/%d/%s)\n%d/%d %s\n%d %s"),
-                      pUnit->attack_strength,
-                      pUnit->defense_strength,
-                      move_points_text(pUnit->move_rate, TRUE),
+                      punittype->attack_strength,
+                      punittype->defense_strength,
+                      move_points_text(punittype->move_rate, TRUE),
                       pCity->shield_stock, utype_build_shield_cost(un), 
-                      PL_("shield","shields", utype_build_shield_cost(un)),
+                      PL_("shield", "shields", utype_build_shield_cost(un)),
                       turns, PL_("turn", "turns", turns));
         }
       } else {
         fc_snprintf(cBuf, sizeof(cBuf),
                     _("(%d/%d/%s)\n%d %s"),
-                    pUnit->attack_strength,
-                    pUnit->defense_strength,
-                    move_points_text(pUnit->move_rate, TRUE),
+                    punittype->attack_strength,
+                    punittype->defense_strength,
+                    move_points_text(punittype->move_rate, TRUE),
                     utype_build_shield_cost(un),
-                    PL_("shield","shields", utype_build_shield_cost(un)));
+                    PL_("shield", "shields", utype_build_shield_cost(un)));
       }
 
       copy_chars_to_string16(pStr, cBuf);
@@ -1736,7 +1738,7 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
   
   /* worklist */
   /* pEditor->pWork->pScroll->count: including production */
-  if (pCity || (worklist_length(&pEditor->worklist_copy) > 0)) {
+  if (len > 0) {
     /* FIXME */
     setup_vertical_widgets_position(1,
       area.x + adj_size(2), area.y + adj_size(152)/* +
