@@ -216,9 +216,12 @@ struct main {
 extern struct main Main;
 
 /* GUI layer */
+/* A gui_layer is a surface with its own origin. Each widget belongs
+ * to a gui_layer. gui_layers are stored in an array Main.guis
+ * (a "window manager"). */
 
 struct gui_layer {
-  SDL_Rect dest_rect;  /* only x and y are used */
+  SDL_Rect dest_rect;  /* origin: only x and y are used */
   SDL_Surface *surface;
 };
 
@@ -231,6 +234,7 @@ struct gui_layer *add_gui_layer(int width, int height);
 void remove_gui_layer(struct gui_layer *gui_layer);
 
 void screen_rect_to_layer_rect(struct gui_layer *gui_layer, SDL_Rect *dest_rect);
+void layer_rect_to_screen_rect(struct gui_layer *gui_layer, SDL_Rect *dest_rect);
 
 /* ---------- */
 
