@@ -462,10 +462,6 @@ static int toggle_map_window_callback(struct widget *pMap_Button)
       pWidget = pWidget->prev;
       widget_redraw(pWidget);
 
-      /* Toggle Minimap mode */
-      pWidget = pWidget->prev;
-      widget_redraw(pWidget);
-
 #ifdef SMALL_SCREEN
       /* options */
       pWidget = pWidget->prev;
@@ -519,24 +515,6 @@ static int toggle_map_window_callback(struct widget *pMap_Button)
 
 /* ====================================================================== */
 
-/**************************************************************************
-  User interacted with minimap toggling button.
-**************************************************************************/
-static int toggle_minimap_mode_callback(struct widget *pWidget)
-{
-  if (PRESSED_EVENT(Main.event)) {
-    if (pWidget != NULL) {
-      selected_widget = pWidget;
-      set_wstate(pWidget, FC_WS_SELECTED);
-    }
-    toggle_overview_mode();
-    refresh_overview();
-    flush_dirty();
-  }
-
-  return -1;
-}
-
 /**************************************************************************
   User interacted with messages toggling button.
 **************************************************************************/
@@ -1435,13 +1413,6 @@ void set_new_minimap_window_pos(void)
                       area.x + adj_size(2),
                       area.y + pWidget->size.h + 2);
 
-  /* Toggle minimap mode */
-  pWidget = pWidget->prev;
-  widget_set_area(pWidget, area);
-  widget_set_position(pWidget,
-                      area.x + adj_size(2),
-                      area.y + pWidget->size.h * 2 + 2);
-
 #ifdef SMALL_SCREEN
   /* ID_TOGGLE_MAP_WINDOW_BUTTON */
   pWidget = pWidget->prev;
@@ -1754,18 +1725,6 @@ void popup_minimap_window(void)
 
   add_to_gui_list(ID_CHATLINE_TOGGLE_LOG_WINDOW_BUTTON, pWidget);
 
-  /* toggle minimap mode button */
-  pWidget = create_themeicon(current_theme->BORDERS_Icon, pMiniMap_Window->dst,
-                             WF_WIDGET_HAS_INFO_LABEL
-                             | WF_RESTORE_BACKGROUND);
-  fc_snprintf(buf, sizeof(buf), "%s (%s)", _("Toggle Mini Map Mode"), "Shift+\\");
-  pWidget->info_label = create_utf8_from_char(buf, adj_font(12));
-  pWidget->action = toggle_minimap_mode_callback;
-  pWidget->key = SDLK_BACKSLASH;
-  pWidget->mod = KMOD_SHIFT;
-
-  add_to_gui_list(ID_TOGGLE_MINIMAP_MODE, pWidget);
-
 #ifdef SMALL_SCREEN
   /* options button */
   pOptions_Button = create_themeicon(current_theme->Options_Icon,
@@ -1836,10 +1795,6 @@ void show_minimap_window_buttons(void)
   pWidget = pWidget->prev;
   clear_wflag(pWidget, WF_HIDDEN);
 
-  /* toggle minimap mode button */
-  pWidget = pWidget->prev;
-  clear_wflag(pWidget, WF_HIDDEN);
-
 #ifdef SMALL_SCREEN
   /* options button */
   pWidget = pWidget->prev;
@@ -1878,10 +1833,6 @@ void hide_minimap_window_buttons(void)
   pWidget = pWidget->prev;
   set_wflag(pWidget, WF_HIDDEN);
 
-  /* toggle minimap mode button */
-  pWidget = pWidget->prev;
-  set_wflag(pWidget, WF_HIDDEN);
-
 #ifdef SMALL_SCREEN
   /* options button */
   pWidget = pWidget->prev;
@@ -1919,10 +1870,6 @@ void redraw_minimap_window_buttons(void)
   pWidget = pWidget->prev;
   widget_redraw(pWidget);
 
-  /* toggle minimap mode button */
-  pWidget = pWidget->prev;
-  widget_redraw(pWidget);
-
 #ifdef SMALL_SCREEN
   /* options button */
   pWidget = pWidget->prev;
@@ -2097,10 +2044,6 @@ static void disable_minimap_widgets(void)
   pBuf = pBuf->prev;
   set_wstate(pBuf, FC_WS_DISABLED);
 
-  /* toggle minimap mode button */
-  pBuf = pBuf->prev;
-  set_wstate(pBuf, FC_WS_DISABLED);
-
 #ifdef SMALL_SCREEN
   /* options button */
   pBuf = pBuf->prev;
@@ -2175,10 +2118,6 @@ static void enable_minimap_widgets(void)
     pBuf = pBuf->prev;
     set_wstate(pBuf, FC_WS_NORMAL);
 
-    /* toggle minimap mode button */
-    pBuf = pBuf->prev;
-    set_wstate(pBuf, FC_WS_NORMAL);
-
 #ifdef SMALL_SCREEN
     /* options button */
     pBuf = pBuf->prev;
@@ -2698,13 +2637,6 @@ bool map_event_handler(SDL_Keysym key)
         }
         return FALSE;
 
-        /* toggle minimap mode - currently without effect */
-      case SDLK_BACKSLASH:
-        if (LSHIFT || RSHIFT) {
-          toggle_minimap_mode_callback(NULL);
-        }
-        return FALSE;
-
       default:
         break;
       }
