@@ -35,6 +35,7 @@
 #include "log.h"
 
 /* common */
+#include "clientutils.h"
 #include "game.h"
 #include "road.h"
 #include "traderoutes.h"
@@ -65,7 +66,10 @@ extern struct widget *pOptions_Button;
 static struct widget *pBeginOrderWidgetList;
 static struct widget *pEndOrderWidgetList;
 
-static struct widget *pOrder_Automate_Unit_Button;
+static struct widget *pOrder_Fallout_Button;
+static struct widget *pOrder_Pollution_Button;
+static struct widget *pOrder_Airbase_Button;
+static struct widget *pOrder_Fortress_Button;
 static struct widget *pOrder_Build_AddTo_City_Button;
 static struct widget *pOrder_Mine_Button;
 static struct widget *pOrder_Irrigation_Button;
@@ -613,7 +617,7 @@ void create_units_order_widgets(void)
   add_to_gui_list(ID_UNIT_ORDER_AUTO_EXPLORE, pBuf);
   /* --------- */
 
-  /* Auto-Attack / Auto-Settler */
+  /* Auto-Settler */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Settler"), "A");
 
   pBuf = create_themeicon(current_theme->OAutoSett_Icon, Main.gui,
@@ -624,8 +628,6 @@ void create_units_order_widgets(void)
   pBuf->info_label = create_utf8_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_a;
   add_to_gui_list(ID_UNIT_ORDER_AUTO_SETTLER, pBuf);
-
-  pOrder_Automate_Unit_Button = pBuf;
   /* --------- */    
 
   /* Wake Up Others */
@@ -716,7 +718,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Clean Nuclear Fallout */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Clean Nuclear Fallout"), "N");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OFallout_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -724,6 +727,7 @@ void create_units_order_widgets(void)
   pBuf->action = unit_order_callback;
   pBuf->info_label = create_utf8_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_n;
+  pOrder_Fallout_Button = pBuf;
   add_to_gui_list(ID_UNIT_ORDER_FALLOUT, pBuf);
   /* --------- */
 
@@ -740,7 +744,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Clean Pollution */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Clean Pollution"), "P");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OPollution_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -748,11 +753,13 @@ void create_units_order_widgets(void)
   pBuf->action = unit_order_callback;
   pBuf->info_label = create_utf8_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_p;
+  pOrder_Pollution_Button = pBuf;
   add_to_gui_list(ID_UNIT_ORDER_POLLUTION, pBuf);
   /* --------- */
 
   /* Build Airbase */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Airbase"), "Shift+E");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OAirBase_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -760,6 +767,8 @@ void create_units_order_widgets(void)
   pBuf->action = unit_order_callback;
   pBuf->info_label = create_utf8_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_e;
+  pBuf->mod = KMOD_SHIFT;
+  pOrder_Airbase_Button = pBuf;
   add_to_gui_list(ID_UNIT_ORDER_AIRBASE, pBuf);
   /* --------- */
 
@@ -776,7 +785,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Build Fortress */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Fortress"), "Shift+F");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OFortress_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -784,11 +794,14 @@ void create_units_order_widgets(void)
   pBuf->action = unit_order_callback;
   pBuf->info_label = create_utf8_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_f;
+  pBuf->mod = KMOD_SHIFT;
+  pOrder_Fortress_Button = pBuf;
   add_to_gui_list(ID_UNIT_ORDER_FORTRESS, pBuf);
   /* --------- */
 
   /* Transform Tile */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Transform Tile"), "O");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OTransform_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -801,7 +814,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Build Mine */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Mine"), "M");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OMine_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -815,7 +829,8 @@ void create_units_order_widgets(void)
   /* --------- */    
 
   /* Build Irrigation */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Irrigation"), "I");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OIrrigation_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -829,8 +844,8 @@ void create_units_order_widgets(void)
   /* --------- */    
 
   /* Establish Trade route */
-  fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)",
-              action_id_name_translation(ACTION_TRADE_ROUTE), "R");
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OTrade_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -844,20 +859,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Build (Rail-)Road */
-  /* TRANS: "Build Road (R) 999 turns" */
-  if (proad != NULL) {
-    fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
-                extra_name_translation(road_extra_get(proad)), "R", 999,
-                PL_("turn", "turns", 999));
-  } else if (prail != NULL) {
-    /* TRANS: "Build Railroad (R) 999 turns" */
-    fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
-                extra_name_translation(road_extra_get(prail)), "R", 999,
-                PL_("turn", "turns", 999));
-  } else {
-    cBuf[0] = '\0';
-  }
-
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->ORoad_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -884,9 +887,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Add to City / Build New City */
-  fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)", _("Add to City"), "B");
-  fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)", _("Build City"), "B");
-
+  /* Label will be replaced by real_menus_update() before it's seen */
+  fc_snprintf(cBuf, sizeof(cBuf), "placeholder");
   pBuf = create_themeicon(current_theme->OBuildCity_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
@@ -1059,8 +1061,7 @@ void real_menus_update(void)
       struct city *pCity = tile_city(pTile);
       struct terrain *pTerrain = tile_terrain(pTile);
       struct base_type *pbase;
-      struct extra_type *pextra = next_extra_for_tile(pTile, EC_ROAD,
-                                                      unit_owner(pUnit), pUnit);
+      struct extra_type *pextra;
 
       if (!counter) {
 	local_show(ID_UNIT_ORDER_GOTO);
@@ -1092,11 +1093,14 @@ void real_menus_update(void)
 	local_hide(ID_UNIT_ORDER_BUILD_WONDER);
       }
 
-      if (pextra != NULL) {
+      pextra = next_extra_for_tile(pTile, EC_ROAD,
+                                   unit_owner(pUnit), pUnit);
+      if (pextra != NULL
+          && can_unit_do_activity_targeted(pUnit, ACTIVITY_GEN_ROAD, pextra)) {
         struct road_type *proad = extra_road_get(pextra);
         enum road_compat compat = road_compat_special(proad);
 
-        time = tile_activity_time(ACTIVITY_GEN_ROAD, pTile, road_extra_get(proad));
+        time = turns_to_activity_done(pTile, ACTIVITY_GEN_ROAD, pextra, pUnit);
 
         /* TRANS: "Build Railroad (R) 3 turns" */
 	fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
@@ -1145,28 +1149,40 @@ void real_menus_update(void)
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_IRRIGATE)) {
-        time = tile_activity_time(ACTIVITY_IRRIGATE, unit_tile(pUnit), NULL);
+        if (is_build_activity(ACTIVITY_IRRIGATE, pTile)) {
+          /* Activity results in extra */
+          struct extra_type *irrig_extra = next_extra_for_tile(pTile, EC_IRRIGATION,
+                                                               unit_owner(pUnit),
+                                                               pUnit);
 
-        if (!strcmp(terrain_rule_name(pTerrain), "Forest")
-            || !strcmp(terrain_rule_name(pTerrain), "Jungle")) {
-          /* set Crop Forest Icon */
-          fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
-                      _("Cut Down to"),
-                      terrain_name_translation(pTerrain->irrigation_result),
-                      "I", time , PL_("turn", "turns", time));
-          pOrder_Irrigation_Button->theme = current_theme->OCutDownForest_Icon;
-        } else if (!strcmp(terrain_rule_name(pTerrain), "Swamp")) {
-          fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
-                      _("Irrigate to"),
-                      terrain_name_translation(pTerrain->irrigation_result),
-                      "I", time , PL_("turn", "turns", time));
-          pOrder_Irrigation_Button->theme = current_theme->OIrrigation_Icon;
-        } else {
-          /* set Irrigation Icon */
-          fc_snprintf(cBuf, sizeof(cBuf),"%s (%s) %d %s",
-                      _("Build Irrigation"), "I", time , 
+          time = turns_to_activity_done(pTile, ACTIVITY_IRRIGATE,
+                                        irrig_extra, pUnit);
+          /* TRANS: "Build Irrigation (I) 5 turns" */
+          fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
+                      extra_name_translation(irrig_extra), "I", time,
                       PL_("turn", "turns", time));
           pOrder_Irrigation_Button->theme = current_theme->OIrrigation_Icon;
+        } else {
+          /* Activity results in terrain change */
+          time = turns_to_activity_done(pTile, ACTIVITY_IRRIGATE,
+                                        NULL, pUnit);
+
+          /* FIXME: get rid of this ruleset-specific hardcoding */
+          if (!strcmp(terrain_rule_name(pTerrain), "Forest")
+              || !strcmp(terrain_rule_name(pTerrain), "Jungle")) {
+            /* set Crop Forest Icon */
+            fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
+                        _("Cut Down to"),
+                        terrain_name_translation(pTerrain->irrigation_result),
+                        "I", time , PL_("turn", "turns", time));
+            pOrder_Irrigation_Button->theme = current_theme->OCutDownForest_Icon;
+          } else {
+            /* TRANS: "Change to Grassland (I) 10 turns" */
+            fc_snprintf(cBuf, sizeof(cBuf), _("Change to %s (%s) %d %s"),
+                        terrain_name_translation(pTerrain->irrigation_result),
+                        "I", time , PL_("turn", "turns", time));
+            pOrder_Irrigation_Button->theme = current_theme->OIrrigation_Icon;
+          }
         }
 
         copy_chars_to_utf8_str(pOrder_Irrigation_Button->info_label, cBuf);
@@ -1176,32 +1192,41 @@ void real_menus_update(void)
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_MINE)) {
-        time = tile_activity_time(ACTIVITY_MINE, unit_tile(pUnit), NULL);
+        if (is_build_activity(ACTIVITY_MINE, pTile)) {
+          /* Activity results in extra */
+          struct extra_type *mine_extra = next_extra_for_tile(pTile, EC_MINE,
+                                                              unit_owner(pUnit),
+                                                              pUnit);
 
-        /* FIXME: THIS CODE IS WRONG */
-        if (!strcmp(terrain_rule_name(pTerrain), "Forest")) {
-	  /* set Irrigate Icon -> make swamp */
-          fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
-                      _("Irrigate to"),
-                      terrain_name_translation(pTerrain->mining_result),
-                      "M", time , PL_("turn", "turns", time));
-          pOrder_Mine_Button->theme = current_theme->OIrrigation_Icon;
-        } else if (!strcmp(terrain_rule_name(pTerrain), "Jungle")
-                   || !strcmp(terrain_rule_name(pTerrain), "Plains")
-                   || !strcmp(terrain_rule_name(pTerrain), "Grassland")
-                   || !strcmp(terrain_rule_name(pTerrain), "Swamp")) {
-          /* set Forest Icon -> plant Forrest*/
-          fc_snprintf(cBuf, sizeof(cBuf),"%s (%s) %d %s",
-                      _("Plant Forest"), "M", time,
-                      PL_("turn", "turns", time));
-          pOrder_Mine_Button->theme = current_theme->OPlantForest_Icon;
-
-        } else {
-          /* set Mining Icon */
-          fc_snprintf(cBuf, sizeof(cBuf),"%s (%s) %d %s",
-                      _("Build Mine"), "M", time,
+          time = turns_to_activity_done(pTile, ACTIVITY_MINE, mine_extra, pUnit);
+          /* TRANS: "Build Mine (M) 5 turns" */
+          fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
+                      extra_name_translation(mine_extra), "M", time,
                       PL_("turn", "turns", time));
           pOrder_Mine_Button->theme = current_theme->OMine_Icon;
+        } else {
+          /* Activity results in terrain change */
+          time = turns_to_activity_done(pTile, ACTIVITY_MINE, NULL, pUnit);
+
+          /* FIXME: get rid of this ruleset-specific hardcoding */
+          if (!strcmp(terrain_rule_name(pTerrain->mining_result), "Forest")) {
+            /* set Forest Icon -> plant Forest */
+            fc_snprintf(cBuf, sizeof(cBuf), "%s (%s) %d %s",
+                        _("Plant Forest"), "M", time,
+                        PL_("turn", "turns", time));
+            pOrder_Mine_Button->theme = current_theme->OPlantForest_Icon;
+          } else {
+            /* TRANS: "Change to Swamp (M) 10 turns" */
+            fc_snprintf(cBuf, sizeof(cBuf), _("Change to %s (%s) %d %s"),
+                        terrain_name_translation(pTerrain->mining_result),
+                        "M", time , PL_("turn", "turns", time));
+            if (!strcmp(terrain_rule_name(pTerrain->mining_result), "Swamp")) {
+              /* set Irrigate Icon -> make swamp */
+              pOrder_Mine_Button->theme = current_theme->OIrrigation_Icon;
+            } else {
+              pOrder_Mine_Button->theme = current_theme->OPlantForest_Icon;
+            }
+          }
         }
 
         copy_chars_to_utf8_str(pOrder_Mine_Button->info_label, cBuf);
@@ -1211,7 +1236,8 @@ void real_menus_update(void)
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_TRANSFORM)) {
-        time = tile_activity_time(ACTIVITY_TRANSFORM, unit_tile(pUnit), NULL);
+        /* Activity always results in terrain change */
+        time = turns_to_activity_done(pTile, ACTIVITY_TRANSFORM, NULL, pUnit);
         fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
                     _("Transform to"),
                     terrain_name_translation(pTerrain->transform_result),
@@ -1222,11 +1248,19 @@ void real_menus_update(void)
         set_wflag(pOrder_Transform_Button, WF_HIDDEN);
       }
 
-      pbase = get_base_by_gui_type(BASE_GUI_FORTRESS, pUnit, unit_tile(pUnit));
+      pbase = get_base_by_gui_type(BASE_GUI_FORTRESS, pUnit, pTile);
       if (pbase != NULL) {
-        local_show(ID_UNIT_ORDER_FORTRESS);
+        struct extra_type *base_extra = base_extra_get(pbase);
+
+        time = turns_to_activity_done(pTile, ACTIVITY_BASE, base_extra, pUnit);
+        /* TRANS: "Build Fortress (Shift+F) 5 turns" */
+        fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
+                    extra_name_translation(base_extra), "Shift+F", time,
+                    PL_("turn", "turns", time));
+        copy_chars_to_utf8_str(pOrder_Fortress_Button->info_label, cBuf);
+        clear_wflag(pOrder_Fortress_Button, WF_HIDDEN);
       } else {
-        local_hide(ID_UNIT_ORDER_FORTRESS);
+        set_wflag(pOrder_Fortress_Button, WF_HIDDEN);
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_FORTIFYING)) {
@@ -1235,17 +1269,35 @@ void real_menus_update(void)
         local_hide(ID_UNIT_ORDER_FORTIFY);
       }
 
-      pbase = get_base_by_gui_type(BASE_GUI_AIRBASE, pUnit, unit_tile(pUnit));
+      pbase = get_base_by_gui_type(BASE_GUI_AIRBASE, pUnit, pTile);
       if (pbase != NULL) {
-        local_show(ID_UNIT_ORDER_AIRBASE);
+        struct extra_type *base_extra = base_extra_get(pbase);
+
+        time = turns_to_activity_done(pTile, ACTIVITY_BASE, base_extra, pUnit);
+        /* TRANS: "Build Airbase (Shift+E) 5 turns" */
+        fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
+                    extra_name_translation(base_extra), "Shift+E", time,
+                    PL_("turn", "turns", time));
+        copy_chars_to_utf8_str(pOrder_Airbase_Button->info_label, cBuf);
+        clear_wflag(pOrder_Airbase_Button, WF_HIDDEN);
       } else {
-        local_hide(ID_UNIT_ORDER_AIRBASE);
+        set_wflag(pOrder_Airbase_Button, WF_HIDDEN);
       }
 
-      if (can_unit_do_activity(pUnit, ACTIVITY_POLLUTION)) {
-        local_show(ID_UNIT_ORDER_POLLUTION);
+      pextra = prev_extra_in_tile(pTile, ERM_CLEANPOLLUTION,
+                                  unit_owner(pUnit), pUnit);
+      if (pextra != NULL
+          && can_unit_do_activity_targeted(pUnit, ACTIVITY_POLLUTION, pextra)) {
+        time = turns_to_activity_done(pTile, ACTIVITY_POLLUTION, pextra,
+                                      pUnit);
+        /* TRANS: "Clean Pollution (P) 3 turns" */
+        fc_snprintf(cBuf, sizeof(cBuf), _("Clean %s (%s) %d %s"),
+                    extra_name_translation(pextra), "P", time,
+                    PL_("turn", "turns", time));
+        copy_chars_to_utf8_str(pOrder_Pollution_Button->info_label, cBuf);
+        clear_wflag(pOrder_Pollution_Button, WF_HIDDEN);
       } else {
-        local_hide(ID_UNIT_ORDER_POLLUTION);
+        set_wflag(pOrder_Pollution_Button, WF_HIDDEN);
       }
 
       if (can_unit_paradrop(pUnit)) {
@@ -1254,10 +1306,20 @@ void real_menus_update(void)
         local_hide(ID_UNIT_ORDER_PARADROP);
       }
 
-      if (can_unit_do_activity(pUnit, ACTIVITY_FALLOUT)) {
-        local_show(ID_UNIT_ORDER_FALLOUT);
+      pextra = prev_extra_in_tile(pTile, ERM_CLEANFALLOUT,
+                                  unit_owner(pUnit), pUnit);
+      if (pextra != NULL
+          && can_unit_do_activity_targeted(pUnit, ACTIVITY_FALLOUT, pextra)) {
+        time = turns_to_activity_done(pTile, ACTIVITY_FALLOUT, pextra,
+                                      pUnit);
+        /* TRANS: "Clean Fallout (N) 3 turns" */
+        fc_snprintf(cBuf, sizeof(cBuf), _("Clean %s (%s) %d %s"),
+                    extra_name_translation(pextra), "N", time,
+                    PL_("turn", "turns", time));
+        copy_chars_to_utf8_str(pOrder_Fallout_Button->info_label, cBuf);
+        clear_wflag(pOrder_Fallout_Button, WF_HIDDEN);
       } else {
-        local_hide(ID_UNIT_ORDER_FALLOUT);
+        set_wflag(pOrder_Fallout_Button, WF_HIDDEN);
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_SENTRY)) {
@@ -1304,24 +1366,9 @@ void real_menus_update(void)
       }
 
       if (can_unit_do_autosettlers(pUnit)) {
-        if (unit_has_type_flag(pUnit, UTYF_SETTLERS)) {
-          if(pOrder_Automate_Unit_Button->theme != current_theme->OAutoSett_Icon) {
-            fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Settler"), "A");
-            pOrder_Automate_Unit_Button->theme = current_theme->OAutoSett_Icon;
-            copy_chars_to_utf8_str(pOrder_Automate_Unit_Button->info_label,
-                                   cBuf);
-          }
-        } else {
-          if (pOrder_Automate_Unit_Button->theme != current_theme->OAutoAtt_Icon) {
-            fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Attack"), "A");
-            pOrder_Automate_Unit_Button->theme = current_theme->OAutoAtt_Icon;
-            copy_chars_to_utf8_str(pOrder_Automate_Unit_Button->info_label,
-                                   cBuf);
-          }
-        }
-        clear_wflag(pOrder_Automate_Unit_Button, WF_HIDDEN);
+        local_show(ID_UNIT_ORDER_AUTO_SETTLER);
       } else {
-        set_wflag(pOrder_Automate_Unit_Button, WF_HIDDEN);
+        local_hide(ID_UNIT_ORDER_AUTO_SETTLER);
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_EXPLORE)) {
