@@ -969,10 +969,12 @@ static void refresh_production_label(int stock)
   pEditor->pProduction_Name->size.x = pEditor->pEndWidgetList->area.x +
     (adj_size(130) - pEditor->pProduction_Name->size.w)/2;
 
-  area.x = pEditor->pEndWidgetList->area.x;
+  /* Can't just widget_mark_dirty(), as it may have reduced in size */
+  area.x = pEditor->pEndWidgetList->area.x;  /* left edge of client area */
   area.y = pEditor->pProduction_Name->size.y;
   area.w = adj_size(130);
   area.h = pEditor->pProduction_Name->size.h;
+  layer_rect_to_screen_rect(pEditor->pEndWidgetList->dst, &area);
 
   if (get_wflags(pEditor->pProduction_Name) & WF_RESTORE_BACKGROUND) {
     refresh_widget_background(pEditor->pProduction_Name);
@@ -1002,17 +1004,15 @@ static void refresh_worklist_count_label(void)
 {
   char cBuf[64];
   SDL_Rect area;
-  int external_entries;
+  int len = worklist_length(&pEditor->worklist_copy);
 
   if (pEditor->pCity != NULL) {
-    external_entries = 1; /* Current production */
-  } else {
-    external_entries = 0;
+    len += 1;  /* External entry from current production */
   }
 
-  /* TRANS: length of worklist */
-  fc_snprintf(cBuf, sizeof(cBuf), _("( %d entries )"),
-              worklist_length(&pEditor->worklist_copy) + external_entries);
+  fc_snprintf(cBuf, sizeof(cBuf),
+              /* TRANS: length of worklist */
+              PL_("( %d entry )", "( %d entries )", len), len);
   copy_chars_to_utf8_str(pEditor->pWorkList_Counter->string_utf8, cBuf);
 
   widget_undraw(pEditor->pWorkList_Counter);
@@ -1027,10 +1027,12 @@ static void refresh_worklist_count_label(void)
 
   widget_redraw(pEditor->pWorkList_Counter);
 
-  area.x = pEditor->pEndWidgetList->area.x;
+  /* Can't just widget_mark_dirty(), as it may have reduced in size */
+  area.x = pEditor->pEndWidgetList->area.x;  /* left edge of client area */
   area.y = pEditor->pWorkList_Counter->size.y;
   area.w = adj_size(130);
   area.h = pEditor->pWorkList_Counter->size.h;
+  layer_rect_to_screen_rect(pEditor->pEndWidgetList->dst, &area);
   dirty_sdl_rect(&area);
 }
 
@@ -1038,7 +1040,7 @@ static void refresh_worklist_count_label(void)
 
 /**************************************************************************
   Global/City worklist editor.
-  if pCity == NULL then fucnction take pWorklist as global worklist.
+  if pCity == NULL then function takes pWorklist as global worklist.
   pWorklist must be not NULL.
 **************************************************************************/
 void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
@@ -1054,12 +1056,12 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
   SDL_Surface *pIcon;
   SDL_Rect dst;
   char cbuf[128];
-  struct unit_type *pUnit = NULL;
+  struct unit_type *punittype = NULL;
   char *state = NULL;
   bool advanced_tech;
   bool can_build, can_eventually_build;
   SDL_Rect area;
-  int external_entries;
+  int len;
 
   if (pEditor) {
     return;
@@ -1085,6 +1087,7 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
     return;
   }
 
+  len = worklist_length(&pEditor->worklist_copy);
   advanced_tech = (pCity == NULL);
 
   /* --------------- */
@@ -1110,10 +1113,9 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
   /* ---------------- */
   if (pCity) {
     fc_snprintf(cbuf, sizeof(cbuf), _("Worklist of\n%s"), city_name_get(pCity));
-    external_entries = 1; /* Current production */
+    len += 1;  /* External entry from current production */
   } else {
     fc_snprintf(cbuf, sizeof(cbuf), "%s", global_worklist_name(gwl));
-    external_entries = 0;
   }
 
   pstr = create_utf8_from_char(cbuf, adj_font(12));
@@ -1124,9 +1126,9 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
   add_to_gui_list(ID_LABEL, pBuf);
   /* --------------------------- */
 
-  /* TRANS: length of worklist */
-  fc_snprintf(cbuf, sizeof(cbuf), _("( %d entries )"),
-              worklist_length(&pEditor->worklist_copy) + external_entries);
+  fc_snprintf(cbuf, sizeof(cbuf),
+              /* TRANS: length of worklist */
+              PL_("( %d entry )", "( %d entries )", len), len);
   pstr = create_utf8_from_char(cbuf, adj_font(10));
   pstr->bgcol = (SDL_Color) {0, 0, 0, 0};
   pBuf = create_iconlabel(NULL, pWindow->dst, pstr, WF_RESTORE_BACKGROUND);
@@ -1455,7 +1457,7 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
             } else {
               fc_snprintf(cbuf, sizeof(cbuf), _("%d/%d %s\n%s"),
                           pCity->shield_stock, impr_build_shield_cost(pImprove),
-                          PL_("shield","shields",
+                          PL_("shield", "shields",
                               impr_build_shield_cost(pImprove)), _("never"));
             }	  
           } else {
@@ -1463,13 +1465,13 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
               fc_snprintf(cbuf, sizeof(cbuf), _("(%s)\n%d/%d %s\n%d %s"),
                           state, pCity->shield_stock,
                           impr_build_shield_cost(pImprove),
-                          PL_("shield","shields",
+                          PL_("shield", "shields",
                               impr_build_shield_cost(pImprove)),
                           turns, PL_("turn", "turns", turns));
             } else {
               fc_snprintf(cbuf, sizeof(cbuf), _("%d/%d %s\n%d %s"),
                           pCity->shield_stock, impr_build_shield_cost(pImprove),
-                          PL_("shield","shields",
+                          PL_("shield", "shields",
                               impr_build_shield_cost(pImprove)),
                           turns, PL_("turn", "turns", turns));
             }
@@ -1488,12 +1490,12 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
           if (state) {
             fc_snprintf(cbuf, sizeof(cbuf), _("(%s)\n%d %s"),
                         state, impr_build_shield_cost(pImprove),
-                        PL_("shield","shields",
+                        PL_("shield", "shields",
                             impr_build_shield_cost(pImprove)));
           } else {
             fc_snprintf(cbuf, sizeof(cbuf), _("%d %s"),
                         impr_build_shield_cost(pImprove),
-                        PL_("shield","shields",
+                        PL_("shield", "shields",
                             impr_build_shield_cost(pImprove)));
           }
         } else {
@@ -1563,7 +1565,7 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
     if ((advanced_tech && can_eventually_build)
         || (!advanced_tech && can_build)) {
 
-      pUnit = un;
+      punittype = un;
 
       pIcon = crop_rect_from_surface(pMain, NULL);
 
@@ -1581,29 +1583,29 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
         if (turns == FC_INFINITY) {
           fc_snprintf(cbuf, sizeof(cbuf),
                       _("(%d/%d/%s)\n%d/%d %s\nnever"),
-                      pUnit->attack_strength,
-                      pUnit->defense_strength,
-                      move_points_text(pUnit->move_rate, TRUE),
+                      punittype->attack_strength,
+                      punittype->defense_strength,
+                      move_points_text(punittype->move_rate, TRUE),
                       pCity->shield_stock, utype_build_shield_cost(un),
-                      PL_("shield","shields", utype_build_shield_cost(un)));
+                      PL_("shield", "shields", utype_build_shield_cost(un)));
         } else {
           fc_snprintf(cbuf, sizeof(cbuf),
                       _("(%d/%d/%s)\n%d/%d %s\n%d %s"),
-                      pUnit->attack_strength,
-                      pUnit->defense_strength,
-                      move_points_text(pUnit->move_rate, TRUE),
+                      punittype->attack_strength,
+                      punittype->defense_strength,
+                      move_points_text(punittype->move_rate, TRUE),
                       pCity->shield_stock, utype_build_shield_cost(un), 
-                      PL_("shield","shields", utype_build_shield_cost(un)),
+                      PL_("shield", "shields", utype_build_shield_cost(un)),
                       turns, PL_("turn", "turns", turns));
         }
       } else {
         fc_snprintf(cbuf, sizeof(cbuf),
                     _("(%d/%d/%s)\n%d %s"),
-                    pUnit->attack_strength,
-                    pUnit->defense_strength,
-                    move_points_text(pUnit->move_rate, TRUE),
+                    punittype->attack_strength,
+                    punittype->defense_strength,
+                    move_points_text(punittype->move_rate, TRUE),
                     utype_build_shield_cost(un),
-                    PL_("shield","shields", utype_build_shield_cost(un)));
+                    PL_("shield", "shields", utype_build_shield_cost(un)));
       }
 
       copy_chars_to_utf8_str(pstr, cbuf);
@@ -1765,7 +1767,7 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl)
 
   /* worklist */
   /* pEditor->pWork->pScroll->count: including production */
-  if (pCity || (worklist_length(&pEditor->worklist_copy) > 0)) {
+  if (len > 0) {
     /* FIXME */
     setup_vertical_widgets_position(1,
                                     area.x + adj_size(2), area.y + adj_size(152)
