@@ -785,7 +785,7 @@ void unit_select_dialog_popup(struct tile *ptile)
 /**************************************************************************
   Update the dialog window to select units on a particular tile.
 **************************************************************************/
-void unit_select_dialog_update_real(void)
+void unit_select_dialog_update_real(void *unused)
 {
   /* PORTME */
 }
