@@ -547,7 +547,7 @@ void ui_main(int argc, char *argv[])
 /**************************************************************************
   Do any necessary UI-specific cleanup
 **************************************************************************/
-void ui_exit()
+void ui_exit(void)
 {
 }
 
@@ -1148,11 +1148,3 @@ void insert_client_build_info(char *outbuf, size_t outlen)
 {
   /* PORTME */
 }
-
-/**************************************************************************
-  Make dynamic adjustments to first-launch default options.
-**************************************************************************/
-void adjust_default_options(void)
-{
-  /* Nothing in case of this gui */
-}
