@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -176,6 +176,7 @@ void create_intel_dialog(struct intel_dialog *pdialog, bool raise)
 {
   char buf[4 * MAX_LEN_NAME], plr_buf[4 * MAX_LEN_NAME];
   struct city *pcity;
+  const struct research *presearch = research_get(pdialog->pplayer);
 
   static char *tech_list_names_ptrs[A_LAST+1];
   static char tech_list_names[A_LAST+1][200];
@@ -253,19 +254,20 @@ void create_intel_dialog(struct intel_dialog *pdialog, bool raise)
 			  XtNlabel, buf,
 			  NULL);
 
-  switch (player_research_get(pdialog->pplayer)->researching) {
+  switch (presearch->researching) {
   case A_UNKNOWN:
     fc_snprintf(buf, sizeof(buf), _("Researching: (Unknown)"));
     break;
   case A_UNSET:
     fc_snprintf(buf, sizeof(buf), _("Researching: Unknown(%d/-)"),
-		player_research_get(pdialog->pplayer)->bulbs_researched);
+                presearch->bulbs_researched);
     break;
   default:
     fc_snprintf(buf, sizeof(buf), _("Researching: %s(%d/%d)"),
-		advance_name_researching(pdialog->pplayer),
-		player_research_get(pdialog->pplayer)->bulbs_researched,
-                player_research_get(pdialog->pplayer)->client.researching_cost);
+                research_advance_name_translation(presearch,
+                                                  presearch->researching),
+                presearch->bulbs_researched,
+                presearch->client.researching_cost);
     break;
   };
 
@@ -277,17 +279,19 @@ void create_intel_dialog(struct intel_dialog *pdialog, bool raise)
 
   pcity = player_capital(pdialog->pplayer);
   fc_snprintf(buf, sizeof(buf), _("Capital: %s"),
-	      /* TRANS: "unknown" location */
-	      (!pcity) ? _("(unknown)") : city_name(pcity));
+              /* TRANS: "unknown" location */
+              (!pcity) ? _("(unknown)") : city_name_get(pcity));
   XtVaCreateManagedWidget("intelcapitallabel",
-			  labelWidgetClass,
-			  pdialog->intel_form,
-			  XtNlabel, buf,
-			  NULL);
+                          labelWidgetClass,
+                          pdialog->intel_form,
+                          XtNlabel, buf,
+                          NULL);
 
   advance_index_iterate(A_FIRST, i) {
-    if (player_invention_state(pdialog->pplayer, i) == TECH_KNOWN) {
-      if (TECH_KNOWN == player_invention_state(client.conn.playing, i)) {
+    if (research_invention_state(presearch, i)
+        == TECH_KNOWN) {
+      if (research_invention_state(research_get(client_player()), i)
+          == TECH_KNOWN) {
 	sz_strlcpy(tech_list_names[j], advance_name_translation(advance_by_number(i)));
       } else {
 	fc_snprintf(tech_list_names[j], sizeof(tech_list_names[j]),
@@ -503,7 +507,7 @@ void update_intel_diplo_dialog(struct intel_dialog *pdialog)
 		  "%-32s %-16s %-16s",
 		  player_name(other),
 		  nation_adjective_for_player(other),
-		  diplstate_text(state->type));
+		  diplstate_type_translated_name(state->type));
       namelist_ptrs[i] = namelist_text[i];
       i++;
     } players_iterate_end;
