@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -75,12 +75,13 @@
 #define TEXT_ORDER_CITY_BUILD   0
 #define TEXT_ORDER_CITY_ADD_TO  1
 
-#define TEXT_ORDER_IRRIGATE_IRRIGATE   0
-#define TEXT_ORDER_IRRIGATE_FARMLAND   1
+#define TEXT_ORDER_IRRIGATE            0
+#define TEXT_ORDER_IRRIGATE_GENERIC    1
 #define TEXT_ORDER_IRRIGATE_CHANGE_TO  2
 
-#define TEXT_ORDER_MINE_MINE       0
-#define TEXT_ORDER_MINE_CHANGE_TO  1
+#define TEXT_ORDER_MINE            0
+#define TEXT_ORDER_MINE_GENERIC    1
+#define TEXT_ORDER_MINE_CHANGE_TO  2
 
 #define TEXT_ORDER_TRANSFORM_TERRAIN       0
 #define TEXT_ORDER_TRANSFORM_TRANSFORM_TO  1
@@ -136,7 +137,7 @@ static struct MenuEntry government_menu_entries[]={
 
 /* One entry for every government, appended to the government menu. */
 static int num_government_entries = 0;
-static Widget government_widgets[G_MAGIC];
+static Widget government_widgets[G_LAST];
 
 static struct MenuEntry view_menu_entries[]={
     { { N_("Map Grid"), 0             }, "ctl-g", MENU_VIEW_SHOW_MAP_GRID, 0 },
@@ -153,7 +154,8 @@ static struct MenuEntry view_menu_entries[]={
     { { N_("Irrigation"), 0           },      "", MENU_VIEW_SHOW_IRRIGATION, 0 },
     { { N_("Mines"), 0                },      "", MENU_VIEW_SHOW_MINES, 0 },
     { { N_("Bases"), 0                },      "", MENU_VIEW_SHOW_BASES, 0 },
-    { { N_("Specials"), 0             },      "", MENU_VIEW_SHOW_SPECIALS, 0 },
+    { { N_("Resources"), 0            },      "", MENU_VIEW_SHOW_RESOURCES, 0 },
+    { { N_("Huts"), 0                 },      "", MENU_VIEW_SHOW_HUTS, 0 },
     { { N_("Pollution & Fallout"), 0  },      "", MENU_VIEW_SHOW_POLLUTION, 0 },
     { { N_("Cities"), 0               },      "", MENU_VIEW_SHOW_CITIES, 0 },
     { { N_("Units"), 0                },      "", MENU_VIEW_SHOW_UNITS, 0 },
@@ -168,15 +170,16 @@ static struct MenuEntry order_menu_entries[]={
     { { N_("Build City"),
         N_("Add to City"), 0          },     "b", MENU_ORDER_BUILD_CITY, 0 },
     { { N_("Build Road"), 0           },     "r", MENU_ORDER_ROAD, 0 },
-    { { N_("Build Irrigation"),
-        N_("Build Farmland"),
+    { { N_("Build %s"),
+        N_("Build Irrigation"),
         N_("Change to %s"), 0         },     "i", MENU_ORDER_IRRIGATE, 0 },
-    { { N_("Build Mine"),
+    { { N_("Build %s"),
+        N_("Build Mine"),
         N_("Change to %s"), 0         },     "m", MENU_ORDER_MINE, 0 },
     { { N_("Transform Terrain"),
         N_("Transform to %s"), 0      },     "o", MENU_ORDER_TRANSFORM, 0 },
-    { { N_("Build Fortress"), 0       },     "f", MENU_ORDER_FORTRESS, 0 },
-    { { N_("Build Airbase"), 0        },     "e", MENU_ORDER_AIRBASE, 0 },
+    { { N_("Build Fortress"), 0       },     "F", MENU_ORDER_FORTRESS, 0 },
+    { { N_("Build Airbase"), 0        },     "E", MENU_ORDER_AIRBASE, 0 },
     { { N_("Clean Pollution"),
 	N_("Drop Paratrooper"), 0             },     "p", MENU_ORDER_POLLUTION, 0 },
     { { N_("Clean Nuclear Fallout"), 0},     "n", MENU_ORDER_FALLOUT, 0 },
@@ -230,6 +233,7 @@ static struct MenuEntry reports_menu_entries[]={
     { { N_("Messages"), 0             },    "F9", MENU_REPORT_MESSAGES, 0 },
     { { N_("Demographics"), 0         },   "F11", MENU_REPORT_DEMOGRAPHIC, 0 },
     { { N_("Spaceship"), 0            },   "F12", MENU_REPORT_SPACESHIP, 0 },
+    { { N_("Achievements"), 0         },      "", MENU_REPORT_ACHIEVEMENTS, 0},
     { { 0,                            },       0, MENU_END_OF_LIST, 0 }
 };
 
@@ -358,18 +362,21 @@ void real_menus_update(void)
     num_government_entries = i;
 
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_CITY_GROWTH,
-			 draw_city_names);
+                         gui_options.draw_city_names);
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_TERRAIN, 1);
-    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_COASTLINE, !draw_terrain);
+    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_COASTLINE,
+                         !gui_options.draw_terrain);
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_PATHS, 1);
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_IRRIGATION, 1);
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_MINES, 1);
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_BASES, 1);
-    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_SPECIALS, 1);
+    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_RESOURCES, 1);
+    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_HUTS, 1);
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_POLLUTION, 1);
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_CITIES, 1);
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_UNITS, 1);
-    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_FOCUS_UNIT, !draw_units);
+    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_FOCUS_UNIT,
+                         !gui_options.draw_units);
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_FOG_OF_WAR, 1);
 
     menu_entry_sensitive(MENU_GAME, MENU_GAME_OPTIONS, 1);
@@ -392,8 +399,9 @@ void real_menus_update(void)
       struct tile *ptile = NULL;
       bool can_build;
       struct unit_list *punits = get_units_in_focus();
-      bool road_conn_possible;
+      bool conn_possible;
       struct road_type *proad;
+      struct extra_type_list *extras;
 
       XtSetSensitive(menus[MENU_ORDER]->button, True);
 
@@ -448,32 +456,41 @@ void real_menus_update(void)
 
       proad = road_by_compat_special(ROCO_ROAD);
       if (proad != NULL) {
-        struct act_tgt tgt = { .type = ATT_ROAD,
-                               .obj.road = road_number(proad) }; 
+        struct extra_type *tgt;
 
-        road_conn_possible = can_units_do_connect(punits, ACTIVITY_GEN_ROAD,
-                                                  &tgt);
+        tgt = road_extra_get(proad);
+
+        conn_possible = can_units_do_connect(punits, ACTIVITY_GEN_ROAD, tgt);
       } else {
-        road_conn_possible = FALSE;
+        conn_possible = FALSE;
       }
-      menu_entry_sensitive(MENU_ORDER, MENU_ORDER_CONNECT_ROAD,
-			   road_conn_possible);
+      menu_entry_sensitive(MENU_ORDER, MENU_ORDER_CONNECT_ROAD, conn_possible);
 
       proad = road_by_compat_special(ROCO_RAILROAD);
       if (proad != NULL) {
-        struct act_tgt tgt = { .type = ATT_ROAD,
-                               .obj.road = road_number(proad) }; 
+        struct extra_type *tgt;
 
-        road_conn_possible = can_units_do_connect(punits, ACTIVITY_GEN_ROAD,
-                                                  &tgt);
+        tgt = road_extra_get(proad);
+
+        conn_possible = can_units_do_connect(punits, ACTIVITY_GEN_ROAD, tgt);
       } else {
-        road_conn_possible = FALSE;
+        conn_possible = FALSE;
       }
       menu_entry_sensitive(MENU_ORDER, MENU_ORDER_CONNECT_RAIL,
-                           road_conn_possible);
+                           conn_possible);
 
-      menu_entry_sensitive(MENU_ORDER, MENU_ORDER_CONNECT_IRRIGATE,
-			   can_units_do_connect(punits, ACTIVITY_IRRIGATE, NULL));
+      extras = extra_type_list_by_cause(EC_IRRIGATION);
+
+      if (extra_type_list_size(extras) > 0) { 
+        struct extra_type *tgt;
+
+        tgt = extra_type_list_get(extras, 0);
+        conn_possible = can_units_do_connect(punits, ACTIVITY_IRRIGATE, tgt);
+      } else {
+        conn_possible = FALSE;
+      }
+
+      menu_entry_sensitive(MENU_ORDER, MENU_ORDER_CONNECT_IRRIGATE, conn_possible);
       menu_entry_sensitive(MENU_ORDER, MENU_ORDER_GOTO_CITY,
 			   any_cities);
       menu_entry_sensitive(MENU_ORDER, MENU_ORDER_BUILD_WONDER,
@@ -483,8 +500,7 @@ void real_menus_update(void)
 			   can_units_do(punits,
 				        unit_can_est_trade_route_here));
       menu_entry_sensitive(MENU_ORDER, MENU_ORDER_DIPLOMAT_DLG,
-			   can_units_do_diplomat_action(punits,
-							DIPLOMAT_ANY_ACTION));
+                           can_units_act_against_own_tile(punits));
       menu_entry_sensitive(MENU_ORDER, MENU_ORDER_NUKE,
                            units_have_type_flag(punits, UTYF_NUCLEAR, TRUE));
 
@@ -497,14 +513,14 @@ void real_menus_update(void)
       tinfo = tile_terrain(ptile);
       can_build = !(tile_city(ptile));
 
-      if (units_have_type_flag(punits, UTYF_CITIES, TRUE)) {
-	if (!can_build) {
-	  menu_entry_rename(MENU_ORDER, MENU_ORDER_BUILD_CITY,
-			  TEXT_ORDER_CITY_ADD_TO, NULL);
-	} else {
-	  menu_entry_rename(MENU_ORDER, MENU_ORDER_BUILD_CITY,
-			  TEXT_ORDER_CITY_BUILD, NULL);
-	}
+      if (units_contain_cityfounder(punits)) {
+        if (!can_build) {
+          menu_entry_rename(MENU_ORDER, MENU_ORDER_BUILD_CITY,
+                            TEXT_ORDER_CITY_ADD_TO, NULL);
+        } else {
+          menu_entry_rename(MENU_ORDER, MENU_ORDER_BUILD_CITY,
+                            TEXT_ORDER_CITY_BUILD, NULL);
+        }
       }
 
       if ((tinfo->irrigation_result != T_NONE)
@@ -512,14 +528,27 @@ void real_menus_update(void)
 	menu_entry_rename(MENU_ORDER, MENU_ORDER_IRRIGATE,
 			  TEXT_ORDER_IRRIGATE_CHANGE_TO,
 			  terrain_name_translation(tinfo->irrigation_result));
-      }
-      else if (tile_has_special(ptile, S_IRRIGATION) &&
-	       player_knows_techs_with_flag(client.conn.playing, TF_FARMLAND)) {
-	menu_entry_rename(MENU_ORDER, MENU_ORDER_IRRIGATE,
-			  TEXT_ORDER_IRRIGATE_FARMLAND, NULL);
-      } else {
-	menu_entry_rename(MENU_ORDER, MENU_ORDER_IRRIGATE,
-			  TEXT_ORDER_IRRIGATE_IRRIGATE, NULL);
+      } else if (units_have_type_flag(punits, UTYF_SETTLERS, TRUE)) {
+        struct extra_type *pextra = NULL;
+
+        /* FIXME: this overloading doesn't work well with multiple focus
+         * units. */
+        unit_list_iterate(punits, punit) {
+          pextra = next_extra_for_tile(unit_tile(punit), EC_IRRIGATION,
+                                       unit_owner(punit), punit);
+          if (pextra != NULL) {
+            break;
+          }
+        } unit_list_iterate_end;
+
+        if (pextra != NULL) {
+          /* TRANS: Build irrigation of specific type */
+          menu_entry_rename(MENU_ORDER, MENU_ORDER_IRRIGATE,
+                            TEXT_ORDER_IRRIGATE, extra_name_translation(pextra));
+        } else {
+          menu_entry_rename(MENU_ORDER, MENU_ORDER_IRRIGATE,
+                            TEXT_ORDER_IRRIGATE_GENERIC, NULL);
+        }
       }
 
       if ((tinfo->mining_result != T_NONE)
@@ -527,9 +556,27 @@ void real_menus_update(void)
 	menu_entry_rename(MENU_ORDER, MENU_ORDER_MINE,
 			  TEXT_ORDER_MINE_CHANGE_TO,
 			  terrain_name_translation(tinfo->mining_result));
-      } else {
-	menu_entry_rename(MENU_ORDER, MENU_ORDER_MINE,
-			  TEXT_ORDER_MINE_MINE, NULL);
+      } else if (units_have_type_flag(punits, UTYF_SETTLERS, TRUE)) {
+        struct extra_type *pextra = NULL;
+
+        /* FIXME: this overloading doesn't work well with multiple focus
+         * units. */
+        unit_list_iterate(punits, punit) {
+          pextra = next_extra_for_tile(unit_tile(punit), EC_MINE,
+                                       unit_owner(punit), punit);
+          if (pextra != NULL) {
+            break;
+          }
+        } unit_list_iterate_end;
+
+        if (pextra != NULL) {
+          /* TRANS: Build mine of specific type */
+          menu_entry_rename(MENU_ORDER, MENU_ORDER_MINE,
+                            TEXT_ORDER_MINE, extra_name_translation(pextra));
+        } else {
+          menu_entry_rename(MENU_ORDER, MENU_ORDER_MINE,
+                            TEXT_ORDER_MINE_GENERIC, NULL);
+        }
       }
 
       if ((tinfo->transform_result != T_NONE)
@@ -650,7 +697,7 @@ static void view_menu_callback(Widget w, XtPointer client_data,
   case MENU_VIEW_SHOW_CITY_NAMES:
     key_city_names_toggle();
     menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_CITY_GROWTH,
-			 draw_city_names);
+                         gui_options.draw_city_names);
     break;
   case MENU_VIEW_SHOW_CITY_GROWTH:
     key_city_growth_toggle();
@@ -660,7 +707,8 @@ static void view_menu_callback(Widget w, XtPointer client_data,
     break;
   case MENU_VIEW_SHOW_TERRAIN:
     key_terrain_toggle();
-    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_COASTLINE, !draw_terrain);
+    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_COASTLINE,
+                         !gui_options.draw_terrain);
     break;
   case MENU_VIEW_SHOW_COASTLINE:
     key_coastline_toggle();
@@ -677,8 +725,11 @@ static void view_menu_callback(Widget w, XtPointer client_data,
   case MENU_VIEW_SHOW_BASES:
     key_bases_toggle();
     break;
-  case MENU_VIEW_SHOW_SPECIALS:
-    key_specials_toggle();
+  case MENU_VIEW_SHOW_RESOURCES:
+    key_resources_toggle();
+    break;
+  case MENU_VIEW_SHOW_HUTS:
+    key_huts_toggle();
     break;
   case MENU_VIEW_SHOW_POLLUTION:
     key_pollution_toggle();
@@ -688,7 +739,8 @@ static void view_menu_callback(Widget w, XtPointer client_data,
     break;
   case MENU_VIEW_SHOW_UNITS:
     key_units_toggle();
-    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_FOCUS_UNIT, !draw_units);
+    menu_entry_sensitive(MENU_VIEW, MENU_VIEW_SHOW_FOCUS_UNIT,
+                         !gui_options.draw_units);
     break;
   case MENU_VIEW_SHOW_FOCUS_UNIT:
     key_focus_unit_toggle();
@@ -703,10 +755,10 @@ static void view_menu_callback(Widget w, XtPointer client_data,
 }
 
 /****************************************************************
-...
+  Order selected from the orders menu.
 *****************************************************************/
 static void orders_menu_callback(Widget w, XtPointer client_data,
-				 XtPointer garbage)
+                                 XtPointer garbage)
 {
   size_t pane_num = (size_t)client_data;
 
@@ -733,6 +785,9 @@ static void orders_menu_callback(Widget w, XtPointer client_data,
     key_unit_airbase(); 
     break;
   case MENU_ORDER_POLLUTION: /* or MENU_ORDER_PARADROP */
+    /* FIXME: This calls key_unit_paradrop() / key_unit_pollution()
+     * as many times as there's focus units while those functions
+     * themselves handle all focus units at once. */
     unit_list_iterate(get_units_in_focus(), punit) {
       if (can_unit_paradrop(punit)) {
 	key_unit_paradrop();
@@ -761,7 +816,7 @@ static void orders_menu_callback(Widget w, XtPointer client_data,
     break;
   case MENU_ORDER_LOAD:
     unit_list_iterate(get_units_in_focus(), punit) {
-      request_unit_load(punit, NULL);
+      request_unit_load(punit, NULL, unit_tile(punit));
     } unit_list_iterate_end;
     break;
   case MENU_ORDER_UNLOAD:
@@ -783,10 +838,11 @@ static void orders_menu_callback(Widget w, XtPointer client_data,
       struct road_type *proad = road_by_compat_special(ROCO_ROAD);
 
       if (proad != NULL) {
-        struct act_tgt tgt = { .type = ATT_ROAD,
-                               .obj.road = road_number(proad) }; 
+        struct extra_type *tgt;
 
-        key_unit_connect(ACTIVITY_GEN_ROAD, &tgt);
+        tgt = road_extra_get(proad);
+
+        key_unit_connect(ACTIVITY_GEN_ROAD, tgt);
       }
     }
     break;
@@ -795,15 +851,26 @@ static void orders_menu_callback(Widget w, XtPointer client_data,
       struct road_type *proad = road_by_compat_special(ROCO_RAILROAD);
 
       if (proad != NULL) {
-        struct act_tgt tgt = { .type = ATT_ROAD,
-                               .obj.road = road_number(proad) }; 
+        struct extra_type *tgt;
 
-        key_unit_connect(ACTIVITY_GEN_ROAD, &tgt);
+        tgt = road_extra_get(proad);
+
+        key_unit_connect(ACTIVITY_GEN_ROAD, tgt);
       }
     }
     break;
   case MENU_ORDER_CONNECT_IRRIGATE:
-    key_unit_connect(ACTIVITY_IRRIGATE, NULL);
+    {
+      struct extra_type_list *extras = extra_type_list_by_cause(EC_IRRIGATION);
+
+      if (extra_type_list_size(extras) > 0) {
+        struct extra_type *pextra;
+
+        pextra = extra_type_list_get(extra_type_list_by_cause(EC_IRRIGATION), 0);
+
+        key_unit_connect(ACTIVITY_IRRIGATE, pextra);
+      }
+    }
     break;
   case MENU_ORDER_PATROL:
     key_unit_patrol();
@@ -833,7 +900,7 @@ static void orders_menu_callback(Widget w, XtPointer client_data,
     key_unit_trade_route();
     break;
   case MENU_ORDER_DIPLOMAT_DLG:
-    key_unit_diplomat_actions();
+    key_unit_action_select();
     break;
   case MENU_ORDER_NUKE:
     key_unit_nuke();
@@ -851,7 +918,7 @@ static void orders_menu_callback(Widget w, XtPointer client_data,
 }
 
 /****************************************************************
-...
+  User has selected item from reports menu
 *****************************************************************/
 static void reports_menu_callback(Widget w, XtPointer client_data,
 				  XtPointer garbage)
@@ -859,34 +926,37 @@ static void reports_menu_callback(Widget w, XtPointer client_data,
   size_t pane_num = (size_t)client_data;
 
   switch(pane_num) {
-   case MENU_REPORT_CITIES:
+  case MENU_REPORT_CITIES:
     city_report_dialog_popup(FALSE);
     break;
-   case MENU_REPORT_UNITS:
+  case MENU_REPORT_UNITS:
     units_report_dialog_popup(FALSE);
     break;
   case MENU_REPORT_PLAYERS:
     popup_players_dialog(FALSE);
     break;
-   case MENU_REPORT_ECONOMY:
+  case MENU_REPORT_ECONOMY:
     economy_report_dialog_popup(FALSE);
     break;
-   case MENU_REPORT_SCIENCE:
+  case MENU_REPORT_SCIENCE:
     science_report_dialog_popup(FALSE);
     break;
-   case MENU_REPORT_WOW:
+  case MENU_REPORT_WOW:
     send_report_request(REPORT_WONDERS_OF_THE_WORLD);
     break;
-   case MENU_REPORT_TOP_CITIES:
+  case MENU_REPORT_TOP_CITIES:
     send_report_request(REPORT_TOP_5_CITIES);
     break;
   case MENU_REPORT_MESSAGES:
     meswin_dialog_popup(FALSE);
     break;
-   case MENU_REPORT_DEMOGRAPHIC:
+  case MENU_REPORT_DEMOGRAPHIC:
     send_report_request(REPORT_DEMOGRAPHIC);
     break;
-   case MENU_REPORT_SPACESHIP:
+  case MENU_REPORT_ACHIEVEMENTS:
+    send_report_request(REPORT_ACHIEVEMENTS);
+    break;
+  case MENU_REPORT_SPACESHIP:
     if (NULL != client.conn.playing) {
       popup_spaceship_dialog(client.conn.playing);
     }
@@ -1041,7 +1111,7 @@ int is_menu_item_active(enum MenuIndex menu, enum MenuID id)
 }
 
 /****************************************************************
-...
+  Create one of the main menus
 *****************************************************************/
 void create_menu(enum MenuIndex menu, char *name, struct MenuEntry entries[], 
 		 void (*menucallback)(Widget, XtPointer, XtPointer),
