@@ -511,6 +511,14 @@ void update_timeout_label(void)
   funcs.update_timeout_label();
 }
 
+/****************************************************************************
+  Call start_turn callback
+****************************************************************************/
+void start_turn(void)
+{
+  funcs.start_turn();
+}
+
 /**************************************************************************
   Call real_city_dialog_popup callback
 **************************************************************************/
@@ -543,6 +551,14 @@ void popdown_all_city_dialogs(void)
   funcs.popdown_all_city_dialogs();
 }
 
+/**************************************************************************
+  Call city_to_disappear callback
+**************************************************************************/
+void city_to_disappear(struct city *pcity)
+{
+  funcs.city_to_disappear(pcity);
+}
+
 /**************************************************************************
   Call handmade_scenario_warning callback
 **************************************************************************/
