@@ -30,6 +30,9 @@ enum line_type {
 GUI_FUNC_PROTO(struct canvas *, canvas_create, int width, int height)
 GUI_FUNC_PROTO(void, canvas_free, struct canvas *store)
 
+GUI_FUNC_PROTO(void, canvas_set_zoom, struct canvas *store, float zoom)
+GUI_FUNC_PROTO(bool, has_zoom_support, void)
+
 /* Drawing functions */
 GUI_FUNC_PROTO(void, canvas_copy, struct canvas *dest, struct canvas *src,
                int src_x, int src_y, int dest_x, int dest_y,
@@ -51,8 +54,6 @@ GUI_FUNC_PROTO(void, canvas_fill_sprite_area, struct canvas *pcanvas,
                struct sprite *psprite,
                struct color *pcolor,
                int canvas_x, int canvas_y)
-GUI_FUNC_PROTO(void, canvas_fog_sprite_area, struct canvas *pcanvas,
-               struct sprite *psprite, int canvas_x, int canvas_y)
 GUI_FUNC_PROTO(void, canvas_put_line, struct canvas *pcanvas,
                struct color *pcolor,
                enum line_type ltype, int start_x, int start_y,
