@@ -163,20 +163,21 @@ static void node_rectangle_minimum_size(struct tree_node *node,
   int icons_width_sum; /* sum of icons width plus space between them */
   struct sprite* sprite;
   int swidth, sheight;
-  
+
   if (node->is_dummy) {
     /* Dummy node is a straight line */
     *width = *height = 1;
   } else {
     get_text_size(width, height, FONT_REQTREE_TEXT,
-		  advance_name_for_player(client.conn.playing, node->tech));
+                  research_advance_name_translation
+                      (research_get(client_player()), node->tech));
     *width += 2;
     *height += 8;
     
     max_icon_height = 0;
     icons_width_sum = 5;
     
-    if (reqtree_show_icons) {
+    if (gui_options.reqtree_show_icons) {
       /* units */
       unit_type_iterate(unit) {
         if (advance_number(unit->require_advance) != node->tech) {
@@ -387,8 +388,9 @@ static void calculate_diagram_layout(struct reqtree *tree)
   If pplayer is given, add only techs reachable by that player to tree.
 *************************************************************************/
 static struct reqtree *create_dummy_reqtree(struct player *pplayer,
-                                            bool reachable)
+                                            bool show_all)
 {
+  const struct research *presearch = research_get(pplayer);
   struct reqtree *tree = fc_malloc(sizeof(*tree));
   int j;
   struct tree_node *nodes[advance_count()];
@@ -399,7 +401,8 @@ static struct reqtree *create_dummy_reqtree(struct player *pplayer,
       nodes[tech] = NULL;
       continue;
     }
-    if (pplayer && reachable && !player_invention_reachable(pplayer, tech, TRUE)) {
+    if (pplayer && !show_all
+        && !research_invention_reachable(presearch, tech)) {
       /* Reqtree requested for particular player and this tech is
        * unreachable to him/her. */
       nodes[tech] = NULL;
@@ -424,7 +427,7 @@ static struct reqtree *create_dummy_reqtree(struct player *pplayer,
     tech_one = advance_required(tech, AR_ONE);
     tech_two = advance_required(tech, AR_TWO);
 
-    if (reachable && A_NONE != tech_one
+    if (!show_all && A_NONE != tech_one
         && A_LAST != tech_two && A_NONE != tech_two
         && (nodes[tech_one] == NULL || nodes[tech_two] == NULL)) {
       /* Print only reachable techs. */
@@ -826,12 +829,12 @@ static void improve(struct reqtree *tree)
 
   If pplayer is not NULL, techs unreachable to that player are not shown.
 *************************************************************************/
-struct reqtree *create_reqtree(struct player *pplayer, bool reachable)
+struct reqtree *create_reqtree(struct player *pplayer, bool show_all)
 {
   struct reqtree *tree1, *tree2;
   int i, j;
 
-  tree1 = create_dummy_reqtree(pplayer, reachable);
+  tree1 = create_dummy_reqtree(pplayer, show_all);
   longest_path_layering(tree1);
   tree2 = add_dummy_nodes(tree1);
   destroy_reqtree(tree1);
@@ -874,19 +877,18 @@ void get_reqtree_dimensions(struct reqtree *reqtree,
 static enum color_std node_color(struct tree_node *node)
 {
   if (!node->is_dummy) {
-    struct player_research* research = player_research_get(client.conn.playing);
+    struct research *research = research_get(client_player());
 
     if (!research) {
       return COLOR_REQTREE_KNOWN;
     }
 
-    if (!player_invention_reachable(client.conn.playing, node->tech, TRUE)) {
+    if (!research_invention_reachable(research, node->tech)) {
       return COLOR_REQTREE_UNREACHABLE;
     }
 
-    if (!player_invention_reachable(client.conn.playing, node->tech, FALSE)) {
-      if (is_tech_a_req_for_goal(client.conn.playing, node->tech,
-                                 research->tech_goal)
+    if (!research_invention_gettable(research, node->tech, TRUE)) {
+      if (research_goal_tech_req(research, research->tech_goal, node->tech)
           || node->tech == research->tech_goal) {
         return COLOR_REQTREE_GOAL_NOT_GETTABLE;
       } else {
@@ -898,23 +900,22 @@ static enum color_std node_color(struct tree_node *node)
       return COLOR_REQTREE_RESEARCHING;
     }
 
-    if (TECH_KNOWN == player_invention_state(client.conn.playing, node->tech)) {
+    if (TECH_KNOWN == research_invention_state(research, node->tech)) {
       return COLOR_REQTREE_KNOWN;
     }
 
-    if (is_tech_a_req_for_goal(client.conn.playing, node->tech,
-                               research->tech_goal)
+    if (research_goal_tech_req(research, research->tech_goal, node->tech)
 	|| node->tech == research->tech_goal) {
-      if (TECH_PREREQS_KNOWN ==
-            player_invention_state(client.conn.playing, node->tech)) {
+      if (TECH_PREREQS_KNOWN == research_invention_state(research,
+                                                         node->tech)) {
 	return COLOR_REQTREE_GOAL_PREREQS_KNOWN;
       } else {
 	return COLOR_REQTREE_GOAL_UNKNOWN;
       }
     }
 
-    if (TECH_PREREQS_KNOWN ==
-          player_invention_state(client.conn.playing, node->tech)) {
+    if (TECH_PREREQS_KNOWN == research_invention_state(research,
+                                                       node->tech)) {
       return COLOR_REQTREE_PREREQS_KNOWN;
     }
 
@@ -933,7 +934,7 @@ static enum color_std node_color(struct tree_node *node)
 static enum reqtree_edge_type get_edge_type(struct tree_node *node, 
                                             struct tree_node *dest_node)
 {
-  struct player_research *research = player_research_get(client.conn.playing);
+  struct research *research = research_get(client_player());
 
   if (dest_node == NULL) {
     /* assume node is a dummy */
@@ -980,14 +981,13 @@ static enum reqtree_edge_type get_edge_type(struct tree_node *node,
     return REQTREE_ACTIVE_EDGE;
   }
 
-  if (is_tech_a_req_for_goal(client.conn.playing, dest_node->tech,
-                             research->tech_goal)
+  if (research_goal_tech_req(research, research->tech_goal, dest_node->tech)
       || dest_node->tech == research->tech_goal) {
     return REQTREE_GOAL_EDGE;
   }
 
-  if (TECH_KNOWN == player_invention_state(client.conn.playing, node->tech)) {
-    if (TECH_KNOWN == player_invention_state(client.conn.playing, dest_node->tech)) {
+  if (TECH_KNOWN == research_invention_state(research, node->tech)) {
+    if (TECH_KNOWN == research_invention_state(research, dest_node->tech)) {
       return REQTREE_KNOWN_EDGE;
     } else {
       return REQTREE_READY_EDGE;
@@ -1053,10 +1053,11 @@ void draw_reqtree(struct reqtree *tree, struct canvas *pcanvas,
 		        LINE_GOTO,
 		        startx, starty, width, 0);
       } else {
-	const char *text = advance_name_for_player(client.conn.playing, node->tech);
+        const char *text = research_advance_name_translation
+                               (research_get(client_player()), node->tech);
 	int text_w, text_h;
 	int icon_startx;
-	
+
         canvas_put_rectangle(pcanvas,
                              get_color(tileset, COLOR_REQTREE_BACKGROUND),
                              startx, starty, width, height);
@@ -1080,7 +1081,7 @@ void draw_reqtree(struct reqtree *tree, struct canvas *pcanvas,
 			text);
  	icon_startx = startx + 5;
 	
-	if (reqtree_show_icons) {
+	if (gui_options.reqtree_show_icons) {
  	  unit_type_iterate(unit) {
             if (advance_number(unit->require_advance) != node->tech) {
 	      continue;
@@ -1143,7 +1144,7 @@ void draw_reqtree(struct reqtree *tree, struct canvas *pcanvas,
 	endx = dest_node->node_x;
 	endy = dest_node->node_y + dest_node->node_height / 2;
 	
-        if (reqtree_curved_lines) {
+        if (gui_options.reqtree_curved_lines) {
           canvas_put_curved_line(pcanvas, color, LINE_GOTO,
                                  startx, starty, endx - startx,
                                  endy - starty);
