@@ -1,4 +1,4 @@
-/**********************************************************************
+/***********************************************************************
  Freeciv - Copyright (C) 1996-2005 - Freeciv Development Team
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,10 +15,12 @@
 #include <fc_config.h>
 #endif
 
+#include "fc_prehdrs.h"
+
 #include <errno.h>
 #include <stdlib.h>
 
-#ifdef HAVE_SYS_TYPES_H
+#ifdef FREECIV_HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_SOCKET_H
@@ -48,16 +50,6 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#ifdef HAVE_WINSOCK
-#ifdef HAVE_WINSOCK2
-#include <winsock2.h>
-#else  /* HAVE_WINSOCK2 */
-#include <winsock.h>
-#endif /* HAVE_WINSOCK2 */
-#endif /* HAVE_WINSOCK */
-#ifdef HAVE_WS2TCPIP_H
-#include <ws2tcpip.h>
-#endif
 
 /* dependencies */
 #include "cvercmp.h"
@@ -103,7 +95,7 @@ struct server_scan {
     fc_mutex mutex;
 
     const char *urlpath;
-    FILE *fp; /* temp file */
+    struct netfile_write_cb_data mem;
   } meta;
 };
 
@@ -122,6 +114,7 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
   struct section_file *file;
   int nservers, i, j;
   const char *latest_ver;
+  const char *comment;
 
   /* This call closes f. */
   if (!(file = secfile_from_stream(f, TRUE))) {
@@ -129,13 +122,14 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
   }
 
   latest_ver = secfile_lookup_str_default(file, NULL, "versions." FOLLOWTAG);
+  comment = secfile_lookup_str_default(file, NULL, "version_comments." FOLLOWTAG);
 
   if (latest_ver != NULL) {
     const char *my_comparable = fc_comparable_version();
     char vertext[2048];
 
-    log_verbose("Metaserver says latest '%s' version is '%s'; we have '%s'",
-                FOLLOWTAG, latest_ver, my_comparable);
+    log_verbose("Metaserver says latest '" FOLLOWTAG "' version is '%s'; we have '%s'",
+                latest_ver, my_comparable);
     if (cvercmp_greater(latest_ver, my_comparable)) {
       const char *const followtag = "?vertag:" FOLLOWTAG;
       fc_snprintf(vertext, sizeof(vertext),
@@ -144,13 +138,20 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
                    * '?vertag:') */
                   _("Latest %s release of Freeciv is %s, this is %s."),
                   Q_(followtag), latest_ver, my_comparable);
-    } else {
+
+      version_message(vertext);
+    } else if (comment == NULL) {
       fc_snprintf(vertext, sizeof(vertext),
                   _("There is no newer %s release of Freeciv available."),
                   FOLLOWTAG);
-    }
 
-    version_message(vertext);
+      version_message(vertext);
+    }
+  }
+
+  if (comment != NULL) {
+    log_verbose("Mesaserver comment about '" FOLLOWTAG "': %s", comment);
+    version_message(comment);
   }
 
   server_list = server_list_new();
@@ -191,7 +192,7 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
     }
 
     for (j = 0; j < pserver->nplayers ; j++) {
-      const char *name, *nation, *type, *host;
+      const char *name, *nation, *type, *plrhost;
 
       name = secfile_lookup_str_default(file, "", 
                                         "server%d.player%d.name", i, j);
@@ -201,9 +202,9 @@ static struct server_list *parse_metaserver_data(fz_FILE *f)
                                         "server%d.player%d.type", i, j);
       pserver->players[j].type = fc_strdup(type);
 
-      host = secfile_lookup_str_default(file, "", 
-                                        "server%d.player%d.host", i, j);
-      pserver->players[j].host = fc_strdup(host);
+      plrhost = secfile_lookup_str_default(file, "", 
+                                           "server%d.player%d.host", i, j);
+      pserver->players[j].host = fc_strdup(plrhost);
 
       nation = secfile_lookup_str_default(file, "",
                                           "server%d.player%d.nation", i, j);
@@ -227,7 +228,7 @@ static bool meta_read_response(struct server_scan *scan)
   char str[4096];
   struct server_list *srvrs;
 
-  f = fz_from_stream(scan->meta.fp);
+  f = fz_from_memory(scan->meta.mem.mem, scan->meta.mem.size, TRUE);
   if (NULL == f) {
     fc_snprintf(str, sizeof(str),
                 _("Failed to read the metaserver data from %s."),
@@ -243,8 +244,8 @@ static bool meta_read_response(struct server_scan *scan)
   scan->srvrs.servers = srvrs;
   fc_release_mutex(&scan->srvrs.mutex);
 
-  /* 'f' (hence 'meta.fp') was closed in parse_metaserver_data(). */
-  scan->meta.fp = NULL;
+  /* 'f' (hence 'meta.mem.mem') was closed in parse_metaserver_data(). */
+  scan->meta.mem.mem = NULL;
 
   if (NULL == srvrs) {
     fc_snprintf(str, sizeof(str),
@@ -266,45 +267,22 @@ static void metaserver_scan(void *arg)
 {
   struct server_scan *scan = arg;
 
-  if (!scan->meta.fp) {
-#ifdef WIN32_NATIVE
-    char filename[MAX_PATH];
-
-    GetTempPath(sizeof(filename), filename);
-    cat_snprintf(filename, sizeof(filename), "fctmp%d", fc_rand(1000));
-
-    scan->meta.fp = fc_fopen(filename, "w+b");
-#else
-    scan->meta.fp = tmpfile();
-#endif /* WIN32_NATIVE */
-
-    if (!scan->meta.fp) {
-      scan->error_func(scan, _("Could not open temp file."));
-    }
-  }
-
-  if (scan->meta.fp) {
-
-    if (!begin_metaserver_scan(scan)) {
+  if (!begin_metaserver_scan(scan)) {
+    fc_allocate_mutex(&scan->meta.mutex);
+    scan->meta.status = SCAN_STATUS_ERROR;
+  } else {
+    if (!meta_read_response(scan)) {
       fc_allocate_mutex(&scan->meta.mutex);
       scan->meta.status = SCAN_STATUS_ERROR;
     } else {
-
-      rewind(scan->meta.fp);
-
-      if (!meta_read_response(scan)) {
-        fc_allocate_mutex(&scan->meta.mutex);
-        scan->meta.status = SCAN_STATUS_ERROR;
-      } else {
-        fc_allocate_mutex(&scan->meta.mutex);
-        if (scan->meta.status == SCAN_STATUS_WAITING) {
-          scan->meta.status = SCAN_STATUS_DONE;
-        }
+      fc_allocate_mutex(&scan->meta.mutex);
+      if (scan->meta.status == SCAN_STATUS_WAITING) {
+        scan->meta.status = SCAN_STATUS_DONE;
       }
     }
-
-    fc_release_mutex(&scan->meta.mutex);
   }
+
+  fc_release_mutex(&scan->meta.mutex);
 }
 
 /****************************************************************************
@@ -321,7 +299,7 @@ static bool begin_metaserver_scan(struct server_scan *scan)
   post = netfile_start_post();
   netfile_add_form_str(post, "client_cap", our_capability);
 
-  if (!netfile_send_post(metaserver, post, scan->meta.fp, NULL)) {
+  if (!netfile_send_post(metaserver, post, NULL, &scan->meta.mem, NULL)) {
     scan->error_func(scan, _("Error connecting to metaserver"));
     retval = FALSE;
   }
@@ -377,11 +355,11 @@ static bool begin_lanserver_scan(struct server_scan *scan)
   union fc_sockaddr addr;
   struct data_out dout;
   int send_sock, opt = 1;
-#ifndef HAVE_WINSOCK
+#ifndef FREECIV_HAVE_WINSOCK
   unsigned char buffer[MAX_LEN_PACKET];
-#else  /* HAVE_WINSOCK */
+#else  /* FREECIV_HAVE_WINSOCK */
   char buffer[MAX_LEN_PACKET];
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 #ifdef HAVE_IP_MREQN
   struct ip_mreqn mreq4;
 #else
@@ -391,11 +369,11 @@ static bool begin_lanserver_scan(struct server_scan *scan)
   size_t size;
   int family;
 
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   struct ipv6_mreq mreq6;
 #endif
 
-#ifndef HAVE_WINSOCK
+#ifndef FREECIV_HAVE_WINSOCK
   unsigned char ttl;
 #endif
 
@@ -404,7 +382,7 @@ static bool begin_lanserver_scan(struct server_scan *scan)
     return TRUE;
   }
 
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   if (announce == ANNOUNCE_IPV6) {
     family = AF_INET6;
   } else
@@ -437,7 +415,7 @@ static bool begin_lanserver_scan(struct server_scan *scan)
 
   memset(&addr, 0, sizeof(addr));
 
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   if (family == AF_INET6) {
     addr.saddr.sa_family = AF_INET6;
     addr.saddr_in6.sin6_port = htons(SERVER_LAN_PORT + 1);
@@ -468,7 +446,7 @@ static bool begin_lanserver_scan(struct server_scan *scan)
     return FALSE;
   }
 
-#ifndef IPV6_SUPPORT
+#ifndef FREECIV_IPV6_SUPPORT
   {
 #ifdef HAVE_INET_ATON
     inet_aton(group, &mreq4.imr_multiaddr);
@@ -520,7 +498,7 @@ static bool begin_lanserver_scan(struct server_scan *scan)
 
   memset(&addr, 0, sizeof(addr));
   
-#ifndef IPV6_SUPPORT
+#ifndef FREECIV_IPV6_SUPPORT
   if (family == AF_INET) {
 #ifdef HAVE_INET_ATON
     inet_aton(group, &addr.saddr_in4.sin_addr);
@@ -547,7 +525,7 @@ static bool begin_lanserver_scan(struct server_scan *scan)
 
 /* this setsockopt call fails on Windows 98, so we stick with the default
  * value of 1 on Windows, which should be fine in most cases */
-#ifndef HAVE_WINSOCK
+#ifndef FREECIV_HAVE_WINSOCK
   /* Set the Time-to-Live field for the packet  */
   ttl = SERVER_LAN_TTL;
   if (setsockopt(send_sock, IPPROTO_IP, IP_MULTICAST_TTL, (const char*)&ttl, 
@@ -555,7 +533,7 @@ static bool begin_lanserver_scan(struct server_scan *scan)
     log_error("setsockopt failed: %s", fc_strerror(fc_get_errno()));
     return FALSE;
   }
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 
   if (setsockopt(send_sock, SOL_SOCKET, SO_BROADCAST, (const char*)&opt, 
                  sizeof(opt))) {
@@ -639,7 +617,7 @@ get_lan_server_list(struct server_scan *scan)
 
     if (!fc_strcasecmp("none", servername)) {
       bool nameinfo = FALSE;
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
       char dst[INET6_ADDRSTRLEN];
       char host[NI_MAXHOST], service[NI_MAXSERV];
 
@@ -851,7 +829,7 @@ void server_scan_finish(struct server_scan *scan)
   }
 
   if (scan->type == SERVER_SCAN_GLOBAL) {
-    /* Signal metserver scan thread to stop */
+    /* Signal metaserver scan thread to stop */
     fc_allocate_mutex(&scan->meta.mutex);
     scan->meta.status = SCAN_STATUS_ABORT;
     fc_release_mutex(&scan->meta.mutex);
@@ -875,9 +853,9 @@ void server_scan_finish(struct server_scan *scan)
       fc_release_mutex(&scan->srvrs.mutex);
     }
 
-    if (scan->meta.fp) {
-      fclose(scan->meta.fp);
-      scan->meta.fp = NULL;
+    if (scan->meta.mem.mem) {
+      FC_FREE(scan->meta.mem.mem);
+      scan->meta.mem.mem = NULL;
     }
   } else {
     if (scan->sock >= 0) {
