@@ -24,9 +24,9 @@
 #include "game.h"
 #include "map.h"
 #include "movement.h"
-#include "unit.h"
 #include "research.h"
 #include "tile.h"
+#include "unit.h"
 
 /* Values used to interpret action probabilities.
  *
@@ -51,6 +51,8 @@ static bool actions_initialized = FALSE;
 
 static struct action_enabler_list *action_enablers_by_action[ACTION_COUNT];
 
+static struct astring ui_name_str = ASTRING_INIT;
+
 static struct action *action_new(enum gen_action id,
                                  enum action_target_kind target_kind,
                                  bool hostile);
@@ -156,6 +158,8 @@ void actions_free(void)
 
     FC_FREE(actions[act]);
   } action_iterate_end;
+
+  astr_free(&ui_name_str);
 }
 
 /**************************************************************************
@@ -301,16 +305,18 @@ const char *action_get_ui_name_mnemonic(int act_id,
   appears in the action name it can be escaped by doubling.
   Success probability information is interpreted and added to the text.
   A custom text can be inserted before the probability information.
+
+  The returned string is in statically allocated astring, and thus this
+  function is not thread-safe.
 **************************************************************************/
-const char *action_prepare_ui_name(int act_id, const char* mnemonic,
+const char *action_prepare_ui_name(int act_id, const char *mnemonic,
                                    const struct act_prob prob,
-                                   const char* custom)
+                                   const char *custom)
 {
-  static struct astring str = ASTRING_INIT;
-  static struct astring chance = ASTRING_INIT;
+  struct astring chance = ASTRING_INIT;
 
   /* Text representation of the probability. */
-  const char* probtxt;
+  const char *probtxt;
 
   if (!actions_are_ready()) {
     /* Could be a client who haven't gotten the ruleset yet */
@@ -327,11 +333,11 @@ const char *action_prepare_ui_name(int act_id, const char* mnemonic,
     fc_assert(custom == NULL || custom[0] == '\0');
 
     /* Make the best of what is known */
-    astr_set(&str, _("%s%s (name may be wrong)"),
+    astr_set(&ui_name_str, _("%s%s (name may be wrong)"),
              mnemonic, gen_action_name(act_id));
 
     /* Return the guess. */
-    return astr_str(&str);
+    return astr_str(&ui_name_str);
   }
 
   /* How to interpret action probabilities like prob is documented in
@@ -418,18 +424,23 @@ const char *action_prepare_ui_name(int act_id, const char* mnemonic,
     astr_add(&fmtstr, "%s", ui_name);
 
     /* Use the modified format string */
-    astr_set(&str, astr_str(&fmtstr), mnemonic,
+    astr_set(&ui_name_str, astr_str(&fmtstr), mnemonic,
              astr_str(&chance));
 
     astr_free(&fmtstr);
   }
 
-  return astr_str(&str);
+  astr_free(&chance);
+
+  return astr_str(&ui_name_str);
 }
 
 /**************************************************************************
   Get information about starting the action in the current situation.
   Suitable for a tool tip for the button that starts it.
+
+  The returned string is in statically allocated astring, and thus this
+  function is not thread-safe.
 **************************************************************************/
 const char *action_get_tool_tip(const int act_id,
                                 const struct act_prob prob)
@@ -1187,9 +1198,18 @@ static struct act_prob ap_dipl_battle_win(const struct unit *pattacker,
   See diplomat_infiltrate_tile() in server/diplomats.c
 **************************************************************************/
 static struct act_prob ap_diplomat_battle(const struct unit *pattacker,
-                                          const struct unit *pvictim)
+                                          const struct unit *pvictim,
+                                          const struct tile *tgt_tile)
 {
-  unit_list_iterate(unit_tile(pvictim)->units, punit) {
+  fc_assert_ret_val(tgt_tile, ACTPROB_NOT_KNOWN);
+
+  if (!can_player_see_hypotetic_units_at(unit_owner(pattacker),
+                                         tgt_tile)) {
+    /* Don't leak information about unseen defenders. */
+    return ACTPROB_NOT_KNOWN;
+  }
+
+  unit_list_iterate(tgt_tile->units, punit) {
     if (unit_owner(punit) == unit_owner(pattacker)) {
       /* Won't defend against its owner. */
       continue;
@@ -1205,7 +1225,7 @@ static struct act_prob ap_diplomat_battle(const struct unit *pattacker,
     }
 
     if (!(unit_has_type_flag(punit, UTYF_DIPLOMAT)
-        || unit_has_type_flag(punit, UTYF_SUPERSPY))) {
+          || unit_has_type_flag(punit, UTYF_SUPERSPY))) {
       /* The unit can't defend. */
       continue;
     }
@@ -1288,18 +1308,19 @@ action_prob(const enum gen_action wanted_action,
 
   switch (wanted_action) {
   case ACTION_SPY_POISON:
-    /* TODO */
+    /* All uncertainty comes from potential diplomatic battles. */
+    chance = ap_diplomat_battle(actor_unit, NULL, target_tile);
     break;
   case ACTION_SPY_STEAL_GOLD:
     /* TODO */
     break;
   case ACTION_SPY_SABOTAGE_UNIT:
     /* All uncertainty comes from potential diplomatic battles. */
-    chance = ap_diplomat_battle(actor_unit, target_unit);
+    chance = ap_diplomat_battle(actor_unit, target_unit, target_tile);
     break;
   case ACTION_SPY_BRIBE_UNIT:
     /* All uncertainty comes from potential diplomatic battles. */
-    chance = ap_diplomat_battle(actor_unit, target_unit);;
+    chance = ap_diplomat_battle(actor_unit, target_unit, target_tile);
     break;
   case ACTION_SPY_SABOTAGE_CITY:
     /* TODO */
@@ -1371,8 +1392,9 @@ action_prob(const enum gen_action wanted_action,
     break;
   };
 
-  fc_assert_ret_val_msg(FALSE, ACTPROB_NOT_IMPLEMENTED,
-                        "Should be yes, maybe or no");
+  fc_assert_msg(FALSE, "Should be yes, maybe or no");
+
+  return ACTPROB_NOT_IMPLEMENTED;
 }
 
 /**************************************************************************
@@ -1483,6 +1505,45 @@ struct act_prob action_prob_vs_unit(const struct unit* actor_unit,
                      target_unit, NULL, NULL);
 }
 
+/**********************************************************************//**
+  Returns the actor unit's probability of successfully performing the
+  specified action against the action specific target.
+  @param paction the action to perform
+  @param act_unit the actor unit
+  @param tgt_city the target for city targeted actions
+  @param tgt_unit the target for unit targeted actions
+  @return the action probability of performing the action
+**************************************************************************/
+struct act_prob action_prob_unit_vs_tgt(const struct action *paction,
+                                        const struct unit *act_unit,
+                                        const struct city *tgt_city,
+                                        const struct unit *tgt_unit)
+{
+  /* Assume impossible until told otherwise. */
+  struct act_prob prob = ACTPROB_IMPOSSIBLE;
+
+  fc_assert_ret_val(paction, ACTPROB_IMPOSSIBLE);
+  fc_assert_ret_val(act_unit, ACTPROB_IMPOSSIBLE);
+
+  switch (action_get_target_kind(paction)) {
+  case ATK_CITY:
+    if (tgt_city) {
+      prob = action_prob_vs_city(act_unit, paction->id, tgt_city);
+    }
+    break;
+  case ATK_UNIT:
+    if (tgt_unit) {
+      prob = action_prob_vs_unit(act_unit, paction->id, tgt_unit);
+    }
+    break;
+  case ATK_COUNT:
+    log_error("Invalid action target kind");
+    break;
+  }
+
+  return prob;
+}
+
 /**********************************************************************//**
   Returns a speculation about the actor unit's probability of successfully
   performing the chosen action on the target city given the specified
