@@ -17,7 +17,8 @@
 extern "C" {
 #endif /* __cplusplus */
 
-int game_next_year(int);
+struct packet_game_info;
+void game_next_year(struct packet_game_info *info);
 void game_advance_year(void);
 
 const char *textyear(int year);
