@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 #include <fc_config.h>
 #endif
 
+#include "fc_prehdrs.h"
+
 #include <limits.h>
 #include <math.h>
 #include <stdint.h>
@@ -30,7 +32,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef HAVE_SYS_TYPES_H
+#ifdef FREECIV_HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_SOCKET_H
@@ -42,13 +44,6 @@
 #ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
-#ifdef HAVE_WINSOCK
-#ifdef HAVE_WINSOCK2
-#include <winsock2.h>
-#else  /* HAVE_WINSOCK2 */
-#include <winsock.h>
-#endif /* HAVE_WINSOCK2 */
-#endif /* HAVE_WINSOCK */
 
 /* utility */
 #include "bitvector.h"
@@ -67,11 +62,36 @@
 #include "dataio.h"
 
 static bool get_conv(char *dst, size_t ndst, const char *src,
-		     size_t nsrc);
+                     size_t nsrc);
 
 static DIO_PUT_CONV_FUN put_conv_callback = NULL;
 static DIO_GET_CONV_FUN get_conv_callback = get_conv;
 
+/* Uncomment to make field range tests to asserts, fatal with -F */
+/* #define FIELD_RANGE_ASSERT */
+
+#if defined(FREECIV_TESTMATIC) && !defined(FIELD_RANGE_ASSERT)
+#define FIELD_RANGE_ASSERT
+#endif
+
+#ifdef FIELD_RANGE_ASSERT
+/* This evaluates _test_ twice. If that's a problem,
+ * it should evaluate it just once and store result to variable.
+ * That would lose verbosity of the assert message. */
+#define FIELD_RANGE_TEST(_test_, _action_, _format_, ...) \
+  fc_assert(!(_test_));                                   \
+  if (_test_) {                                           \
+    _action_                                              \
+    log_error(_format_, ## __VA_ARGS__);                  \
+  }
+#else  /* FIELD_RANGE_ASSERT */
+#define FIELD_RANGE_TEST(_test_, _action_, _format_, ...) \
+  if (_test_) {                                           \
+    _action_                                              \
+    log_error(_format_, ## __VA_ARGS__);                  \
+  }
+#endif /* FIELD_RANGE_ASSERT */
+
 /**************************************************************************
   Sets string conversion callback to be used when putting text.
 **************************************************************************/
@@ -234,11 +254,10 @@ void dio_put_uint8(struct data_out *dout, int value)
   uint8_t x = value;
   FC_STATIC_ASSERT(sizeof(x) == 1, uint8_not_1_byte);
 
-  if ((int) x != value) {
-    log_error("Trying to put %d into 8 bits; "
-              "it will result %d at receiving side.",
-              value, (int) x);
-  }
+  FIELD_RANGE_TEST((int) x != value, ,
+                   "Trying to put %d into 8 bits; "
+                   "it will result %d at receiving side.",
+                   value, (int) x);
 
   if (enough_space(dout, 1)) {
     memcpy(ADD_TO_POINTER(dout->dest, dout->current), &x, 1);
@@ -254,11 +273,10 @@ void dio_put_uint16(struct data_out *dout, int value)
   uint16_t x = htons(value);
   FC_STATIC_ASSERT(sizeof(x) == 2, uint16_not_2_bytes);
 
-  if ((int) ntohs(x) != value) {
-    log_error("Trying to put %d into 16 bits; "
-              "it will result %d at receiving side.",
-              value, (int) ntohs(x));
-  }
+  FIELD_RANGE_TEST((int) ntohs(x) != value, ,
+                   "Trying to put %d into 16 bits; "
+                   "it will result %d at receiving side.",
+                   value, (int) ntohs(x));
 
   if (enough_space(dout, 2)) {
     memcpy(ADD_TO_POINTER(dout->dest, dout->current), &x, 2);
@@ -274,11 +292,10 @@ void dio_put_uint32(struct data_out *dout, int value)
   uint32_t x = htonl(value);
   FC_STATIC_ASSERT(sizeof(x) == 4, uint32_not_4_bytes);
 
-  if ((int) ntohl(x) != value) {
-    log_error("Trying to put %d into 32 bits; "
-              "it will result %d at receiving side.",
-              value, (int) ntohl(x));
-  }
+  FIELD_RANGE_TEST((int) ntohl(x) != value, ,
+                   "Trying to put %d into 32 bits; "
+                   "it will result %d at receiving side.",
+                   value, (int) ntohl(x));
 
   if (enough_space(dout, 4)) {
     memcpy(ADD_TO_POINTER(dout->dest, dout->current), &x, 4);
@@ -350,10 +367,9 @@ void dio_put_sint32(struct data_out *dout, int value)
 **************************************************************************/
 void dio_put_bool8(struct data_out *dout, bool value)
 {
-  if (value != TRUE && value != FALSE) {
-    log_error("Trying to put a non-boolean: %d", (int) value);
-    value = (value != FALSE);
-  }
+  FIELD_RANGE_TEST(value != TRUE && value != FALSE,
+                   value = (value != FALSE);,
+                   "Trying to put a non-boolean: %d", (int) value);
 
   dio_put_uint8(dout, value ? 1 : 0);
 }
@@ -363,10 +379,10 @@ void dio_put_bool8(struct data_out *dout, bool value)
 **************************************************************************/
 void dio_put_bool32(struct data_out *dout, bool value)
 {
-  if (value != TRUE && value != FALSE) {
-    log_error("Trying to put a non-boolean: %d", (int) value);
-    value = (value != FALSE);
-  }
+  FIELD_RANGE_TEST(value != TRUE && value != FALSE,
+                   value = (value != FALSE);,
+                   "Trying to put a non-boolean: %d",
+                   (int) value);
 
   dio_put_uint32(dout, value ? 1 : 0);
 }
@@ -379,12 +395,11 @@ void dio_put_ufloat(struct data_out *dout, float value, int float_factor)
 {
   uint32_t v = value * float_factor;
 
-  if (fabsf((float) v / float_factor - value) > 1.1 / float_factor) {
-    log_error("Trying to put %f with factor %d in 32 bits; "
-              "it will result %f at receiving side, having error of %f units.",
-              value, float_factor, (float) v / float_factor,
-              fabsf((float) v / float_factor - value) * float_factor);
-  }
+  FIELD_RANGE_TEST(fabsf((float) v / float_factor - value) > 1.1 / float_factor, ,
+                   "Trying to put %f with factor %d in 32 bits; "
+                   "it will result %f at receiving side, having error of %f units.",
+                   value, float_factor, (float) v / float_factor,
+                   fabsf((float) v / float_factor - value) * float_factor);
 
   dio_put_uint32(dout, v);
 }
@@ -397,12 +412,11 @@ void dio_put_sfloat(struct data_out *dout, float value, int float_factor)
 {
   int32_t v = value * float_factor;
 
-  if (fabsf((float) v / float_factor - value) > 1.1 / float_factor) {
-    log_error("Trying to put %f with factor %d in 32 bits; "
-              "it will result %f at receiving side, having error of %f units.",
-              value, float_factor, (float) v / float_factor,
-              fabsf((float) v / float_factor - value) * float_factor);
-  }
+  FIELD_RANGE_TEST(fabsf((float) v / float_factor - value) > 1.1 / float_factor, ,
+                   "Trying to put %f with factor %d in 32 bits; "
+                   "it will result %f at receiving side, having error of %f units.",
+                   value, float_factor, (float) v / float_factor,
+                   fabsf((float) v / float_factor - value) * float_factor);
 
   dio_put_sint32(dout, v);
 }
@@ -912,6 +926,7 @@ bool dio_get_worklist(struct data_in *din, struct worklist *pwl)
   for (i = 0; i < length; i++) {
     int identifier;
     int kind;
+    struct universal univ;
 
     if (!dio_get_uint8(din, &kind)
         || !dio_get_uint8(din, &identifier)) {
@@ -922,7 +937,8 @@ bool dio_get_worklist(struct data_in *din, struct worklist *pwl)
     /*
      * FIXME: the value returned by universal_by_number() should be checked!
      */
-    worklist_append(pwl, universal_by_number(kind, identifier));
+    univ = universal_by_number(kind, identifier);
+    worklist_append(pwl, &univ);
   }
 
   return TRUE;
@@ -979,19 +995,50 @@ bool dio_get_uint16_vec8(struct data_in *din, int **values, int stop_value)
   return TRUE;
 }
 
+/**************************************************************************
+  De-serialize an action probability.
+**************************************************************************/
+bool dio_get_action_probability(struct data_in *din,
+                                struct act_prob *aprob)
+{
+  int min, max;
+
+  if (!dio_get_uint8(din, &min)
+      || !dio_get_uint8(din, &max)) {
+    log_packet("Got a bad action probability");
+    return FALSE;
+  }
+
+  aprob->min = min;
+  aprob->max = max;
+
+  return TRUE;
+}
+
+/**************************************************************************
+  Serialize an action probability.
+**************************************************************************/
+void dio_put_action_probability(struct data_out *dout,
+                                const struct act_prob *aprob)
+{
+  dio_put_uint8(dout, aprob->min);
+  dio_put_uint8(dout, aprob->max);
+}
+
 /**************************************************************************
   De-serialize a requirement.
 **************************************************************************/
 bool dio_get_requirement(struct data_in *din, struct requirement *preq)
 {
   int type, range, value;
-  bool survives, negated;
+  bool survives, present, quiet;
 
   if (!dio_get_uint8(din, &type)
       || !dio_get_sint32(din, &value)
       || !dio_get_uint8(din, &range)
       || !dio_get_bool8(din, &survives)
-      || !dio_get_bool8(din, &negated)) {
+      || !dio_get_bool8(din, &present)
+      || !dio_get_bool8(din, &quiet)) {
     log_packet("Got a bad requirement");
     return FALSE;
   }
@@ -999,7 +1046,7 @@ bool dio_get_requirement(struct data_in *din, struct requirement *preq)
   /*
    * FIXME: the value returned by req_from_values() should be checked!
    */
-  *preq = req_from_values(type, range, survives, negated, value);
+  *preq = req_from_values(type, range, survives, present, quiet, value);
 
   return TRUE;
 }
@@ -1010,13 +1057,14 @@ bool dio_get_requirement(struct data_in *din, struct requirement *preq)
 void dio_put_requirement(struct data_out *dout, const struct requirement *preq)
 {
   int type, range, value;
-  bool survives, negated;
+  bool survives, present, quiet;
 
-  req_get_values(preq, &type, &range, &survives, &negated, &value);
+  req_get_values(preq, &type, &range, &survives, &present, &quiet, &value);
 
   dio_put_uint8(dout, type);
   dio_put_sint32(dout, value);
   dio_put_uint8(dout, range);
   dio_put_bool8(dout, survives);
-  dio_put_bool8(dout, negated);
+  dio_put_bool8(dout, present);
+  dio_put_bool8(dout, quiet);
 }
