@@ -1,4 +1,4 @@
-/********************************************************************** 
+/**********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@ extern "C" {
 
 #include <time.h>	/* time_t */
 
-#ifdef HAVE_SYS_TIME_H
+#ifdef FREECIV_HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
 
@@ -31,6 +31,7 @@ extern "C" {
 /* common */
 #include "connection.h"		/* struct conn_list */
 #include "fc_types.h"
+#include "map_types.h"
 #include "player.h"
 #include "packets.h"
 
@@ -58,7 +59,13 @@ enum autosave_type {
   AS_TURN = 0,
   AS_GAME_OVER,
   AS_QUITIDLE,
-  AS_INTERRUPT
+  AS_INTERRUPT,
+  AS_TIMER
+};
+
+enum scorelog_level {
+  SL_ALL = 0,
+  SL_HUMANS
 };
 
 struct user_flag
@@ -67,22 +74,25 @@ struct user_flag
   char *helptxt;
 };
 
-#define CONTAMINATION_POLLUTION 1
-#define CONTAMINATION_FALLOUT   2
-
 /* The number of turns that the first user needs to be attached to a 
  * player for that user to be ranked as that player */
 #define TURNS_NEEDED_TO_RANK 10
 
 struct civ_game {
   struct packet_ruleset_control control;
+  char *ruleset_summary;
+  char *ruleset_description;
   struct packet_scenario_info scenario;
+  struct packet_scenario_description scenario_desc;
   struct packet_game_info info;
+  struct packet_timeout_info tinfo;
 
+  struct government *default_government; /* may be overridden by nation */
   struct government *government_during_revolution;
 
   struct conn_list *all_connections;   /* including not yet established */
   struct conn_list *est_connections;   /* all established client conns */
+  struct conn_list *glob_observers;    /* global observers */
 
   struct veteran_system *veteran; /* veteran system */
 
@@ -95,8 +105,15 @@ struct civ_game {
     int global_init_buildings[MAX_NUM_BUILDING_LIST];
   } rgame;
 
+  struct civ_map map;
+
   union {
-    /* Add client side when needed */
+    struct {
+      /* Only used at the client (./client/). */
+
+      bool ruleset_init;
+      bool ruleset_ready;
+    } client;
 
     struct {
       /* Only used in the server (./ai/ and ./server/). */
@@ -105,7 +122,6 @@ struct civ_game {
 
       /* Game settings & other data. */
 
-      bool allied_victory;
       enum city_names_mode allowed_city_names;
       enum plrcolor_mode plrcolormode;
       int aqueductloss;
@@ -118,7 +134,8 @@ struct civ_game {
       int conquercost;
       int contactturns;
       int diplchance;
-      int diplcost;
+      int diplbulbcost;
+      int diplgoldcost;
       int dispersion;
       int end_turn;
       bool endspaceship;
@@ -140,10 +157,10 @@ struct civ_game {
       int mgr_turninterval;
       int mgr_worldchance;
       bool migration;
+      enum trait_dist_mode trait_dist;
       int min_players;
       bool natural_city_names;
       int netwait;
-      int nuke_contamination;
       int num_phases;
       int occupychance;
       int onsetbarbarian;
@@ -156,6 +173,7 @@ struct civ_game {
       int save_compress_level;
       enum fz_method save_compress_type;
       int save_nturns;
+      int save_frequency;
       unsigned autosaves; /* FIXME: char would be enough, but current settings.c code wants to
                              write sizeof(unsigned) bytes */
       bool savepalace;
@@ -163,7 +181,6 @@ struct civ_game {
       char start_units[MAX_LEN_STARTUNIT];
       bool start_city;
       int start_year;
-      int techloss_forgiveness;
       int techloss_restore;
       int techlost_donor;
       int techlost_recv;
@@ -188,11 +205,15 @@ struct civ_game {
        * use. The "stored" value is a value the player can change; it won't
        * take effect until the next turn. */
       int phase_mode_stored;
+      struct timer *save_timer;
+      float turn_change_time;
       char connectmsg[MAX_LEN_MSG];
       char save_name[MAX_LEN_NAME];
       bool scorelog;
+      enum scorelog_level scoreloglevel;
       char scorefile[MAX_LEN_NAME];
       int scoreturn;    /* next make_history_report() */
+      int seed_setting;
       int seed;
 
       bool global_warming;
@@ -200,6 +221,8 @@ struct civ_game {
 
       bool fogofwar_old; /* as the fog_of_war bit get changed by setting
                           * the server we need to remember the old setting */
+      bool last_updated_year; /* last_updated is still counted as year in this
+                               * game. */
       char rulesetdir[MAX_LEN_NAME];
       char demography[MAX_LEN_DEMOGRAPHY];
       char allow_take[MAX_LEN_ALLOW_TAKE];
@@ -217,8 +240,6 @@ struct civ_game {
 
       /* used by the map editor to control game_save. */
       struct {
-        bool save_random;
-
         bool save_known; /* loading will just reveal the squares around
                           * cities and units */
         bool save_starts; /* start positions will be auto generated */
@@ -228,13 +249,31 @@ struct civ_game {
       struct {
         bool user_message_set;
         char user_message[256];
+        char type[20];
       } meta_info;
 
       struct {
         fc_mutex city_list;
       } mutexes;
 
-      int first_timeout;
+      struct trait_limits default_traits[TRAIT_COUNT];
+
+      struct {
+        char *description_file;
+        char *nationlist;
+        char **embedded_nations;
+        size_t embedded_nations_count;
+        const char **allowed_govs;
+        char **nc_agovs;
+        size_t ag_count;
+        const char **allowed_terrains;
+        char **nc_aterrs;
+        size_t at_count;
+        const char **allowed_styles;
+        char **nc_astyles;
+        size_t as_count;
+        int named_teams;
+      } ruledit;
     } server;
   };
 
@@ -256,9 +295,6 @@ void game_reset(void);
 void game_ruleset_init(void);
 void game_ruleset_free(void);
 
-int game_next_year(int);
-void game_advance_year(void);
-
 int civ_population(const struct player *pplayer);
 struct city *game_city_by_name(const char *name);
 struct city *game_city_by_number(int id);
@@ -273,14 +309,14 @@ bool is_player_phase(const struct player *pplayer, int phase);
 
 const char *population_to_text(int thousand_citizen);
 
-const char *textyear(int year);
-
 int generate_save_name(const char *format, char *buf, int buflen,
                        const char *reason);
 
 void user_flag_init(struct user_flag *flag);
 void user_flag_free(struct user_flag *flag);
 
+int current_turn_timeout(void);
+
 extern struct civ_game game;
 
 #define GAME_DEFAULT_SEED        0
@@ -334,9 +370,13 @@ extern struct civ_game game;
 #define GAME_MIN_SCIENCEBOX 1
 #define GAME_MAX_SCIENCEBOX 10000
 
-#define GAME_DEFAULT_DIPLCOST        0
-#define GAME_MIN_DIPLCOST            0
-#define GAME_MAX_DIPLCOST            100
+#define GAME_DEFAULT_DIPLBULBCOST    0
+#define GAME_MIN_DIPLBULBCOST        0
+#define GAME_MAX_DIPLBULBCOST        100
+
+#define GAME_DEFAULT_DIPLGOLDCOST    0
+#define GAME_MIN_DIPLGOLDCOST        0
+#define GAME_MAX_DIPLGOLDCOST        100
 
 #define GAME_DEFAULT_FOGOFWAR        TRUE
 
@@ -347,7 +387,7 @@ extern struct civ_game game;
 
 #define GAME_DEFAULT_BORDERS         BORDERS_ENABLED
 
-#define GAME_DEFAULT_HAPPYBORDERS    TRUE
+#define GAME_DEFAULT_HAPPYBORDERS    HB_NATIONAL
 
 #define GAME_DEFAULT_DIPLOMACY       DIPLO_FOR_ALL
 
@@ -373,7 +413,7 @@ extern struct civ_game game;
 
 #define GAME_DEFAULT_CITYMINDIST     2
 #define GAME_MIN_CITYMINDIST         1
-#define GAME_MAX_CITYMINDIST         9
+#define GAME_MAX_CITYMINDIST         11
 
 #define GAME_DEFAULT_CIVILWARSIZE    10
 #define GAME_MIN_CIVILWARSIZE        2 /* can't split an empire of 1 city */
@@ -395,7 +435,9 @@ extern struct civ_game game;
 #define GAME_DEFAULT_DISASTERS       10
 #define GAME_MIN_DISASTERS           0
 #define GAME_MAX_DISASTERS           1000
- 
+
+#define GAME_DEFAULT_TRAIT_DIST_MODE TDM_FIXED
+
 #define GAME_DEFAULT_SAVEPALACE      TRUE
 
 #define GAME_DEFAULT_HOMECAUGHTUNITS TRUE
@@ -457,6 +499,7 @@ extern struct civ_game game;
 #define GAME_DEFAULT_REVEALMAP       REVEAL_MAP_NONE
 
 #define GAME_DEFAULT_SCORELOG        FALSE
+#define GAME_DEFAULT_SCORELOGLEVEL   SL_ALL
 #define GAME_DEFAULT_SCOREFILE       "freeciv-score.log"
 
 /* Turns between reports is random between SCORETURN and (2 x SCORETURN).
@@ -464,7 +507,7 @@ extern struct civ_game game;
  * first report is already generated at (SCORETURN - 1) */
 #define GAME_DEFAULT_SCORETURN       20
 
-#define GAME_DEFAULT_SPACERACE       TRUE
+#define GAME_DEFAULT_VICTORY_CONDITIONS (1 << VC_SPACERACE | 1 << VC_ALLIED)
 #define GAME_DEFAULT_END_SPACESHIP   TRUE
 
 #define GAME_DEFAULT_TURNBLOCK       TRUE
@@ -549,13 +592,17 @@ extern struct civ_game game;
 #define GAME_DEFAULT_SAVETURNS       1
 #define GAME_MIN_SAVETURNS           1
 #define GAME_MAX_SAVETURNS           200
+#define GAME_DEFAULT_SAVEFREQUENCY   15
+#define GAME_MIN_SAVEFREQUENCY       2
+#define GAME_MAX_SAVEFREQUENCY       1440
 
 #define GAME_DEFAULT_AUTOSAVES       (1 << AS_TURN | 1 << AS_GAME_OVER | 1 << AS_QUITIDLE | 1 << AS_INTERRUPT)
 
-#define GAME_DEFAULT_SKILL_LEVEL 3      /* easy */
-#define GAME_OLD_DEFAULT_SKILL_LEVEL 5  /* normal; for old save games */
+#define GAME_DEFAULT_SKILL_LEVEL     AI_LEVEL_EASY
+#define GAME_HARDCODED_DEFAULT_SKILL_LEVEL 3 /* that was 'easy' in old saves */
+#define GAME_OLD_DEFAULT_SKILL_LEVEL 5  /* normal; for oldest save games */
 
-#define GAME_DEFAULT_DEMOGRAPHY      "NASRLPEMOqrb"
+#define GAME_DEFAULT_DEMOGRAPHY      "NASRLPEMOCqrb"
 #define GAME_DEFAULT_ALLOW_TAKE      "HAhadOo"
 
 #define GAME_DEFAULT_EVENT_CACHE_TURNS    1
@@ -574,11 +621,11 @@ extern struct civ_game game;
 #define GAME_MIN_COMPRESS_LEVEL     1
 #define GAME_MAX_COMPRESS_LEVEL     9
 
-#if defined(HAVE_LIBBZ2)
+#if defined(FREECIV_HAVE_LIBBZ2)
 #  define GAME_DEFAULT_COMPRESS_TYPE FZ_BZIP2
-#elif defined(HAVE_LIBZ)
+#elif defined(FREECIV_HAVE_LIBZ)
 #  define GAME_DEFAULT_COMPRESS_TYPE FZ_ZLIB
-#elif defined(HAVE_LIBLZMA)
+#elif defined(FREECIV_HAVE_LIBLZMA)
 #  define GAME_DEFAULT_COMPRESS_TYPE FZ_XZ
 #else
 #  define GAME_DEFAULT_COMPRESS_TYPE FZ_PLAIN
@@ -588,18 +635,18 @@ extern struct civ_game game;
 
 #define GAME_DEFAULT_PLRCOLORMODE PLRCOL_PLR_ORDER
 
-#define GAME_DEFAULT_REVOLUTION_LENGTH 0
-#define GAME_MIN_REVOLUTION_LENGTH 0
-#define GAME_MAX_REVOLUTION_LENGTH 10
+#define GAME_DEFAULT_REVOLENTYPE        REVOLEN_RANDOM
+#define GAME_DEFAULT_REVOLUTION_LENGTH  5
+#define GAME_MIN_REVOLUTION_LENGTH      1
+#define GAME_MAX_REVOLUTION_LENGTH      20
 
 #define GAME_START_YEAR -4000
 
 #define GAME_DEFAULT_AIRLIFTINGSTYLE AIRLIFTING_CLASSICAL
+#define GAME_DEFAULT_PERSISTENTREADY PERSISTENTR_DISABLED
 
 #define GAME_MAX_READ_RECURSION 10 /* max recursion for the read command */
 
-#define GAME_DEFAULT_ALLIED_VICTORY TRUE
-
 #define GAME_DEFAULT_KICK_TIME 1800     /* 1800 seconds = 30 minutes. */
 #define GAME_MIN_KICK_TIME 0            /* 0 = disabling. */
 #define GAME_MAX_KICK_TIME 86400        /* 86400 seconds = 24 hours. */
@@ -647,6 +694,10 @@ extern struct civ_game game;
 #define RS_MIN_BORDER_SIZE_EFFECT                0
 #define RS_MAX_BORDER_SIZE_EFFECT                100
 
+#define RS_DEFAULT_BORDER_RADIUS_SQ_CITY_PERMANENT 0
+#define RS_MIN_BORDER_RADIUS_SQ_CITY_PERMANENT   (-CITY_MAP_MAX_RADIUS_SQ)
+#define RS_MAX_BORDER_RADIUS_SQ_CITY_PERMANENT   401 /* city radius 20 */
+
 #define RS_DEFAULT_INCITE_BASE_COST              1000
 #define RS_MIN_INCITE_BASE_COST                  0
 #define RS_MAX_INCITE_BASE_COST                  RS_MAX_VALUE
@@ -699,10 +750,6 @@ extern struct civ_game game;
 #define RS_MIN_FOOD_COST                         0
 #define RS_MAX_FOOD_COST                         100
 
-#define RS_DEFAULT_GOLD_UPKEEP_STYLE             0
-#define RS_MIN_GOLD_UPKEEP_STYLE                 0
-#define RS_MAX_GOLD_UPKEEP_STYLE                 2
-
 #define RS_DEFAULT_SLOW_INVASIONS                TRUE
 
 #define RS_DEFAULT_TIRED_ATTACK                  FALSE
@@ -729,13 +776,7 @@ extern struct civ_game game;
 #define RS_MIN_BASE_TECH_COST                    0
 #define RS_MAX_BASE_TECH_COST                    200
 
-#define RS_DEFAULT_TECH_COST_STYLE               0
-#define RS_MIN_TECH_COST_STYLE                   0
-#define RS_MAX_TECH_COST_STYLE                   4
-
-#define RS_DEFAULT_TECH_LEAKAGE                  0
-#define RS_MIN_TECH_LEAKAGE                      0
-#define RS_MAX_TECH_LEAKAGE                      3
+#define RS_DEFAULT_FORCE_TRADE_ROUTE             FALSE
 
 #ifdef __cplusplus
 }
