@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -67,7 +67,7 @@ struct government *government_by_rule_name(const char *name)
 /**************************************************************************
   Return the number of governments.
 **************************************************************************/
-int government_count(void)
+Government_type_id government_count(void)
 {
   return game.control.government_count;
 }
@@ -78,7 +78,7 @@ int government_count(void)
   Currently same as government_number(), paired with government_count()
   indicates use as an array index.
 **************************************************************************/
-int government_index(const struct government *pgovern)
+Government_type_id government_index(const struct government *pgovern)
 {
   fc_assert_ret_val(NULL != pgovern, -1);
   return pgovern - governments;
@@ -87,7 +87,7 @@ int government_index(const struct government *pgovern)
 /**************************************************************************
   Return the government index.
 **************************************************************************/
-int government_number(const struct government *pgovern)
+Government_type_id government_number(const struct government *pgovern)
 {
   fc_assert_ret_val(NULL != pgovern, -1);
   return pgovern->item_number;
@@ -99,7 +99,7 @@ int government_number(const struct government *pgovern)
   This function returns NULL for an out-of-range index (some callers
   rely on this).
 ****************************************************************************/
-struct government *government_by_number(const int gov)
+struct government *government_by_number(const Government_type_id gov)
 {
   if (gov < 0 || gov >= game.control.government_count) {
     return NULL;
@@ -132,7 +132,7 @@ struct government *government_of_city(const struct city *pcity)
 const char *government_rule_name(const struct government *pgovern)
 {
   fc_assert_ret_val(NULL != pgovern, NULL);
-  return rule_name(&pgovern->name);
+  return rule_name_get(&pgovern->name);
 }
 
 /****************************************************************************
@@ -142,7 +142,8 @@ const char *government_rule_name(const struct government *pgovern)
 const char *government_name_translation(const struct government *pgovern)
 {
   fc_assert_ret_val(NULL != pgovern, NULL);
-  return name_translation(&pgovern->name);
+
+  return name_translation_get(&pgovern->name);
 }
 
 /****************************************************************************
@@ -176,7 +177,7 @@ bool can_change_to_government(struct player *pplayer,
   }
 
   return are_reqs_active(pplayer, NULL, NULL, NULL, NULL, NULL, NULL,
-			 &gov->reqs, RPT_CERTAIN);
+                         NULL, NULL, &gov->reqs, RPT_CERTAIN);
 }
 
 
@@ -238,66 +239,70 @@ static bool ruler_title_check(const struct ruler_title *pruler_title)
 {
   bool ret = TRUE;
 
-  if (!formats_match(rule_name(&pruler_title->male), "%s")) {
+  if (!formats_match(rule_name_get(&pruler_title->male), "%s")) {
     if (NULL != pruler_title->pnation) {
       log_error("\"%s\" male ruler title for nation \"%s\" (nb %d) "
                 "is not a format. It should match \"%%s\"",
-                rule_name(&pruler_title->male),
+                rule_name_get(&pruler_title->male),
                 nation_rule_name(pruler_title->pnation),
                 nation_number(pruler_title->pnation));
     } else {
       log_error("\"%s\" male ruler title is not a format. "
                 "It should match \"%%s\"",
-                rule_name(&pruler_title->male));
+                rule_name_get(&pruler_title->male));
     }
     ret = FALSE;
   }
-  if (!formats_match(rule_name(&pruler_title->female), "%s")) {
+
+  if (!formats_match(rule_name_get(&pruler_title->female), "%s")) {
     if (NULL != pruler_title->pnation) {
       log_error("\"%s\" female ruler title for nation \"%s\" (nb %d) "
                 "is not a format. It should match \"%%s\"",
-                rule_name(&pruler_title->female),
+                rule_name_get(&pruler_title->female),
                 nation_rule_name(pruler_title->pnation),
                 nation_number(pruler_title->pnation));
     } else {
       log_error("\"%s\" female ruler title is not a format. "
                 "It should match \"%%s\"",
-                rule_name(&pruler_title->female));
+                rule_name_get(&pruler_title->female));
     }
     ret = FALSE;
   }
-  if (!formats_match(name_translation(&pruler_title->male), "%s")) {
+
+  if (!formats_match(name_translation_get(&pruler_title->male), "%s")) {
     if (NULL != pruler_title->pnation) {
       log_error("Translation of \"%s\" male ruler title for nation \"%s\" "
                 "(nb %d) is not a format (\"%s\"). It should match \"%%s\"",
-                rule_name(&pruler_title->male),
+                rule_name_get(&pruler_title->male),
                 nation_rule_name(pruler_title->pnation),
                 nation_number(pruler_title->pnation),
-                name_translation(&pruler_title->male));
+                name_translation_get(&pruler_title->male));
     } else {
       log_error("Translation of \"%s\" male ruler title is not a format "
                 "(\"%s\"). It should match \"%%s\"",
-                rule_name(&pruler_title->male),
-                name_translation(&pruler_title->male));
+                rule_name_get(&pruler_title->male),
+                name_translation_get(&pruler_title->male));
     }
     ret = FALSE;
   }
-  if (!formats_match(name_translation(&pruler_title->female), "%s")) {
+
+  if (!formats_match(name_translation_get(&pruler_title->female), "%s")) {
     if (NULL != pruler_title->pnation) {
       log_error("Translation of \"%s\" female ruler title for nation \"%s\" "
                 "(nb %d) is not a format (\"%s\"). It should match \"%%s\"",
-                rule_name(&pruler_title->female),
+                rule_name_get(&pruler_title->female),
                 nation_rule_name(pruler_title->pnation),
                 nation_number(pruler_title->pnation),
-                name_translation(&pruler_title->female));
+                name_translation_get(&pruler_title->female));
     } else {
       log_error("Translation of \"%s\" female ruler title is not a format "
                 "(\"%s\"). It should match \"%%s\"",
-                rule_name(&pruler_title->female),
-                name_translation(&pruler_title->female));
+                rule_name_get(&pruler_title->female),
+                name_translation_get(&pruler_title->female));
     }
     ret = FALSE;
   }
+
   return ret;
 }
 
@@ -409,9 +414,9 @@ const char *ruler_title_for_player(const struct player *pplayer,
     }
   } else {
     fc_snprintf(buf, buf_len,
-                name_translation(pplayer->is_male
-                                 ? &pruler_title->male
-                                 : &pruler_title->female),
+                name_translation_get(pplayer->is_male
+                                     ? &pruler_title->male
+                                     : &pruler_title->female),
                 player_name(pplayer));
   }
 
@@ -487,6 +492,7 @@ static inline void government_init(struct government *pgovern)
       ruler_title_hash_new_full(nation_hash_val, nation_hash_comp,
                                 NULL, NULL, NULL, ruler_title_destroy);
   requirement_vector_init(&pgovern->reqs);
+  pgovern->changed_to_times = 0;
 }
 
 /****************************************************************************
@@ -540,3 +546,18 @@ void governments_free(void)
   governments = NULL;
   game.control.government_count = 0;
 }
+
+/****************************************************************************
+  Is it possible to start a revolution without specifying the target
+  government in the current game?
+****************************************************************************/
+bool untargeted_revolution_allowed(void)
+{
+  if (game.info.revolentype == REVOLEN_QUICKENING
+      || game.info.revolentype == REVOLEN_RANDQUICK) {
+    /* We need to know the target government at the onset of the revolution
+     * in order to know how long anarchy will last. */
+    return FALSE;
+  }
+  return TRUE;
+}
