@@ -38,46 +38,107 @@
 #include "movement.h"
 
 /****************************************************************************
-  This function calculates the move rate of the unit, taking into 
-  account the penalty for reduced hitpoints (affects sea and land 
-  units only), the effects of wonders for sea units, and any veteran
+  This function calculates the move rate of the unit, taking into account
+  the penalty for reduced hitpoints, the active effects, and any veteran
   bonuses.
+
+  'utype' and 'pplayer' must be set. 'ptile' can be NULL.
 ****************************************************************************/
-int unit_move_rate(const struct unit *punit)
+int utype_move_rate(const struct unit_type *utype, const struct tile *ptile,
+                    const struct player *pplayer, int veteran_level,
+                    int hitpoints)
 {
-  int move_rate = 0;
-  int base_move_rate;
-  struct unit_class *pclass;
+  const struct unit_class *uclass;
   const struct veteran_level *vlevel;
+  int base_move_rate, move_rate;
 
-  fc_assert_ret_val(punit != NULL, 0);
+  fc_assert_ret_val(NULL != utype, 0);
+  fc_assert_ret_val(NULL != pplayer, 0);
+  vlevel = utype_veteran_level(utype, veteran_level);
+  fc_assert_ret_val(NULL != vlevel, 0);
+  uclass = utype_class(utype);
 
-  vlevel = utype_veteran_level(unit_type(punit), punit->veteran);
-  fc_assert_ret_val(vlevel != NULL, 0);
-
-  base_move_rate = unit_type(punit)->move_rate + vlevel->move_bonus;
+  base_move_rate = utype->move_rate + vlevel->move_bonus;
   move_rate = base_move_rate;
 
-  pclass = unit_class(punit);
-
-  if (uclass_has_flag(pclass, UCF_DAMAGE_SLOWS)) {
+  if (uclass_has_flag(uclass, UCF_DAMAGE_SLOWS)) {
     /* Scale the MP based on how many HP the unit has. */
-    move_rate = (move_rate * punit->hp) / unit_type(punit)->hp;
+    move_rate = (move_rate * hitpoints) / utype->hp;
   }
 
   /* Add on effects bonus (Magellan's Expedition, Lighthouse,
    * Nuclear Power). */
-  move_rate += (get_unit_bonus(punit, EFT_MOVE_BONUS) * SINGLE_MOVE);
+  move_rate += (get_unittype_bonus(pplayer, ptile, utype, EFT_MOVE_BONUS)
+                * SINGLE_MOVE);
 
   /* Don't let the move_rate be less than min_speed unless the base_move_rate is
    * also less than min_speed. */
-  if (move_rate < pclass->min_speed) {
-    move_rate = MIN(pclass->min_speed, base_move_rate);
+  if (move_rate < uclass->min_speed) {
+    move_rate = MIN(uclass->min_speed, base_move_rate);
   }
 
   return move_rate;
 }
 
+/****************************************************************************
+  This function calculates the move rate of the unit. See utype_move_rate()
+  for further details.
+****************************************************************************/
+int unit_move_rate(const struct unit *punit)
+{
+  fc_assert_ret_val(NULL != punit, 0);
+
+  return utype_move_rate(unit_type_get(punit), unit_tile(punit),
+                         unit_owner(punit), punit->veteran, punit->hp);
+}
+
+/****************************************************************************
+  This function calculates the movement cost to unknown tiles. The base
+  value is equal to the highest movement cost the unit can encounter. If
+  the unit cannot enter all terrains, a malus is applied.
+  The returned value is usually cached into utype->unknown_move_cost and
+  used in the path-finding module.
+****************************************************************************/
+int utype_unknown_move_cost(const struct unit_type *utype)
+{
+  const struct unit_class *uclass = utype_class(utype);
+  int move_cost;
+
+  if (!uclass_has_flag(uclass, UCF_TERRAIN_SPEED)) {
+    /* Unit is not subject to terrain movement costs. */
+    move_cost = SINGLE_MOVE;
+  } else if (utype_has_flag(utype, UTYF_IGTER)) {
+    /* All terrain movement costs are equal! */
+    move_cost = MOVE_COST_IGTER;
+  } else {
+    /* Unit is subject to terrain movement costs. */
+    move_cost = 1; /* Arbitrary minimum. */
+    terrain_type_iterate(pterrain) {
+      if (is_native_to_class(uclass, pterrain, NULL)
+          && pterrain->movement_cost > move_cost) {
+        /* Exact movement cost matters only if we can enter
+         * the tile. */
+        move_cost = pterrain->movement_cost;
+      }
+    } terrain_type_iterate_end;
+    move_cost *= SINGLE_MOVE; /* Real value. */
+  }
+
+  /* Let's see if we can cross over all terrain types, else apply a malus.
+   * We want units that may encounter unsuitable terrain explore less.
+   * N.B.: We don't take in account terrain no unit can enter here. */
+  terrain_type_iterate(pterrain) {
+    if (BV_ISSET_ANY(pterrain->native_to)
+        && !is_native_to_class(uclass, pterrain, NULL)) {
+      /* Units that may encounter unsuitable terrain explore less. */
+      move_cost *= 2;
+      break;
+    }
+  } terrain_type_iterate_end;
+
+  return move_cost;
+}
+
 
 /****************************************************************************
   Return TRUE iff the unit can be a defender at its current location.  This
@@ -116,41 +177,6 @@ bool can_attack_from_non_native(const struct unit_type *utype)
          || utype_has_flag(utype, UTYF_MARINES);
 }
 
-/****************************************************************************
-  Return TRUE iff the unit is a sailing/naval/sea/water unit.
-****************************************************************************/
-bool is_sailing_unit(const struct unit *punit)
-{
-  return (uclass_move_type(unit_class(punit)) == UMT_SEA);
-}
-
-
-/****************************************************************************
-  Return TRUE iff this unit is a ground/land/normal unit.
-****************************************************************************/
-bool is_ground_unit(const struct unit *punit)
-{
-  return (uclass_move_type(unit_class(punit)) == UMT_LAND);
-}
-
-
-/****************************************************************************
-  Return TRUE iff this unit type is a sailing/naval/sea/water unit type.
-****************************************************************************/
-bool is_sailing_unittype(const struct unit_type *punittype)
-{
-  return (utype_move_type(punittype) == UMT_SEA);
-}
-
-
-/****************************************************************************
-  Return TRUE iff this unit type is a ground/land/normal unit type.
-****************************************************************************/
-bool is_ground_unittype(const struct unit_type *punittype)
-{
-  return (utype_move_type(punittype) == UMT_LAND);
-}
-
 /****************************************************************************
   Check for a city channel.
 ****************************************************************************/
@@ -170,7 +196,7 @@ bool is_city_channel_tile(const struct unit_class *punitclass,
         continue;
       } else if (piter != pexclude
                  && is_native_to_class(punitclass, tile_terrain(piter),
-                                       tile_bases(piter), tile_roads(piter))) {
+                                       tile_extras(piter))) {
         found = TRUE;
         break;
       } else if (piter != pexclude
@@ -229,7 +255,7 @@ bool can_exist_at_tile(const struct unit_type *utype,
 bool can_unit_exist_at_tile(const struct unit *punit,
                             const struct tile *ptile)
 {
-  return can_exist_at_tile(unit_type(punit), ptile);
+  return can_exist_at_tile(unit_type_get(punit), ptile);
 }
 
 /****************************************************************************
@@ -241,32 +267,7 @@ bool is_native_tile(const struct unit_type *punittype,
                     const struct tile *ptile)
 {
   return is_native_to_class(utype_class(punittype), tile_terrain(ptile),
-                            tile_bases(ptile), tile_roads(ptile));
-}
-
-
-/****************************************************************************
-  This terrain is native to unit.
-
-  See is_native_to_class()
-****************************************************************************/
-bool is_native_terrain(const struct unit_type *punittype,
-                       const struct terrain *pterrain,
-                       const bv_bases *bases, const bv_roads *roads)
-{
-  return is_native_to_class(utype_class(punittype), pterrain, bases, roads);
-}
-
-/****************************************************************************
-  This tile is native to unit class.
-
-  See is_native_to_class()
-****************************************************************************/
-bool is_native_tile_to_class(const struct unit_class *punitclass,
-                             const struct tile *ptile)
-{
-  return is_native_to_class(punitclass, tile_terrain(ptile),
-                            tile_bases(ptile), tile_roads(ptile));
+                            tile_extras(ptile));
 }
 
 /****************************************************************************
@@ -275,7 +276,7 @@ bool is_native_tile_to_class(const struct unit_class *punitclass,
 ****************************************************************************/
 bool is_native_to_class(const struct unit_class *punitclass,
                         const struct terrain *pterrain,
-                        const bv_bases *bases, const bv_roads *roads)
+                        const bv_extras *extras)
 {
   if (!pterrain) {
     /* Unknown is considered native terrain */
@@ -286,21 +287,108 @@ bool is_native_to_class(const struct unit_class *punitclass,
     return TRUE;
   }
 
-  if (roads != NULL) {
-    road_type_list_iterate(punitclass->cache.native_tile_roads, proad) {
-      if (BV_ISSET(*roads, road_index(proad))) {
+  if (extras != NULL) {
+    extra_type_list_iterate(punitclass->cache.native_tile_extras, pextra) {
+      if (BV_ISSET(*extras, extra_index(pextra))) {
         return TRUE;
       }
-    } road_type_list_iterate_end;
+    } extra_type_list_iterate_end;
   }
 
-  if (bases != NULL) {
-    base_type_list_iterate(punitclass->cache.native_tile_bases, pbase) {
-      if (BV_ISSET(*bases, base_index(pbase))) {
+  return FALSE;
+}
+
+
+/****************************************************************************
+  Is the move under consideration a native move?
+  Note that this function does not check for possible moves, only native
+  moves, so that callers are responsible for checking for other sources of
+  legal moves (e.g. cities, transports, etc.).
+****************************************************************************/
+bool is_native_move(const struct unit_class *punitclass,
+                    const struct tile *src_tile,
+                    const struct tile *dst_tile)
+{
+  const struct road_type *proad;
+
+  if (is_native_to_class(punitclass, tile_terrain(dst_tile), NULL)) {
+    /* We aren't using extras to make the destination native. */
+    return TRUE;
+  } else if (!is_native_tile_to_class(punitclass, src_tile)) {
+    /* Disembarking or leaving port, so ignore road connectivity. */
+    return TRUE;
+  } else if (is_native_to_class(punitclass, tile_terrain(src_tile), NULL)) {
+    /* Native source terrain depends entirely on destination tile nativity. */
+    return is_native_tile_to_class(punitclass, dst_tile);
+  }
+
+  /* Check for non-road native extras on the source tile. */
+  extra_type_list_iterate(punitclass->cache.native_tile_extras, pextra) {
+    if (tile_has_extra(src_tile, pextra)
+        && !is_extra_caused_by(pextra, EC_ROAD)
+        && is_native_tile_to_class(punitclass, dst_tile)) {
+      /* If there is one, and the destination is native, the move is native. */
+      return TRUE;
+    }
+  } extra_type_list_iterate_end;
+
+  extra_type_list_iterate(punitclass->cache.native_tile_extras, pextra) {
+    if (!tile_has_extra(dst_tile, pextra)) {
+      continue;
+    } else if (!is_extra_caused_by(pextra, EC_ROAD)) {
+      /* The destination is native because of a non-road extra. */
+      return TRUE;
+    }
+
+    proad = extra_road_get(pextra);
+
+    if (road_has_flag(proad, RF_JUMP_TO)) {
+      extra_type_list_iterate(punitclass->cache.native_tile_extras, jextra) {
+        if (pextra != jextra
+            && is_extra_caused_by(jextra, EC_ROAD)
+            && tile_has_extra(src_tile, jextra)
+            && road_has_flag(jextra->data.road, RF_JUMP_FROM)) {
+          return TRUE;
+        }
+      } extra_type_list_iterate_end;
+    }
+
+    extra_type_list_iterate(proad->integrators, iextra) {
+      if (!tile_has_extra(src_tile, iextra)) {
+        continue;
+      }
+      if (ALL_DIRECTIONS_CARDINAL()) {
+        /* move_mode does not matter as all of them accept cardinal move */
         return TRUE;
       }
-    } base_type_list_iterate_end;
-  }
+      switch (extra_road_get(iextra)->move_mode) {
+      case RMM_FAST_ALWAYS:
+        /* Road connects source and destination, so we're fine. */
+        return TRUE;
+      case RMM_CARDINAL:
+        /* Road connects source and destination if cardinal move. */
+        if (is_move_cardinal(src_tile, dst_tile)) {
+          return TRUE;
+        }
+        break;
+      case RMM_RELAXED:
+        if (is_move_cardinal(src_tile, dst_tile)) {
+          /* Cardinal moves have no between tiles, so connected. */
+          return TRUE;
+        }
+        cardinal_between_iterate(src_tile, dst_tile, between) {
+          if (tile_has_extra(between, iextra)
+              || (pextra != iextra && tile_has_extra(between, pextra))) {
+            /* We have a link for the connection.
+             * 'pextra != iextra' is there just to avoid tile_has_extra()
+             * in by far more common case that 'pextra == iextra' */
+            return TRUE;
+          }
+        } cardinal_between_iterate_end;
+        break;
+      }
+    } extra_type_list_iterate_end;
+  } extra_type_list_iterate_end;
 
   return FALSE;
 }
@@ -343,12 +431,12 @@ bool can_unit_survive_at_tile(const struct unit *punit,
     return TRUE;
   }
 
-  if (tile_has_native_base(ptile, unit_type(punit))) {
-    /* Unit can always survive at native base */
+  if (tile_has_refuel_extra(ptile, unit_type_get(punit))) {
+    /* Unit can always survive at refueling base */
     return TRUE;
   }
 
-  if (utype_fuel(unit_type(punit))) {
+  if (utype_fuel(unit_type_get(punit))) {
     /* Unit requires fuel and this is not refueling tile */
     return FALSE;
   }
@@ -388,10 +476,11 @@ bool can_step_taken_wrt_to_zoc(const struct unit_type *punittype,
   if (tile_city(src_tile) || tile_city(dst_tile)) {
     return TRUE;
   }
-  if (is_ocean_tile(src_tile)
-      || is_ocean_tile(dst_tile)) {
+  if (terrain_has_flag(tile_terrain(src_tile), TER_NO_ZOC)
+      || terrain_has_flag(tile_terrain(dst_tile), TER_NO_ZOC)) {
     return TRUE;
   }
+
   return (is_my_zoc(unit_owner, src_tile)
 	  || is_my_zoc(unit_owner, dst_tile));
 }
@@ -405,7 +494,7 @@ static bool zoc_ok_move_gen(const struct unit *punit,
                             const struct tile *src_tile,
                             const struct tile *dst_tile)
 {
-  return can_step_taken_wrt_to_zoc(unit_type(punit), unit_owner(punit),
+  return can_step_taken_wrt_to_zoc(unit_type_get(punit), unit_owner(punit),
 				   src_tile, dst_tile);
 }
 
@@ -434,7 +523,7 @@ bool unit_can_move_to_tile(const struct unit *punit,
 {
   return (MR_OK == unit_move_to_tile_test(punit,
                                           punit->activity, unit_tile(punit),
-                                          dst_tile, igzoc));
+                                          dst_tile, igzoc, NULL));
 }
 
 /**************************************************************************
@@ -446,26 +535,29 @@ bool unit_can_move_to_tile(const struct unit *punit,
     1) The unit is idle or on server goto.
     2) The target location is next to the unit.
     3) There are no non-allied units on the target tile.
-    4) Unit can move to a tile where it can't survive on its own if there
+    4) Animals cannot move out from home terrains
+    5) Unit can move to a tile where it can't survive on its own if there
        is free transport capacity.
-    5) Some units cannot take over a city.
-    6) Only units permitted to attack from non-native tiles may do so.
-    7) There are no peaceful but un-allied units on the target tile.
-    8) There is not a peaceful but un-allied city on the target tile.
-    9) There is no non-allied unit blocking (zoc) [or igzoc is true].
-   10) Triremes cannot move out of sight from land.
-   11) It is not the territory of a player we are at peace with.
-   12) The unit is unable to disembark from current transporter.
+    6) Some units cannot take over a city.
+    7) Only units permitted to attack from non-native tiles may do so.
+    8) There are no peaceful but non allied units on the target tile.
+    9) There is not a peaceful but non allied city on the target tile.
+   10) There is no non-allied unit blocking (zoc) [or igzoc is true].
+   11) Triremes cannot move out of sight from land.
+   12) It is not the territory of a player we are at peace with.
+   13) The unit is unable to disembark from current transporter.
+   14) The unit is making a non-native move (e.g. lack of road)
 **************************************************************************/
 enum unit_move_result
 unit_move_to_tile_test(const struct unit *punit,
                        enum unit_activity activity,
                        const struct tile *src_tile,
-                       const struct tile *dst_tile, bool igzoc)
+                       const struct tile *dst_tile, bool igzoc,
+                       struct unit *embark_to)
 {
   bool zoc;
   struct city *pcity;
-  const struct unit_type *punittype = unit_type(punit);
+  const struct unit_type *punittype = unit_type_get(punit);
   const struct player *puowner = unit_owner(punit);
 
   /* 1) */
@@ -489,21 +581,31 @@ unit_move_to_tile_test(const struct unit *punit,
   }
 
   /* 4) */
-  if (!(can_exist_at_tile(punittype, dst_tile)
-        || NULL != transport_from_tile(punit, dst_tile))) {
+  if (puowner->ai_common.barbarian_type == ANIMAL_BARBARIAN
+      && dst_tile->terrain->animal != punittype) {
+    return MR_ANIMAL_DISALLOWED;
+  }
+
+  /* 5) */
+  if (embark_to != NULL) {
+    if (!could_unit_load(punit, embark_to)) {
+      return MR_NO_TRANSPORTER_CAPACITY;
+    }
+  } else if (!(can_exist_at_tile(punittype, dst_tile)
+               || unit_could_load_at(punit, dst_tile))) {
     return MR_NO_TRANSPORTER_CAPACITY;
   }
 
   pcity = is_enemy_city_tile(dst_tile, puowner);
   if (NULL != pcity) {
-    /* 5) */
-    if (!utype_can_take_over(punittype)) {
+    /* 6) */
+    if (!unit_can_take_over(punit)) {
       return MR_BAD_TYPE_FOR_CITY_TAKE_OVER;
     } else {
       /* No point checking for being able to take over from non-native
        * for units that can't take over a city anyway. */
 
-      /* 6) */
+      /* 7) */
       if (!can_exist_at_tile(punittype, src_tile)
           && !can_attack_from_non_native(punittype)) {
         /* Don't use is_native_tile() because any unit in an
@@ -513,7 +615,7 @@ unit_move_to_tile_test(const struct unit *punit,
     }
   }
 
-  /* 7) */
+  /* 8) */
   if (is_non_attack_unit_tile(dst_tile, puowner)) {
     /* You can't move into a non-allied tile.
      *
@@ -522,7 +624,7 @@ unit_move_to_tile_test(const struct unit *punit,
     return MR_NO_WAR;
   }
 
-  /* 8) */
+  /* 9) */
   pcity = tile_city(dst_tile);
   if (pcity && pplayers_non_attack(city_owner(pcity), puowner)) {
     /* You can't move into an empty city of a civilization you're at
@@ -530,7 +632,7 @@ unit_move_to_tile_test(const struct unit *punit,
     return MR_NO_WAR;
   }
 
-  /* 9) */
+  /* 10) */
   zoc = igzoc
     || can_step_taken_wrt_to_zoc(punittype, puowner, src_tile, dst_tile);
   if (!zoc) {
@@ -538,23 +640,31 @@ unit_move_to_tile_test(const struct unit *punit,
     return MR_ZOC;
   }
 
-  /* 10) */
+  /* 11) */
   if (utype_has_flag(punittype, UTYF_TRIREME) && !is_safe_ocean(dst_tile)) {
     return MR_TRIREME;
   }
 
-  /* 11) */
+  /* 12) */
   if (!utype_has_flag(punittype, UTYF_CIVILIAN)
       && !player_can_invade_tile(puowner, dst_tile)) {
     return MR_PEACE;
   }
 
-  /* 12) */
+  /* 13) */
   if (unit_transported(punit)
      && !can_unit_unload(punit, unit_transport_get(punit))) {
     return MR_CANNOT_DISEMBARK;
   }
 
+  /* 14) */
+  if (!(is_native_move(utype_class(punittype), src_tile, dst_tile)
+        /* Allow non-native moves into cities or boarding transport. */
+        || pcity
+        || unit_could_load_at(punit, dst_tile))) {
+    return MR_NON_NATIVE_MOVE;
+  }
+
   return MR_OK;
 }
 
@@ -567,7 +677,8 @@ bool can_unit_transport(const struct unit *transporter,
   fc_assert_ret_val(transporter != NULL, FALSE);
   fc_assert_ret_val(transported != NULL, FALSE);
 
-  return can_unit_type_transport(unit_type(transporter), unit_class(transported));
+  return can_unit_type_transport(unit_type_get(transporter),
+                                 unit_class_get(transported));
 }
 
 /**************************************************************************
@@ -584,44 +695,47 @@ bool can_unit_type_transport(const struct unit_type *transporter,
 }
 
 /****************************************************************************
-  Return the first transporter suitable for given unit from tile. It needs
-  to have free space. To find the best transporter, see
-  transporter_for_unit().
+  Return whether we can find a suitable transporter for given unit at
+  current location. It needs to have free space. To find the best transporter,
+  see transporter_for_unit().
 ****************************************************************************/
-struct unit *transport_from_tile(const struct unit *punit,
-                                 const struct tile *ptile)
+bool unit_can_load(const struct unit *punit)
 {
-  unit_list_iterate(ptile->units, ptransport) {
-    if (could_unit_load(punit, ptransport)) {
-      return ptransport;
+  if (unit_transported(punit)) {
+    /* In another transport already. Can it unload first? */
+    if (!can_unit_unload(punit, punit->transporter)) {
+      return FALSE;
     }
-  } unit_list_iterate_end;
+  }
 
-  return NULL;
-}
- 
-/**************************************************************************
- Returns the number of free spaces for units of given class.
- Can be 0.
-**************************************************************************/
-int unit_class_transporter_capacity(const struct tile *ptile,
-                                    const struct player *pplayer,
-                                    const struct unit_class *pclass)
-{
-  int availability = 0;
-
-  unit_list_iterate(ptile->units, punit) {
-    if (unit_owner(punit) == pplayer
-        || pplayers_allied(unit_owner(punit), pplayer)) {
-
-      if (can_unit_type_transport(unit_type(punit), pclass)) {
-        availability += get_transporter_capacity(punit);
-        availability -= get_transporter_occupancy(punit);
+  unit_list_iterate(unit_tile(punit)->units, ptransport) {
+    /* could_unit_load() instead of can_unit_load() since latter
+     * would check against unit already being transported, and we need
+     * to support unload+load to a new transport. */
+    if (ptransport != punit->transporter) {
+      if (could_unit_load(punit, ptransport)) {
+        return TRUE;
       }
     }
   } unit_list_iterate_end;
 
-  return availability;
+  return FALSE;
+}
+
+/****************************************************************************
+  Return whether we could find a suitable transporter for given unit at
+  'ptile'. It needs to have free space. To find the best transporter, see
+  transporter_for_unit_at().
+****************************************************************************/
+bool unit_could_load_at(const struct unit *punit, const struct tile *ptile)
+{
+  unit_list_iterate(ptile->units, ptransport) {
+    if (could_unit_load(punit, ptransport)) {
+      return TRUE;
+    }
+  } unit_list_iterate_end;
+
+  return FALSE;
 }
 
 static int move_points_denomlen = 0;
