@@ -146,6 +146,7 @@ const char *research_rule_name(const struct research *presearch)
 
 /****************************************************************************
   Returns the name of the research owner: a player name or a team name.
+  For most uses you probably want research_pretty_name() instead.
 ****************************************************************************/
 const char *research_name_translation(const struct research *presearch)
 {
@@ -172,7 +173,8 @@ int research_pretty_name(const struct research *presearch, char *buf,
       char buf2[buf_len];
 
       team_pretty_name(pteam, buf2, sizeof(buf2));
-      /* TRANS: e.g. "members of team 1", or even "members of team Red". */
+      /* TRANS: e.g. "members of team 1", or even "members of team Red".
+       * Used in many places where a nation plural might be used. */
       return fc_snprintf(buf, buf_len, _("members of %s"), buf2);
     } else {
       pplayer = player_list_front(team_members(pteam));
@@ -720,6 +722,8 @@ int research_total_bulbs_required(const struct research *presearch,
       break;
     }
 
+    fc_assert(presearch != NULL);
+    fc__fallthrough; /* No break; Fallback to using preset cost. */
   case TECH_COST_CLASSIC:
   case TECH_COST_CLASSIC_PRESET:
   case TECH_COST_EXPERIMENTAL:
