@@ -38,13 +38,12 @@
 
 #include "api_game_methods.h"
 
-
 /*****************************************************************************
   Return the current turn.
 *****************************************************************************/
 int api_methods_game_turn(lua_State *L)
 {
-  LUASCRIPT_CHECK_STATE(L, FALSE);
+  LUASCRIPT_CHECK_STATE(L, 0);
 
   return game.info.turn;
 }
@@ -122,14 +121,13 @@ const char
   return improvement_name_translation(pbuilding);
 }
 
-
 /*****************************************************************************
   Return TRUE iff city has building
 *****************************************************************************/
 bool api_methods_city_has_building(lua_State *L, City *pcity,
                                    Building_Type *building)
 {
-  LUASCRIPT_CHECK_STATE(L, NULL);
+  LUASCRIPT_CHECK_STATE(L, FALSE);
   LUASCRIPT_CHECK_SELF(L, pcity, FALSE);
   LUASCRIPT_CHECK_ARG_NIL(L, building, 3, Building_Type, FALSE);
 
@@ -229,10 +227,11 @@ int api_methods_city_culture_get(lua_State *L, City *pcity)
 *****************************************************************************/
 bool api_methods_is_city_happy(lua_State *L, City *pcity)
 {
-  LUASCRIPT_CHECK_STATE(L, NULL);
+  LUASCRIPT_CHECK_STATE(L, FALSE);
   LUASCRIPT_CHECK_SELF(L, pcity, FALSE);
 
-  return city_happy(pcity);
+  /* Note: if clients ever have virtual cities or sth, needs amending */
+  return is_server() ? city_happy(pcity) : pcity->client.happy;
 }
 
 /*****************************************************************************
@@ -240,10 +239,11 @@ bool api_methods_is_city_happy(lua_State *L, City *pcity)
 *****************************************************************************/
 bool api_methods_is_city_unhappy(lua_State *L, City *pcity)
 {
-  LUASCRIPT_CHECK_STATE(L, NULL);
+  LUASCRIPT_CHECK_STATE(L, FALSE);
   LUASCRIPT_CHECK_SELF(L, pcity, FALSE);
 
-  return city_unhappy(pcity);
+  /* Note: if clients ever have virtual cities or sth, needs amending */
+  return is_server() ? city_unhappy(pcity) : pcity->client.unhappy;
 }
 
 /*****************************************************************************
@@ -251,7 +251,7 @@ bool api_methods_is_city_unhappy(lua_State *L, City *pcity)
 *****************************************************************************/
 bool api_methods_is_city_celebrating(lua_State *L, City *pcity)
 {
-  LUASCRIPT_CHECK_STATE(L, NULL);
+  LUASCRIPT_CHECK_STATE(L, FALSE);
   LUASCRIPT_CHECK_SELF(L, pcity, FALSE);
 
   return city_celebrating(pcity);
@@ -262,7 +262,7 @@ bool api_methods_is_city_celebrating(lua_State *L, City *pcity)
 *****************************************************************************/
 bool api_methods_is_gov_center(lua_State *L, City *pcity)
 {
-  LUASCRIPT_CHECK_STATE(L, NULL);
+  LUASCRIPT_CHECK_STATE(L, FALSE);
   LUASCRIPT_CHECK_SELF(L, pcity, FALSE);
 
   return is_gov_center(pcity);
@@ -273,7 +273,7 @@ bool api_methods_is_gov_center(lua_State *L, City *pcity)
 *****************************************************************************/
 bool api_methods_is_capital(lua_State *L, City *pcity)
 {
-  LUASCRIPT_CHECK_STATE(L, NULL);
+  LUASCRIPT_CHECK_STATE(L, FALSE);
   LUASCRIPT_CHECK_SELF(L, pcity, FALSE);
 
   return is_capital(pcity);
@@ -303,7 +303,6 @@ const char *api_methods_government_name_translation(lua_State *L,
   return government_name_translation(pgovernment);
 }
 
-
 /*****************************************************************************
   Return rule name for Nation_Type
 *****************************************************************************/
@@ -440,8 +439,8 @@ bool api_methods_player_shares_research(lua_State *L, Player *pplayer,
 *****************************************************************************/
 const char *api_methods_research_rule_name(lua_State *L, Player *pplayer)
 {
-  LUASCRIPT_CHECK_STATE(L, FALSE);
-  LUASCRIPT_CHECK_SELF(L, pplayer, FALSE);
+  LUASCRIPT_CHECK_STATE(L, NULL);
+  LUASCRIPT_CHECK_SELF(L, pplayer, NULL);
 
   return research_rule_name(research_get(pplayer));
 }
@@ -453,8 +452,8 @@ const char *api_methods_research_name_translation(lua_State *L, Player *pplayer)
 {
   static char buf[MAX_LEN_MSG];
 
-  LUASCRIPT_CHECK_STATE(L, FALSE);
-  LUASCRIPT_CHECK_SELF(L, pplayer, FALSE);
+  LUASCRIPT_CHECK_STATE(L, NULL);
+  LUASCRIPT_CHECK_SELF(L, pplayer, NULL);
 
   (void) research_pretty_name(research_get(pplayer), buf, ARRAY_SIZE(buf));
 
@@ -879,12 +878,12 @@ Tile *api_methods_unit_tile_get(lua_State *L, Unit *punit)
 /*****************************************************************************
   Get unit orientation
 *****************************************************************************/
-Direction api_methods_unit_orientation_get(lua_State *L, Unit *punit)
+const Direction *api_methods_unit_orientation_get(lua_State *L, Unit *punit)
 {
-  LUASCRIPT_CHECK_STATE(L, direction8_invalid());
-  LUASCRIPT_CHECK_ARG_NIL(L, punit, 2, Unit, direction8_invalid());
+  LUASCRIPT_CHECK_STATE(L, NULL);
+  LUASCRIPT_CHECK_ARG_NIL(L, punit, 2, Unit, NULL);
 
-  return punit->facing;
+  return luascript_dir(punit->facing);
 }
 
 /*****************************************************************************
