@@ -23,6 +23,7 @@
 /* common */
 #include "fc_interface.h"
 #include "game.h"
+#include "map.h"
 #include "movement.h"
 #include "road.h"
 #include "unit.h"
@@ -30,8 +31,7 @@
 
 #include "tile.h"
 
-static bv_bases empty_bases;
-static bv_roads empty_roads;
+static bv_extras empty_extras;
 
 #ifndef tile_index
 /****************************************************************************
@@ -139,106 +139,44 @@ void tile_set_terrain(struct tile *ptile, struct terrain *pterrain)
                 "At (%d, %d), the terrain \"%s\" (nb %d) doesn't "
                 "support cities, whereas \"%s\" (nb %d) is built there.",
                 TILE_XY(ptile), terrain_rule_name(pterrain),
-                terrain_number(pterrain), city_name(tile_city(ptile)),
+                terrain_number(pterrain), city_name_get(tile_city(ptile)),
                 tile_city(ptile)->id);
 
   ptile->terrain = pterrain;
   if (NULL != pterrain
-   && NULL != ptile->resource
-   && terrain_has_resource(pterrain, ptile->resource)) {
-    /* cannot use set_special() for internal values */
-    BV_SET(ptile->special, S_RESOURCE_VALID);
+      && NULL != ptile->resource
+      && terrain_has_resource(pterrain, ptile->resource)) {
+    ptile->resource_valid = TRUE;
   } else {
-    BV_CLR(ptile->special, S_RESOURCE_VALID);
+    ptile->resource_valid = FALSE;
   }
 }
 
 /****************************************************************************
-  Return the specials of the tile.  See terrain.h.
-
-  Note that this returns a mask of _all_ the specials on the tile.  To
-  check a specific special use tile_has_special.
+  Returns a bit vector of the extras present at NULL tile.
 ****************************************************************************/
-bv_special tile_specials(const struct tile *ptile)
+const bv_extras *tile_extras_null(void)
 {
-  return ptile->special;
+  static bool empty_cleared = FALSE;
+
+  if (!empty_cleared) {
+    BV_CLR_ALL(empty_extras);
+    empty_cleared = TRUE;
+  }
+
+  return &(empty_extras);  
 }
 
 /****************************************************************************
-  Sets the tile's specials to those present in the given bit vector.
+  Returns a bit vector of the extras present at the tile.
 ****************************************************************************/
-void tile_set_specials(struct tile *ptile, bv_special specials)
+const bv_extras *tile_extras_safe(const struct tile *ptile)
 {
   if (!ptile) {
-    return;
-  }
-  ptile->special = specials;
-}
-
-/****************************************************************************
-  Returns TRUE iff the given tile has the given special.
-****************************************************************************/
-bool tile_has_special(const struct tile *ptile,
-		      enum tile_special_type special)
-{
-  return contains_special(ptile->special, special);
-}
-
-/****************************************************************************
-  Returns TRUE iff the given tile has any specials.
-****************************************************************************/
-bool tile_has_any_specials(const struct tile *ptile)
-{
-  return contains_any_specials(ptile->special);
-}
-
-/****************************************************************************
-  Returns a bit vector of the bases present at the tile.
-****************************************************************************/
-const bv_bases *tile_bases(const struct tile *ptile)
-{
-  if (!ptile) {
-    static bool empty_cleared = FALSE;
-
-    if (!empty_cleared) {
-      BV_CLR_ALL(empty_bases);
-      empty_cleared = TRUE;
-    }
-
-    return &empty_bases;
+    return tile_extras_null();
   }
 
-  return &(ptile->bases);
-}
-
-/****************************************************************************
-  Returns a bit vector of the roads present at the tile.
-****************************************************************************/
-const bv_roads *tile_roads(const struct tile *ptile)
-{
-  if (!ptile) {
-    static bool empty_cleared = FALSE;
-
-    if (!empty_cleared) {
-      BV_CLR_ALL(empty_roads);
-      empty_cleared = TRUE;
-    }
-
-    return &empty_roads;
-  }
-
-  return &(ptile->roads);
-}
-
-/****************************************************************************
-  Set the bases on the tile to those present in the given bit vector.
-****************************************************************************/
-void tile_set_bases(struct tile *ptile, bv_bases bases)
-{
-  if (!ptile) {
-    return;
-  }
-  ptile->bases = bases;
+  return &(ptile->extras);
 }
 
 /****************************************************************************
@@ -247,7 +185,7 @@ void tile_set_bases(struct tile *ptile, bv_bases bases)
 ****************************************************************************/
 void tile_add_base(struct tile *ptile, const struct base_type *pbase)
 {
-  BV_SET(ptile->bases, base_index(pbase));
+  tile_add_extra(ptile, base_extra_get(pbase));
 }
 
 /****************************************************************************
@@ -255,7 +193,7 @@ void tile_add_base(struct tile *ptile, const struct base_type *pbase)
 ****************************************************************************/
 void tile_remove_base(struct tile *ptile, const struct base_type *pbase)
 {
-  BV_CLR(ptile->bases, base_index(pbase));
+  tile_remove_extra(ptile, base_extra_get(pbase));
 }
 
 /****************************************************************************
@@ -263,11 +201,13 @@ void tile_remove_base(struct tile *ptile, const struct base_type *pbase)
 ****************************************************************************/
 bool tile_has_base_flag(const struct tile *ptile, enum base_flag_id flag)
 {
-  base_type_iterate(pbase) {
-    if (tile_has_base(ptile, pbase) && base_has_flag(pbase, flag)) {
+  extra_type_by_cause_iterate(EC_BASE, pextra) {
+    struct base_type *pbase = extra_base_get(pextra);
+
+    if (tile_has_extra(ptile, pextra) && base_has_flag(pbase, flag)) {
       return TRUE;
     }
-  } base_type_iterate_end;
+  } extra_type_by_cause_iterate_end;
 
   return FALSE;
 }
@@ -279,12 +219,14 @@ bool tile_has_base_flag_for_unit(const struct tile *ptile,
                                  const struct unit_type *punittype,
                                  enum base_flag_id flag)
 {
-  base_type_iterate(pbase) {
-    if (tile_has_base(ptile, pbase)
+  extra_type_by_cause_iterate(EC_BASE, pextra) {
+    struct base_type *pbase = extra_base_get(pextra);
+
+    if (tile_has_extra(ptile, pextra)
         && base_has_flag_for_utype(pbase, flag, punittype)) {
       return TRUE;
     }
-  } base_type_iterate_end;
+  } extra_type_by_cause_iterate_end;
 
   return FALSE;
 }
@@ -295,13 +237,15 @@ bool tile_has_base_flag_for_unit(const struct tile *ptile,
 bool tile_has_claimable_base(const struct tile *ptile,
                              const struct unit_type *punittype)
 {
-  base_type_iterate(pbase) {
-    if (tile_has_base(ptile, pbase)
+  extra_type_by_cause_iterate(EC_BASE, pextra) {
+    struct base_type *pbase = extra_base_get(pextra);
+
+    if (tile_has_extra(ptile, pextra)
         && territory_claiming_base(pbase)
-        && is_native_base_to_uclass(pbase, utype_class(punittype))) {
+        && is_native_extra_to_uclass(pextra, utype_class(punittype))) {
       return TRUE;
     }
-  } base_type_iterate_end;
+  } extra_type_by_cause_iterate_end;
 
   return FALSE;
 }
@@ -316,28 +260,32 @@ int tile_extras_defense_bonus(const struct tile *ptile,
 }
 
 /****************************************************************************
-  Calculate defense bonus given for unit class by bases and roads
+  Calculate defense bonus given for unit class by extras.
 ****************************************************************************/
 int tile_extras_class_defense_bonus(const struct tile *ptile,
                                     const struct unit_class *pclass)
 {
-  int bonus = 0;
+  int natural_bonus = 0;
+  int fortification_bonus = 0;
+  int total_bonus;
 
-  base_type_iterate(pbase) {
-    if (tile_has_base(ptile, pbase)
-        && is_native_base_to_uclass(pbase, pclass)) {
-      bonus += pbase->defense_bonus;
+  extra_type_by_cause_iterate(EC_NATURAL_DEFENSIVE, pextra) {
+    if (tile_has_extra(ptile, pextra)
+        && is_native_extra_to_uclass(pextra, pclass)) {
+      natural_bonus += pextra->defense_bonus;
     }
-  } base_type_iterate_end;
+  } extra_type_by_cause_iterate_end;
 
-  road_type_iterate(proad) {
-    if (tile_has_road(ptile, proad)
-        && is_native_road_to_uclass(proad, pclass)) {
-      bonus += proad->defense_bonus;
+  extra_type_by_cause_iterate(EC_DEFENSIVE, pextra) {
+    if (tile_has_extra(ptile, pextra)
+        && is_native_extra_to_uclass(pextra, pclass)) {
+      fortification_bonus += pextra->defense_bonus;
     }
-  } road_type_iterate_end;
+  } extra_type_by_cause_iterate_end;
 
-  return bonus;
+  total_bonus = (100 + natural_bonus) * (100 + fortification_bonus) / 100 - 100;
+
+  return total_bonus;
 }
 
 /****************************************************************************
@@ -348,12 +296,14 @@ int tile_roads_output_incr(const struct tile *ptile, enum output_type_id o)
   int const_incr = 0;
   int incr = 0;
 
-  road_type_iterate(proad) {
-    if (tile_has_road(ptile, proad)) {
+  extra_type_by_cause_iterate(EC_ROAD, pextra) {
+    if (tile_has_extra(ptile, pextra)) {
+      struct road_type *proad = extra_road_get(pextra);
+
       const_incr += proad->tile_incr_const[o];
       incr += proad->tile_incr[o];
     }
-  } road_type_iterate_end;
+  } extra_type_by_cause_iterate_end;
 
   return const_incr + incr * tile_terrain(ptile)->road_output_incr_pct[o] / 100;
 }
@@ -365,44 +315,50 @@ int tile_roads_output_bonus(const struct tile *ptile, enum output_type_id o)
 {
   int bonus = 0;
 
-  road_type_iterate(proad) {
-    if (tile_has_road(ptile, proad)) {
+  extra_type_by_cause_iterate(EC_ROAD, pextra) {
+    if (tile_has_extra(ptile, pextra)) {
+      struct road_type *proad = extra_road_get(pextra);
+
       bonus += proad->tile_bonus[o];
     }
-  } road_type_iterate_end;
+  } extra_type_by_cause_iterate_end;
 
   return bonus;
 }
 
+/****************************************************************************
+  Check if tile contains refuel extra native for unit
+****************************************************************************/
+bool tile_has_refuel_extra(const struct tile *ptile,
+                           const struct unit_type *punittype)
+{
+  extra_type_iterate(pextra) {
+    if (tile_has_extra(ptile, pextra)
+        && extra_has_flag(pextra, EF_REFUEL)
+        && is_native_extra_to_utype(pextra, punittype)) {
+      return TRUE;
+    }
+  } extra_type_iterate_end;
+
+  return FALSE;
+}
+
 /****************************************************************************
   Check if tile contains base native for unit
 ****************************************************************************/
 bool tile_has_native_base(const struct tile *ptile,
                           const struct unit_type *punittype)
 {
-  base_type_iterate(pbase) {
-    if (tile_has_base(ptile, pbase)
-        && is_native_base_to_utype(pbase, punittype)) {
+  extra_type_by_cause_iterate(EC_BASE, pextra) {
+    if (tile_has_extra(ptile, pextra)
+        && is_native_extra_to_utype(pextra, punittype)) {
       return TRUE;
     }
-  } base_type_iterate_end;
+  } extra_type_by_cause_iterate_end;
 
   return FALSE;
 }
 
-/****************************************************************************
-  Add the given special or specials to the tile.
-
-  Note that this does not erase any existing specials already on the tile
-  (see tile_clear_special or tile_clear_all_specials for that).  Also note
-  the special to be set may be a mask, so you can set more than one
-  special at a time (but this is not recommended).
-****************************************************************************/
-void tile_set_special(struct tile *ptile, enum tile_special_type spe)
-{
-  set_special(&ptile->special, spe);
-}
-
 #ifndef tile_resource
 /****************************************************************************
   Return the resource at the specified tile.
@@ -422,32 +378,12 @@ void tile_set_resource(struct tile *ptile, struct resource *presource)
   if (NULL != ptile->terrain
    && NULL != presource
    && terrain_has_resource(ptile->terrain, presource)) {
-    /* cannot use set_special() for internal values */
-    BV_SET(ptile->special, S_RESOURCE_VALID);
+    ptile->resource_valid = TRUE;
   } else {
-    BV_CLR(ptile->special, S_RESOURCE_VALID);
+    ptile->resource_valid = FALSE;
   }
 }
 
-/****************************************************************************
-  Clear the given special or specials from the tile.
-
-  This function clears all the specials set in the 'spe' mask from the
-  tile's set of specials.  All other specials are unaffected.
-****************************************************************************/
-void tile_clear_special(struct tile *ptile, enum tile_special_type spe)
-{
-  clear_special(&ptile->special, spe);
-}
-
-/****************************************************************************
-  Remove any and all specials from this tile.
-****************************************************************************/
-void tile_clear_all_specials(struct tile *ptile)
-{
-  clear_all_specials(&ptile->special);
-}
-
 #ifndef tile_continent
 /****************************************************************************
   Return the continent ID of the tile.  Typically land has a positive
@@ -485,10 +421,20 @@ enum known_type tile_get_known(const struct tile *ptile,
   }
 }
 
+/**************************************************************************
+  Returns TRUE iff the target_tile is seen by pow_player.
+**************************************************************************/
+bool tile_is_seen(const struct tile *target_tile,
+                  const struct player *pow_player)
+{
+  return tile_get_known(target_tile, pow_player) == TILE_KNOWN_SEEN;
+}
+
 /****************************************************************************
   Time to complete the given activity on the given tile.
 ****************************************************************************/
-int tile_activity_time(enum unit_activity activity, const struct tile *ptile)
+int tile_activity_time(enum unit_activity activity, const struct tile *ptile,
+                       struct extra_type *tgt)
 {
   struct terrain *pterrain = tile_terrain(ptile);
 
@@ -496,55 +442,47 @@ int tile_activity_time(enum unit_activity activity, const struct tile *ptile)
   fc_assert_ret_val(activity != ACTIVITY_FORTRESS
                     && activity != ACTIVITY_AIRBASE, FC_INFINITY);
 
-  /* ACTIVITY_BASE not handled here */
-  fc_assert_ret_val(activity != ACTIVITY_BASE, FC_INFINITY);
-  fc_assert_ret_val(activity != ACTIVITY_GEN_ROAD, FC_INFINITY);
-
   switch (activity) {
   case ACTIVITY_POLLUTION:
-    return pterrain->clean_pollution_time * ACTIVITY_FACTOR;
-  case ACTIVITY_MINE:
-    return pterrain->mining_time * ACTIVITY_FACTOR;
-  case ACTIVITY_IRRIGATE:
-    return pterrain->irrigation_time * ACTIVITY_FACTOR;
+  case ACTIVITY_FALLOUT:
+  case ACTIVITY_PILLAGE:
+    return terrain_extra_removal_time(pterrain, activity, tgt) * ACTIVITY_FACTOR;
   case ACTIVITY_TRANSFORM:
     return pterrain->transform_time * ACTIVITY_FACTOR;
-  case ACTIVITY_FALLOUT:
-    return pterrain->clean_fallout_time * ACTIVITY_FACTOR;
+  case ACTIVITY_IRRIGATE:
+  case ACTIVITY_MINE:
+  case ACTIVITY_BASE:
+  case ACTIVITY_GEN_ROAD:
+    return terrain_extra_build_time(pterrain, activity, tgt) * ACTIVITY_FACTOR;
   default:
     return 0;
   }
 }
 
 /****************************************************************************
-  Time to complete the base building activity on the given tile.
+  Create extra to tile.
 ****************************************************************************/
-int tile_activity_base_time(const struct tile *ptile,
-                            Base_type_id base)
+static void tile_create_extra(struct tile *ptile, struct extra_type *pextra)
 {
-  struct terrain *pterrain = tile_terrain(ptile);
-
-  return terrain_base_time(pterrain, base) * ACTIVITY_FACTOR;
+  if (fc_funcs->create_extra != NULL) {
+    /* Assume callback calls tile_add_extra() itself. */
+    fc_funcs->create_extra(ptile, pextra, NULL);
+  } else {
+    tile_add_extra(ptile, pextra);
+  }
 }
 
 /****************************************************************************
-  Time to complete the road building activity on the given tile.
+  Destroy extra from tile.
 ****************************************************************************/
-int tile_activity_road_time(const struct tile *ptile,
-                            Road_type_id road)
+static void tile_destroy_extra(struct tile *ptile, struct extra_type *pextra)
 {
-  struct terrain *pterrain = tile_terrain(ptile);
-
-  return terrain_road_time(pterrain, road) * ACTIVITY_FACTOR;
-}
-
-/****************************************************************************
-  Clear all "dirtiness" (pollution and fallout) from the tile.
-****************************************************************************/
-static void tile_clear_dirtiness(struct tile *ptile)
-{
-  tile_clear_special(ptile, S_POLLUTION);
-  tile_clear_special(ptile, S_FALLOUT);
+  if (fc_funcs->destroy_extra != NULL) {
+    /* Assume callback calls tile_remove_extra() itself. */
+    fc_funcs->destroy_extra(ptile, pextra);
+  } else {
+    tile_remove_extra(ptile, pextra);
+  }
 }
 
 /****************************************************************************
@@ -556,117 +494,133 @@ void tile_change_terrain(struct tile *ptile, struct terrain *pterrain)
 {
   tile_set_terrain(ptile, pterrain);
 
-  if (is_ocean(pterrain)) {
-    /* The code can't handle these specials in ocean. */
-    tile_clear_special(ptile, S_HUT);
-  }
-
-  if (terrain_has_flag(pterrain, TER_NO_POLLUTION)) {
-    tile_clear_dirtiness(ptile);
-  }
-
-  /* Clear mining/irrigation if resulting terrain type cannot support
-   * that feature. */
-  if (pterrain->mining_result != pterrain) {
-    tile_clear_special(ptile, S_MINE);
-  }
-
-  if (pterrain->irrigation_result != pterrain) {
-    tile_clear_special(ptile, S_IRRIGATION);
-    tile_clear_special(ptile, S_FARMLAND);
-  }
-
-  /* Clear unsupported bases. */
-  base_type_iterate(pbase) {
-    if (tile_has_base(ptile, pbase)
-        && !is_native_tile_to_base(pbase, ptile)) {
-      if (fc_funcs->destroy_base != NULL) {
-        /* Assume callback calls tile_remove_base() itself. */
-	fc_funcs->destroy_base(ptile, pbase);
-      } else {
-	tile_remove_base(ptile, pbase);
-      }
+  /* Remove unsupported extras */
+  extra_type_iterate(pextra) {
+    if (tile_has_extra(ptile, pextra)
+        && (!is_native_tile_to_extra(pextra, ptile)
+            || extra_has_flag(pextra, EF_TERR_CHANGE_REMOVES))) {
+      tile_destroy_extra(ptile, pextra);
     }
-  } base_type_iterate_end;
+  } extra_type_iterate_end;
+}
 
-  road_type_iterate(proad) {
-    if (tile_has_road(ptile, proad)
-        && !is_native_tile_to_road(proad, ptile)) {
-      tile_remove_road(ptile, proad);
+/****************************************************************************
+  Recursively add all extra dependencies to add given extra.
+****************************************************************************/
+static bool add_recursive_extras(struct tile *ptile, struct extra_type *pextra,
+                                 int rec)
+{
+  if (rec > MAX_EXTRA_TYPES) {
+    /* Infinite recursion */
+    return FALSE;
+  }
+
+  /* First place dependency extras */
+  extra_deps_iterate(&(pextra->reqs), pdep) {
+    if (!tile_has_extra(ptile, pdep)) {
+      add_recursive_extras(ptile, pdep, rec + 1);
     }
-  } road_type_iterate_end;
-}
+  } extra_deps_iterate_end;
 
-/****************************************************************************
-  Add the special to the tile.  This does secondary tile updates to
-  the tile.
-****************************************************************************/
-void tile_add_special(struct tile *ptile, enum tile_special_type special)
-{
-  fc_assert_ret(special != S_OLD_FORTRESS && special != S_OLD_AIRBASE);
-  fc_assert_ret(special != S_OLD_ROAD && special != S_OLD_RAILROAD && special != S_OLD_RIVER);
-
-  tile_set_special(ptile, special);
-
-  switch (special) {
-  case S_FARMLAND:
-    tile_add_special(ptile, S_IRRIGATION);
-    /* Fall through to irrigation */
-  case S_IRRIGATION:
-    tile_clear_special(ptile, S_MINE);
-    break;
-  case S_MINE:
-    tile_clear_special(ptile, S_IRRIGATION);
-    tile_clear_special(ptile, S_FARMLAND);
-    break;
-
-  case S_POLLUTION:
-  case S_HUT:
-  case S_FALLOUT:
-  default:
-    break;
+  /* Is tile native for extra after that? */
+  if (!is_native_tile_to_extra(pextra, ptile)) {
+    return FALSE;
   }
+
+  tile_create_extra(ptile, pextra);
+
+  return TRUE;
 }
 
 /****************************************************************************
-  Remove the special from the tile.  This does secondary tile updates to
-  the tile.
+  Recursively remove all extras depending on given extra.
 ****************************************************************************/
-void tile_remove_special(struct tile *ptile, enum tile_special_type special)
+static bool rm_recursive_extras(struct tile *ptile, struct extra_type *pextra,
+                                int rec)
 {
-  fc_assert_ret(special != S_OLD_FORTRESS && special != S_OLD_AIRBASE);
-  fc_assert_ret(special != S_OLD_ROAD && special != S_OLD_RAILROAD && special != S_OLD_RIVER);
-
-  tile_clear_special(ptile, special);
-
-  switch (special) {
-  case S_IRRIGATION:
-    tile_clear_special(ptile, S_FARMLAND);
-    break;
-
-  case S_MINE:
-  case S_POLLUTION:
-  case S_HUT:
-  case S_FARMLAND:
-  case S_FALLOUT:
-  default:
-    break;
+  if (rec > MAX_EXTRA_TYPES) {
+    /* Infinite recursion */
+    return FALSE;
   }
+
+  extra_type_iterate(pdepending) {
+    if (tile_has_extra(ptile, pdepending)) {
+      extra_deps_iterate(&(pdepending->reqs), pdep) {
+        if (pdep == pextra) {
+          /* Depends on what we are going to remove */
+          if (!rm_recursive_extras(ptile, pdepending, rec + 1)) {
+            return FALSE;
+          }
+        }
+      } extra_deps_iterate_end;
+    }
+  } extra_type_iterate_end;
+
+  tile_destroy_extra(ptile, pextra);
+
+  return TRUE;
 }
 
 /****************************************************************************
-  Build irrigation on the tile.  This may change the specials of the tile
+  Add extra and adjust other extras accordingly.
+
+  If not all necessary adjustments can be done, returns FALSE.
+  When problem occurs, changes to tile extras are not reverted.
+  Pass virtual tile to the function if you are not sure it will success
+  and don't want extras adjusted at all in case of failure.
+****************************************************************************/
+bool tile_extra_apply(struct tile *ptile, struct extra_type *tgt)
+{
+  /* Add extra with its dependencies */
+  if (!add_recursive_extras(ptile, tgt, 0)) {
+    return FALSE;
+  }
+
+  /* Remove conflicting extras */
+  extra_type_iterate(pextra) {
+    if (tile_has_extra(ptile, pextra)
+        && !can_extras_coexist(pextra, tgt)) {
+      tile_destroy_extra(ptile, pextra);
+    }
+  } extra_type_iterate_end;
+
+  return TRUE;
+}
+
+/****************************************************************************
+  Remove extra and adjust other extras accordingly.
+
+  If not all necessary adjustments can be done, returns FALSE.
+  When problem occurs, changes to tile extras are not reverted.
+  Pass virtual tile to the function if you are not sure it will success
+  and don't want extras adjusted at all in case of failure.
+****************************************************************************/
+bool tile_extra_rm_apply(struct tile *ptile, struct extra_type *tgt)
+{
+  /* Remove extra with everything depending on it. */
+  if (!rm_recursive_extras(ptile, tgt, 0)) {
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
+/****************************************************************************
+  Build irrigation on the tile.  This may change the extras of the tile
   or change the terrain type itself.
 ****************************************************************************/
-static void tile_irrigate(struct tile *ptile)
+static void tile_irrigate(struct tile *ptile, struct extra_type *tgt)
 {
   struct terrain *pterrain = tile_terrain(ptile);
 
   if (pterrain == pterrain->irrigation_result) {
-    if (tile_has_special(ptile, S_IRRIGATION)) {
-      tile_add_special(ptile, S_FARMLAND);
-    } else {
-      tile_add_special(ptile, S_IRRIGATION);
+    /* Ideally activity should already been cancelled before NULL tgt
+     * gets this far, but it's possible that terrain got changed from
+     * one that gets transformed by irrigation (-> NULL tgt) to one
+     * that does not (-> NULL tgt illegal) since legality of the action
+     * was last checked */
+    if (tgt != NULL) {
+      tile_extra_apply(ptile, tgt);
     }
   } else if (pterrain->irrigation_result) {
     tile_change_terrain(ptile, pterrain->irrigation_result);
@@ -674,17 +628,22 @@ static void tile_irrigate(struct tile *ptile)
 }
 
 /****************************************************************************
-  Build a mine on the tile.  This may change the specials of the tile
+  Build a mine on the tile.  This may change the extras of the tile
   or change the terrain type itself.
 ****************************************************************************/
-static void tile_mine(struct tile *ptile)
+static void tile_mine(struct tile *ptile, struct extra_type *tgt)
 {
   struct terrain *pterrain = tile_terrain(ptile);
 
   if (pterrain == pterrain->mining_result) {
-    tile_set_special(ptile, S_MINE);
-    tile_clear_special(ptile, S_FARMLAND);
-    tile_clear_special(ptile, S_IRRIGATION);
+    /* Ideally activity should already been cancelled before NULL tgt
+     * gets this far, but it's possible that terrain got changed from
+     * one that gets transformed by mining (-> NULL tgt) to one
+     * that does not (-> NULL tgt illegal) since legality of the action
+     * was last checked */
+    if (tgt != NULL) {
+      tile_extra_apply(ptile, tgt);
+    }
   } else if (pterrain->mining_result) {
     tile_change_terrain(ptile, pterrain->mining_result);
   }
@@ -708,22 +667,18 @@ static void tile_transform(struct tile *ptile)
   Return false if there was a error or if the activity is not implemented
   by this function.
 ****************************************************************************/
-bool tile_apply_activity(struct tile *ptile, Activity_type_id act) 
+bool tile_apply_activity(struct tile *ptile, Activity_type_id act,
+                         struct extra_type *tgt)
 {
   /* FIXME: for irrigate, mine, and transform we always return TRUE
    * even if the activity fails. */
   switch(act) {
-  case ACTIVITY_POLLUTION:
-  case ACTIVITY_FALLOUT: 
-    tile_clear_dirtiness(ptile);
-    return TRUE;
-
   case ACTIVITY_MINE:
-    tile_mine(ptile);
+    tile_mine(ptile, tgt);
     return TRUE;
 
   case ACTIVITY_IRRIGATE: 
-    tile_irrigate(ptile);
+    tile_irrigate(ptile, tgt);
     return TRUE;
 
   case ACTIVITY_TRANSFORM:
@@ -740,6 +695,8 @@ bool tile_apply_activity(struct tile *ptile, Activity_type_id act)
   case ACTIVITY_PILLAGE:
   case ACTIVITY_BASE:
   case ACTIVITY_GEN_ROAD:
+  case ACTIVITY_POLLUTION:
+  case ACTIVITY_FALLOUT:
     /* do nothing  - not implemented */
     return FALSE;
 
@@ -754,7 +711,7 @@ bool tile_apply_activity(struct tile *ptile, Activity_type_id act)
   case ACTIVITY_PATROL_UNUSED:
   case ACTIVITY_LAST:
     /* do nothing - these activities have no effect
-       on terrain type or tile specials */
+       on terrain type or tile extras */
     return FALSE;
   }
   fc_assert(FALSE);
@@ -767,10 +724,10 @@ bool tile_apply_activity(struct tile *ptile, Activity_type_id act)
 ****************************************************************************/
 static bool tile_info_pollution(char *buf, int bufsz,
                                 const struct tile *ptile,
-                                enum tile_special_type special,
+                                struct extra_type *pextra,
                                 bool prevp, bool linebreak)
 {
-  if (tile_has_special(ptile, special)) {
+  if (tile_has_visible_extra(ptile, pextra)) {
     if (!prevp) {
       if (linebreak) {
         fc_strlcat(buf, "\n[", bufsz);
@@ -781,7 +738,7 @@ static bool tile_info_pollution(char *buf, int bufsz,
       fc_strlcat(buf, "/", bufsz);
     }
 
-    fc_strlcat(buf, special_name_translation(special), bufsz);
+    fc_strlcat(buf, extra_name_translation(pextra), bufsz);
 
     return TRUE;
   }
@@ -790,7 +747,8 @@ static bool tile_info_pollution(char *buf, int bufsz,
 }
 
 /****************************************************************************
-  Return a (static) string with tile name describing terrain and specials.
+  Return a (static) string with tile name describing terrain and
+  extras of some categories.
   If include_nuisances is set, pollution and nuclear fallout will be
   ignored.
 
@@ -813,18 +771,18 @@ const char *tile_get_info_text(const struct tile *ptile,
     lb = TRUE;
   }
 
-  road_type_iterate(proad) {
-    if (tile_has_road(ptile, proad)
-        && road_has_flag(proad, RF_NATURAL)) {
+  extra_type_iterate(pextra) {
+    if (pextra->category == ECAT_NATURAL
+        && tile_has_visible_extra(ptile, pextra)) {
       if (lb) {
         sz_strlcat(s, "\n");
         lb = FALSE;
       } else {
         sz_strlcat(s, "/");
       }
-      sz_strlcat(s, road_name_translation(proad));
+      sz_strlcat(s, extra_name_translation(pextra));
     }
-  } road_type_iterate_end;
+  } extra_type_iterate_end;
   if (linebreaks & TILE_LB_RIVER_RESOURCE) {
     /* New linebreak requested */
     lb = TRUE;
@@ -847,10 +805,12 @@ const char *tile_get_info_text(const struct tile *ptile,
 
   if (include_nuisances) {
     pollution = FALSE;
-    pollution = tile_info_pollution(s, bufsz, ptile, S_POLLUTION, pollution,
-                                    lb);
-    pollution = tile_info_pollution(s, bufsz, ptile, S_FALLOUT, pollution,
-                                    lb);
+    extra_type_iterate(pextra) {
+      if (pextra->category == ECAT_NUISANCE) {
+        pollution = tile_info_pollution(s, bufsz, ptile, pextra, pollution,
+                                        lb);
+      }
+    } extra_type_iterate_end;
     if (pollution) {
       sz_strlcat(s, "]");
     }
@@ -864,33 +824,15 @@ const char *tile_get_info_text(const struct tile *ptile,
 ****************************************************************************/
 bool tile_has_base(const struct tile *ptile, const struct base_type *pbase)
 {
-  return BV_ISSET(ptile->bases, base_index(pbase));
+  return tile_has_extra(ptile, base_extra_get(pbase));
 }
 
 /****************************************************************************
-  Returns TRUE if the given tile has a base conflicting with the given one.
+  Returns TRUE if the given tile has a road of given type on it.
 ****************************************************************************/
-bool tile_has_conflicting_base(const struct tile *ptile, const struct base_type *pbase)
+bool tile_has_road(const struct tile *ptile, const struct road_type *proad)
 {
-  base_type_iterate(pconfl) {
-    if (BV_ISSET(pbase->conflicts, base_index(pconfl))
-        && tile_has_base(ptile, pconfl)) {
-      return TRUE;
-    }
-  } base_type_iterate_end;
-
-  return FALSE;
-}
-
-/****************************************************************************
-  Returns TRUE if the given tile has any bases on it.
-****************************************************************************/
-bool tile_has_any_bases(const struct tile *ptile)
-{
-  if (!ptile) {
-    return FALSE;
-  }
-  return BV_ISSET_ANY(ptile->bases);
+  return tile_has_extra(ptile, road_extra_get(proad));
 }
 
 /****************************************************************************
@@ -898,12 +840,13 @@ bool tile_has_any_bases(const struct tile *ptile)
 ****************************************************************************/
 bool tile_has_river(const struct tile *ptile)
 {
-  road_type_iterate(priver) {
-    if (tile_has_road(ptile, priver)
-        && road_has_flag(priver, RF_RIVER)) {
+  /* TODO: Have a list of rivers and iterate only that */
+  extra_type_by_cause_iterate(EC_ROAD, priver) {
+    if (tile_has_extra(ptile, priver)
+        && road_has_flag(extra_road_get(priver), RF_RIVER)) {
       return TRUE;
     }
-  } road_type_iterate_end;
+  } extra_type_by_cause_iterate_end;
 
   return FALSE;
 }
@@ -914,7 +857,7 @@ bool tile_has_river(const struct tile *ptile)
 void tile_add_road(struct tile *ptile, const struct road_type *proad)
 {
   if (proad != NULL) {
-    BV_SET(ptile->roads, road_index(proad));
+    tile_add_extra(ptile, road_extra_get(proad));
   }
 }
 
@@ -924,7 +867,114 @@ void tile_add_road(struct tile *ptile, const struct road_type *proad)
 void tile_remove_road(struct tile *ptile, const struct road_type *proad)
 {
   if (proad != NULL) {
-    BV_CLR(ptile->roads, road_index(proad));
+    tile_remove_extra(ptile, road_extra_get(proad));
+  }
+}
+
+/****************************************************************************
+  Check if tile contains road providing effect
+****************************************************************************/
+bool tile_has_road_flag(const struct tile *ptile, enum road_flag_id flag)
+{
+  extra_type_by_cause_iterate(EC_ROAD, pextra) {
+    if (tile_has_extra(ptile, pextra)) {
+      struct road_type *proad = extra_road_get(pextra);
+
+      if (road_has_flag(proad, flag)) {
+        return TRUE;
+      }
+    }
+  } extra_type_by_cause_iterate_end;
+
+  return FALSE;
+}
+
+/****************************************************************************
+  Check if tile contains extra providing effect
+****************************************************************************/
+bool tile_has_extra_flag(const struct tile *ptile, enum extra_flag_id flag)
+{
+  extra_type_iterate(pextra) {
+    if (tile_has_extra(ptile, pextra)
+        && extra_has_flag(pextra, flag)) {
+      return TRUE;
+    }
+  } extra_type_iterate_end;
+
+  return FALSE;
+}
+
+/****************************************************************************
+  Returns TRUE if the given tile has a extra conflicting with the given one.
+****************************************************************************/
+bool tile_has_conflicting_extra(const struct tile *ptile,
+                                const struct extra_type *pextra)
+{
+  extra_type_iterate(pconfl) {
+    if (BV_ISSET(pextra->conflicts, extra_index(pconfl))
+        && tile_has_extra(ptile, pconfl)) {
+      return TRUE;
+    }
+  } extra_type_iterate_end;
+
+  return FALSE;
+}
+
+/****************************************************************************
+  Returns TRUE if the given tile has a road of given type on it.
+****************************************************************************/
+bool tile_has_visible_extra(const struct tile *ptile, const struct extra_type *pextra)
+{
+  bool hidden = FALSE;
+
+  if (!BV_ISSET(ptile->extras, extra_index(pextra))) {
+    return FALSE;
+  }
+
+  extra_type_iterate(top) {
+    int topi = extra_index(top);
+
+    if (BV_ISSET(pextra->hidden_by, topi)
+        && BV_ISSET(ptile->extras, topi)) {
+      hidden = TRUE;
+      break;
+    }
+  } extra_type_iterate_end;
+
+  return !hidden;
+}
+
+/****************************************************************************
+  Has tile any extras of the specified cause.
+****************************************************************************/
+bool tile_has_cause_extra(const struct tile *ptile, enum extra_cause cause)
+{
+  extra_type_by_cause_iterate(cause, pextra) {
+    if (tile_has_extra(ptile, pextra)) {
+      return TRUE;
+    }
+  } extra_type_by_cause_iterate_end;
+
+  return FALSE;
+}
+
+/****************************************************************************
+  Adds extra to tile
+****************************************************************************/
+void tile_add_extra(struct tile *ptile, const struct extra_type *pextra)
+{
+  if (pextra != NULL) {
+    BV_SET(ptile->extras, extra_index(pextra));
+  }
+}
+
+/****************************************************************************
+  Removes extra from tile if such exist
+****************************************************************************/
+void tile_remove_extra(struct tile *ptile, const struct extra_type *pextra)
+{
+  if (pextra != NULL) {
+    BV_CLR(ptile->extras, extra_index(pextra));
   }
 }
 
@@ -941,17 +991,16 @@ struct tile *tile_virtual_new(const struct tile *ptile)
   vtile = fc_calloc(1, sizeof(*vtile));
 
   /* initialise some values */
-  vtile->index = -1;
+  vtile->index = TILE_INDEX_NONE;
   vtile->continent = -1;
 
-  BV_CLR_ALL(vtile->special);
-  BV_CLR_ALL(vtile->bases);
-  BV_CLR_ALL(vtile->roads);
+  BV_CLR_ALL(vtile->extras);
   vtile->resource = NULL;
   vtile->terrain = NULL;
   vtile->units = unit_list_new();
   vtile->worked = NULL;
   vtile->owner = NULL;
+  vtile->extras_owner = NULL;
   vtile->claimer = NULL;
   vtile->spec_sprite = NULL;
 
@@ -961,32 +1010,19 @@ struct tile *tile_virtual_new(const struct tile *ptile)
     vtile->index = tile_index(ptile);
 
     /* Copy all but the unit list. */
-    tile_special_type_iterate(spe) {
-      if (BV_ISSET(ptile->special, spe)) {
-        BV_SET(vtile->special, spe);
+    extra_type_iterate(pextra) {
+      if (BV_ISSET(ptile->extras, extra_number(pextra))) {
+        BV_SET(vtile->extras, extra_number(pextra));
       }
-    } tile_special_type_iterate_end;
+    } extra_type_iterate_end;
 
-    if (BV_ISSET(ptile->special, S_RESOURCE_VALID)) {
-      BV_SET(vtile->special, S_RESOURCE_VALID);
-    }
-
-    base_type_iterate(pbase) {
-      if (BV_ISSET(ptile->bases, base_number(pbase))) {
-        BV_SET(vtile->bases, base_number(pbase));
-      }
-    } base_type_iterate_end;
-
-    road_type_iterate(proad) {
-      if (tile_has_road(ptile, proad)) {
-        tile_add_road(vtile, proad);
-      }
-    } road_type_iterate_end;
+    vtile->resource_valid = ptile->resource_valid;
 
     vtile->resource = ptile->resource;
     vtile->terrain = ptile->terrain;
     vtile->worked = ptile->worked;
     vtile->owner = ptile->owner;
+    vtile->extras_owner = ptile->extras_owner;
     vtile->claimer = ptile->claimer;
     vtile->spec_sprite = NULL;
   }
@@ -1044,7 +1080,7 @@ bool tile_virtual_check(struct tile *vtile)
   tindex = tile_index(vtile);
   fc_assert_ret_val(0 <= tindex && tindex < map_num_tiles(), FALSE);
 
-  return (vtile != map.tiles + tindex);
+  return (vtile != game.map.tiles + tindex);
 }
 
 /****************************************************************************
