@@ -41,8 +41,6 @@
 
 #include "unit.h"
 
-static bool is_real_activity(enum unit_activity activity);
-
 Activity_type_id real_activities[ACTIVITY_LAST];
 
 struct cargo_iter {
@@ -131,7 +129,8 @@ enum unit_airlift_result
        * or no airport).
        *
        * Note that (game.info.airlifting_style & AIRLIFTING_UNLIMITED_SRC)
-       * is not handled here because it always needs an airport to airlift.
+       * is not handled here because it applies only when the source city
+       * has at least one remaining airlift.
        * See also do_airline() in server/unittools.h. */
       return AR_SRC_NO_FLIGHTS;
     } /* else, there is capacity; continue to other checks */
@@ -589,7 +588,7 @@ void setup_real_activities_array(void)
   Return if given activity really is in game. For savegame compatibility
   activity enum cannot be reordered and there is holes in it.
 **************************************************************************/
-static bool is_real_activity(enum unit_activity activity)
+bool is_real_activity(enum unit_activity activity)
 {
   /* ACTIVITY_FORTRESS, ACTIVITY_AIRBASE, ACTIVITY_OLD_ROAD, and
    * ACTIVITY_OLD_RAILROAD are deprecated */
@@ -617,7 +616,7 @@ const char *get_activity_text(enum unit_activity activity)
     return _("Pollution");
   case ACTIVITY_MINE:
     /* TRANS: Activity name, verb in English */
-    return _("Plant");
+    return _("Mine");
   case ACTIVITY_IRRIGATE:
     return _("Irrigate");
   case ACTIVITY_FORTIFYING:
@@ -1829,6 +1828,7 @@ void free_unit_orders(struct unit *punit)
     free(punit->orders.list);
     punit->orders.list = NULL;
   }
+  punit->orders.length = 0;
   punit->has_orders = FALSE;
 }
 
