@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,23 +20,23 @@
 /* Lua headers want to define VERSION to lua version */
 #undef VERSION
 
-#ifdef HAVE_MKSTEMP
+#if defined(HAVE_MKSTEMP) && defined(FREECIV_HAVE_UNISTD_H)
 #define LUA_USE_MKSTEMP
 #endif
-#ifdef HAVE_ISATTY
-#define LUA_USE_ISATTY
-#endif
-#ifdef HAVE_POPEN
+#if defined(HAVE_POPEN) && defined(HAVE_PCLOSE)
 #define LUA_USE_POPEN
 #endif
 #if defined(HAVE__LONGJMP) && defined(HAVE__SETJMP)
 #define LUA_USE_ULONGJMP
 #endif
+#if defined(HAVE_GMTIME_R) && defined(HAVE_LOCALTIME_R)
+#define LUA_USE_GMTIME_R
+#endif
 #if defined(HAVE_FSEEKO)
 #define LUA_USE_FSEEKO
 #endif
 
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
 #define LUA_USE_READLINE
 #endif
 
