@@ -13,9 +13,12 @@
 #ifndef FC__ADVTOOLS_H
 #define FC__ADVTOOLS_H
 
+/* common */
+#include "fc_types.h"
+
 #define MORT 24
 
-int amortize(int benefit, int delay);
+adv_want amortize(adv_want benefit, int delay);
 
 /*
  * To prevent integer overflows the product "power * hp * firepower"
