@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 2003 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
    GNU General Public License for more details.
 ***********************************************************************/
 
-/**********************************************************************
+/***********************************************************************
   Functions for creating barbarians in huts, land and sea
   Started by Jerzy Klek <jekl@altavista.net>
   with more ideas from Falk Hueffner 
@@ -39,6 +39,7 @@
 #include "map.h"
 #include "movement.h"
 #include "nation.h"
+#include "research.h"
 #include "tech.h"
 #include "terrain.h"
 #include "unitlist.h"
@@ -59,6 +60,9 @@
 /* server/advisors */
 #include "advdata.h"
 
+/* ai */
+#include "difficulty.h"
+
 #include "barbarian.h"
 
 #define BARBARIAN_INITIAL_VISION_RADIUS 3
@@ -91,34 +95,37 @@ struct player *create_barbarian_player(enum barbarian_type type)
 {
   struct player *barbarians;
   struct nation_type *nation;
+  struct research *presearch;
 
-  players_iterate(barbarians) {
-    if ((type == LAND_BARBARIAN && is_land_barbarian(barbarians))
-        || (type == SEA_BARBARIAN && is_sea_barbarian(barbarians))) {
-      if (!barbarians->is_alive) {
-        barbarians->economic.gold = 0;
-        barbarians->is_alive = TRUE;
-        player_status_reset(barbarians);
+  players_iterate(old_barbs) {
+    if ((type == LAND_BARBARIAN && is_land_barbarian(old_barbs))
+        || (type == SEA_BARBARIAN && is_sea_barbarian(old_barbs))) {
+      if (!old_barbs->is_alive) {
+        old_barbs->economic.gold = 0;
+        old_barbs->is_alive = TRUE;
+        player_status_reset(old_barbs);
 
         /* Free old name so pick_random_player_name() can select it again.
          * This is needed in case ruleset defines just one leader for
          * barbarian nation. */
-        barbarians->name[0] = '\0';
-        server_player_set_name(barbarians,
-            pick_random_player_name(nation_of_player(barbarians)));
-        sz_strlcpy(barbarians->username, ANON_USER_NAME);
+        old_barbs->name[0] = '\0';
+        server_player_set_name(old_barbs,
+            pick_random_player_name(nation_of_player(old_barbs)));
+        sz_strlcpy(old_barbs->username, _(ANON_USER_NAME));
+        old_barbs->unassigned_user = TRUE;
         /* I need to make them to forget the map, I think */
 	whole_map_iterate(ptile) {
-	  map_clear_known(ptile, barbarians);
+	  map_clear_known(ptile, old_barbs);
 	} whole_map_iterate_end;
       }
-      barbarians->economic.gold += 100;  /* New leader, new money */
-      return barbarians;
+      old_barbs->economic.gold += 100;  /* New leader, new money */
+
+      return old_barbs;
     }
   } players_iterate_end;
 
   /* make a new player, or not */
-  barbarians = server_create_player(-1, default_ai_type_name(), NULL);
+  barbarians = server_create_player(-1, default_ai_type_name(), NULL, FALSE);
   if (!barbarians) {
     return NULL;
   }
@@ -138,9 +145,10 @@ struct player *create_barbarian_player(enum barbarian_type type)
 
   server.nbarbarians++;
 
-  sz_strlcpy(barbarians->username, ANON_USER_NAME);
+  sz_strlcpy(barbarians->username, _(ANON_USER_NAME));
+  barbarians->unassigned_user = TRUE;
   barbarians->is_connected = FALSE;
-  barbarians->government = nation->init_government;
+  barbarians->government = init_government_of_nation(nation);
   fc_assert(barbarians->revolution_finishes < 0);
   barbarians->server.got_first_city = FALSE;
   barbarians->economic.gold = 100;
@@ -151,9 +159,10 @@ struct player *create_barbarian_player(enum barbarian_type type)
   barbarians->ai_controlled = TRUE;
   barbarians->ai_common.barbarian_type = type;
   set_ai_level_directer(barbarians, game.info.skill_level);
-  init_tech(barbarians, TRUE);
-  give_global_initial_techs(barbarians);
-  give_nation_initial_techs(barbarians);
+
+  presearch = research_get(barbarians);
+  init_tech(presearch, TRUE);
+  give_initial_techs(presearch, 0);
 
   /* Ensure that we are at war with everyone else */
   players_iterate(pplayer) {
@@ -174,6 +183,9 @@ struct player *create_barbarian_player(enum barbarian_type type)
                 player_name(barbarians));
 
   send_player_all_c(barbarians, NULL);
+  /* Send research info after player info, else the client will complain
+   * about invalid team. */
+  send_research_info(presearch, NULL);
 
   return barbarians;
 }
@@ -313,7 +325,9 @@ bool unleash_barbarians(struct tile *ptile)
           int rdir = random_unchecked_direction(land_tiles - checked_count, checked);
 
           if (unit_can_move_to_tile(punit2, dir_tiles[rdir], TRUE)) {
-            (void) unit_move_handling(punit2, dir_tiles[rdir], TRUE, FALSE);
+            /* Move */
+            (void) unit_move_handling(punit2, dir_tiles[rdir],
+                                      TRUE, TRUE, NULL);
             log_debug("Moved barbarian unit from (%d, %d) to (%d, %d)", 
                       TILE_XY(ptile), TILE_XY(dir_tiles[rdir]));
             dest_found = TRUE;
@@ -356,7 +370,8 @@ bool unleash_barbarians(struct tile *ptile)
         unit_list_iterate_safe((ptile)->units, punit2) {
           if (unit_owner(punit2) == barbarians) {
             if (unit_can_move_to_tile(punit2, btile, TRUE)) {
-              (void) unit_move_handling(punit2, btile, TRUE, FALSE);
+              /* Load */
+              (void) unit_move_handling(punit2, btile, TRUE, TRUE, NULL);
             }
           }
         } unit_list_iterate_safe_end;
@@ -377,7 +392,9 @@ bool unleash_barbarians(struct tile *ptile)
             rdir = random_unchecked_direction(land_tiles - checked_count, checked);
 
             if (unit_can_move_to_tile(punit2, dir_tiles[rdir], TRUE)) {
-              (void) unit_move_handling(punit2, dir_tiles[rdir], TRUE, FALSE);
+              /* Move */
+              (void) unit_move_handling(punit2, dir_tiles[rdir],
+                                        TRUE, TRUE, NULL);
               dest_found = TRUE;
             }
 
@@ -465,11 +482,14 @@ static void try_summon_barbarians(void)
 {
   struct tile *ptile, *utile;
   int i, dist;
-  int uprise = 1;
+  int uprise;
   struct city *pc;
   struct player *barbarians, *victim;
   struct unit_type *leader_type;
   int barb_count, really_created = 0;
+  bool hut_present = FALSE;
+  int city_count;
+  int city_max;
 
   /* We attempt the summons on a particular, random position.  If this is
    * an invalid position then the summons simply fails this time.  This means
@@ -492,7 +512,7 @@ static void try_summon_barbarians(void)
 
   dist = real_map_distance(ptile, pc->tile);
   log_debug("Closest city (to %d,%d) is %s (at %d,%d) distance %d.",
-            TILE_XY(ptile), city_name(pc), TILE_XY(pc->tile), dist);
+            TILE_XY(ptile), city_name_get(pc), TILE_XY(pc->tile), dist);
   if (dist > MAX_UNREST_DIST || dist < MIN_UNREST_DIST) {
     return;
   }
@@ -508,20 +528,34 @@ static void try_summon_barbarians(void)
   fc_assert(1 < game.server.barbarianrate);
 
   /* do not harass small civs - in practice: do not uprise at the beginning */
-  if ((int)fc_rand(UPRISE_CIV_MORE) >
-           (int)city_list_size(victim->cities) -
-                UPRISE_CIV_SIZE/(game.server.barbarianrate-1)
+  if ((int)fc_rand(30) + 1 >
+      (int)city_list_size(victim->cities) * (game.server.barbarianrate - 1)
       || fc_rand(100) > get_player_bonus(victim, EFT_CIVIL_WAR_CHANCE)) {
     return;
   }
   log_debug("Barbarians are willing to fight");
 
-  if (tile_has_special(utile, S_HUT)) {
-    /* remove the hut in place of uprising */
-    tile_clear_special(utile, S_HUT);
+  /* Remove huts in place of uprising */
+  extra_type_by_cause_iterate(EC_HUT, pextra) {
+    if (tile_has_extra(utile, pextra)) {
+      tile_extra_rm_apply(utile, pextra);
+      hut_present = TRUE;
+    }
+  } extra_type_by_cause_iterate_end;
+
+  if (hut_present) {
     update_tile_knowledge(utile);
   }
 
+  city_count = city_list_size(victim->cities);
+  city_max = UPRISE_CIV_SIZE;
+  uprise = 1;
+
+  while (city_max <= city_count) {
+    uprise++;
+    city_max *= 1.2 + UPRISE_CIV_SIZE;
+  }
+
   barb_count = fc_rand(3) + uprise * game.server.barbarianrate;
   leader_type = get_role_unit(L_BARBARIAN_LEADER, 0);
 
@@ -531,9 +565,6 @@ static void try_summon_barbarians(void)
     if (!barbarians) {
       return;
     }
-    if (city_list_size(victim->cities) > UPRISE_CIV_MOST) {
-      uprise = 3;
-    }
     for (i = 0; i < barb_count; i++) {
       struct unit_type *punittype
 	= find_a_unit_type(L_BARBARIAN, L_BARBARIAN_TECH);
