@@ -15,7 +15,8 @@
 
 struct city;
 
-void citizens_update(struct city *pcity);
+void citizens_update(struct city *pcity, struct player *plr);
+void citizens_convert(struct city *pcity);
 
 void citizens_print(const struct city *pcity);
 
