@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,23 +13,11 @@
 #ifndef FC__CITYTOOLS_H
 #define FC__CITYTOOLS_H
 
+/* common */
 #include "events.h"		/* enum event_type */
 #include "packets.h"
 #include "unitlist.h"
 
-#define FOOD_WEIGHTING 25
-#define SHIELD_WEIGHTING 14
-#define TRADE_WEIGHTING 15
-/* The Trade Weighting has to about as large as the Shield Weighting,
-   otherwise the AI will build Barracks to create veterans in cities 
-   with only 1 shields production.
-    8 is too low
-   18 is too high
- */
-#define POLLUTION_WEIGHTING 16 /* tentative */
-#define WARMING_FACTOR 50
-#define COOLING_FACTOR WARMING_FACTOR
-
 int build_points_left(struct city *pcity);
 int do_make_unit_veteran(struct city *pcity,
 			 const struct unit_type *punittype);
@@ -79,10 +67,10 @@ void building_lost(struct city *pcity, const struct impr_type *pimprove);
 void city_units_upkeep(const struct city *pcity);
 
 bool is_production_equal(const struct universal *one,
-			 const struct universal *two);
+                         const struct universal *two);
 void change_build_target(struct player *pplayer, struct city *pcity,
-			 struct universal target,
-			 enum event_type event);
+                         struct universal *target,
+                         enum event_type event);
 
 bool is_allowed_city_name(struct player *pplayer, const char *cityname,
 			  char *error_buf, size_t bufsz);
@@ -111,4 +99,8 @@ void refresh_player_cities_vision(struct player *pplayer);
 
 void sync_cities(void);
 
+void clear_worker_task(struct city *pcity, struct worker_task *ptask);
+void clear_worker_tasks(struct city *pcity);
+void package_and_send_worker_tasks(struct city *pcity);
+
 #endif  /* FC__CITYTOOLS_H */
