@@ -412,6 +412,7 @@ void diplomat_bribe(struct player *pplayer, struct unit *pdiplomat,
   int bribe_cost;
   int diplomat_id = pdiplomat->id;
   struct city *pcity;
+  bool bounce;
 
   /* Fetch target unit's player.  Sanity checks. */
   fc_assert_ret(pvictim);
@@ -495,8 +496,9 @@ void diplomat_bribe(struct player *pplayer, struct unit *pdiplomat,
   /* The unit may have been on a tile shared with a city or a unit
    * it no longer can share a tile with. */
   pcity = tile_city(unit_tile(pvictim));
-  if ((NULL != pcity && !pplayers_allied(city_owner(pcity), pplayer))
-      || 1 < unit_list_size(unit_tile(pvictim)->units)) {
+  bounce = ((NULL != pcity && !pplayers_allied(city_owner(pcity), pplayer))
+            || 1 < unit_list_size(unit_tile(pvictim)->units));
+  if (bounce) {
     bounce_unit(pvictim, TRUE);
   }
 
@@ -511,9 +513,9 @@ void diplomat_bribe(struct player *pplayer, struct unit *pdiplomat,
     return;
   }
 
-  /* Try to move the briber onto the victim's square unless its a city or
-   * have other units. */
-  if (NULL == pcity && unit_list_size(unit_tile(pvictim)->units) < 2
+  /* Try to move the briber onto the victim's square unless the victim has
+   * been bounced because it couldn't share tile with a unit or city. */
+  if (!bounce
       /* Post bribe move. */
       && !unit_move_handling(pdiplomat, victim_tile, FALSE, TRUE, NULL)
       /* May have died while trying to move. */
