@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,6 +15,8 @@
 #include <fc_config.h>
 #endif
 
+#include "fc_prehdrs.h"
+
 #include <ctype.h>
 #include <errno.h>
 #include <stdio.h>
@@ -36,13 +38,6 @@
 #ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
-#ifdef HAVE_WINSOCK
-#ifdef HAVE_WINSOCK2
-#include <winsock2.h>
-#else  /* HAVE_WINSOCK2 */
-#include <winsock.h>
-#endif /* HAVE_WINSOCK2 */
-#endif /* HAVE_WINSOCK */
 
 /* utility */
 #include "fcintl.h"
@@ -59,6 +54,7 @@
 #include "connection.h"
 #include "dataio.h"
 #include "game.h"
+#include "map.h"
 #include "version.h"
 
 /* server */
@@ -118,6 +114,18 @@ const char *get_meta_message_string(void)
   return meta_message;
 }
 
+/*************************************************************************
+ The server metaserver type
+*************************************************************************/
+static const char *get_meta_type_string(void)
+{
+  if (game.server.meta_info.type[0] != '\0') {
+    return game.server.meta_info.type;
+  }
+
+  return NULL;
+}
+
 /*************************************************************************
  The metaserver message set by user
 *************************************************************************/
@@ -241,7 +249,7 @@ static void send_metaserver_post(void *arg)
     addr = srvarg.bind_addr;
   }
 
-  if (!netfile_send_post(srvarg.metaserver_addr, post, NULL, addr)) {
+  if (!netfile_send_post(srvarg.metaserver_addr, post, NULL, NULL, addr)) {
     con_puts(C_METAERROR, _("Error connecting to metaserver"));
     metaserver_failed();
   }
@@ -280,7 +288,11 @@ static bool send_to_metaserver(enum meta_flag flag)
     sz_strlcpy(host, "unknown");
   }
 
-  sz_strlcpy(rs, game.control.name);
+  if (game.control.version[0] != '\0') {
+    fc_snprintf(rs, sizeof(rs), "%s %s", game.control.name, game.control.version);
+  } else {
+    sz_strlcpy(rs, game.control.name);
+  }
 
   /* Freed in metaserver thread function send_metaserver_post() */
   post = netfile_start_post();
@@ -293,6 +305,11 @@ static bool send_to_metaserver(enum meta_flag flag)
   if (flag == META_GOODBYE) {
     netfile_add_form_int(post, "bye", 1);
   } else {
+    const char *srvtype = get_meta_type_string();
+
+    if (srvtype != NULL) {
+      netfile_add_form_str(post, "type", srvtype);
+    }
     netfile_add_form_str(post, "version", VERSION_STRING);
     netfile_add_form_str(post, "patches",
                          get_meta_patches_string());
@@ -386,7 +403,7 @@ static bool send_to_metaserver(enum meta_flag flag)
       }
 
       /* HACK: send the most determinant setting for the map size. */
-      switch (map.server.mapsize) {
+      switch (game.map.server.mapsize) {
       case MAPSIZE_FULLSIZE:
         meta_insert_setting(post, "size");
         break;
