@@ -67,6 +67,8 @@ static void package_event_full(struct packet_chat_msg *packet,
   packet->tile = (NULL != ptile ? tile_index(ptile) : -1);
   packet->event = event;
   packet->conn_id = pconn ? pconn->id : -1;
+  packet->turn = game.info.turn;
+  packet->phase = game.info.phase;
 
   fc_vsnprintf(buf, sizeof(buf), format, vargs);
   if (is_capitalization_enabled()) {
@@ -80,7 +82,7 @@ static void package_event_full(struct packet_chat_msg *packet,
                             TTT_COLOR, 0, FT_OFFSET_UNSET, color);
   } else {
     /* Simple case */
-    strncpy(packet->message, str, sizeof(packet->message));
+    sz_strlcpy(packet->message, str);
   }
 
   if (is_capitalization_enabled()) {
@@ -189,7 +191,8 @@ void package_event(struct packet_chat_msg *packet,
   coordinates have been normalized.
 **************************************************************************/
 static void notify_conn_packet(struct conn_list *dest,
-                               const struct packet_chat_msg *packet)
+                               const struct packet_chat_msg *packet,
+                               bool early)
 {
   struct packet_chat_msg real_packet = *packet;
   int tile = packet->tile;
@@ -222,7 +225,11 @@ static void notify_conn_packet(struct conn_list *dest,
       real_packet.tile = -1;
     }
 
-    send_packet_chat_msg(pconn, &real_packet);
+    if (early) {
+      send_packet_early_chat_msg(pconn, (struct packet_early_chat_msg *)(&real_packet));
+    } else {
+      send_packet_chat_msg(pconn, &real_packet);
+    }
   } conn_list_iterate_end;
 }
 
@@ -242,7 +249,32 @@ void notify_conn(struct conn_list *dest,
   vpackage_event(&genmsg, ptile, event, color, format, args);
   va_end(args);
 
-  notify_conn_packet(dest, &genmsg);
+  notify_conn_packet(dest, &genmsg, FALSE);
+
+  if (!dest || dest == game.est_connections) {
+    /* Add to the cache */
+    event_cache_add_for_all(&genmsg);
+  }
+}
+
+/**************************************************************************
+  See notify_conn_packet - this is just the "non-v" version, with varargs.
+  Use for early connecting protocol messages.
+**************************************************************************/
+void notify_conn_early(struct conn_list *dest,
+                       const struct tile *ptile,
+                       enum event_type event,
+                       const struct ft_color color,
+                       const char *format, ...)
+{
+  struct packet_chat_msg genmsg;
+  va_list args;
+
+  va_start(args, format);
+  vpackage_event(&genmsg, ptile, event, color, format, args);
+  va_end(args);
+
+  notify_conn_packet(dest, &genmsg, TRUE);
 
   if (!dest || dest == game.est_connections) {
     /* Add to the cache */
@@ -271,7 +303,7 @@ void notify_player(const struct player *pplayer,
   vpackage_event(&genmsg, ptile, event, color, format, args);
   va_end(args);
 
-  notify_conn_packet(dest, &genmsg);
+  notify_conn_packet(dest, &genmsg, FALSE);
 
   /* Add to the cache */
   event_cache_add_for_player(&genmsg, pplayer);
@@ -282,7 +314,6 @@ void notify_player(const struct player *pplayer,
   but excluding pplayer and specified player.
 **************************************************************************/
 void notify_embassies(const struct player *pplayer,
-                      const struct player *exclude,
                       const struct tile *ptile,
                       enum event_type event,
                       const struct ft_color color,
@@ -298,9 +329,8 @@ void notify_embassies(const struct player *pplayer,
 
   players_iterate(other_player) {
     if (player_has_embassy(other_player, pplayer)
-        && exclude != other_player
         && pplayer != other_player) {
-      notify_conn_packet(other_player->connections, &genmsg);
+      notify_conn_packet(other_player->connections, &genmsg, FALSE);
       players = event_cache_player_add(players, other_player);
     }
   } players_iterate_end;
@@ -348,7 +378,7 @@ void notify_team(const struct player *pplayer,
     event_cache_add_for_all(&genmsg);
   }
 
-  notify_conn_packet(dest, &genmsg);
+  notify_conn_packet(dest, &genmsg, FALSE);
 
   if (pplayer) {
     conn_list_destroy(dest);
@@ -356,13 +386,13 @@ void notify_team(const struct player *pplayer,
 }
 
 /****************************************************************************
-  Sends a message to all players that share research with pplayer.  Currently
-  this is all players on the same team but it may not always be that way.
+  Sends a message to all players that share research.
 
   Unlike other notify functions this one does not take a tile argument.  We
   assume no research message will have a tile associated.
 ****************************************************************************/
-void notify_research(const struct player *pplayer,
+void notify_research(const struct research *presearch,
+                     const struct player *exclude,
                      enum event_type event,
                      const struct ft_color color,
                      const char *format, ...)
@@ -370,17 +400,63 @@ void notify_research(const struct player *pplayer,
   struct packet_chat_msg genmsg;
   struct event_cache_players *players = NULL;
   va_list args;
-  struct player_research *research = player_research_get(pplayer);
 
   va_start(args, format);
   vpackage_event(&genmsg, NULL, event, color, format, args);
   va_end(args);
 
-  players_iterate(other_player) {
-    if (player_research_get(other_player) == research) {
-      lsend_packet_chat_msg(other_player->connections, &genmsg);
-      players = event_cache_player_add(players, other_player);
+  research_players_iterate(presearch, aplayer) {
+    if (exclude != aplayer) {
+      lsend_packet_chat_msg(aplayer->connections, &genmsg);
+      players = event_cache_player_add(players, aplayer);
     }
+  } research_players_iterate_end;
+
+  /* Add to the cache */
+  event_cache_add_for_players(&genmsg, players);
+}
+
+/****************************************************************************
+  Sends a message to all players that have embassies with someone who
+  shares research.
+
+  Unlike other notify functions this one does not take a tile argument.  We
+  assume no research message will have a tile associated.
+
+  Exclude parameter excludes everyone who has embassy (only) with that
+  player.
+
+  FIXME: Should not send multiple messages if one has embassy with multiple
+         members of the research group, should really exclude ones having
+         embassy with the exclude -one as the use-case for exclusion is that
+         different message is being sent to those excluded here.
+****************************************************************************/
+void notify_research_embassies(const struct research *presearch,
+                               const struct player *exclude,
+                               enum event_type event,
+                               const struct ft_color color,
+                               const char *format, ...)
+{
+  struct packet_chat_msg genmsg;
+  struct event_cache_players *players = NULL;
+  va_list args;
+
+  va_start(args, format);
+  vpackage_event(&genmsg, NULL, event, color, format, args);
+  va_end(args);
+
+  players_iterate(aplayer) {
+    if (exclude == aplayer || research_get(aplayer) == presearch) {
+      continue;
+    }
+
+    research_players_iterate(presearch, rplayer) {
+      if (player_has_embassy(aplayer, rplayer)) {
+        lsend_packet_chat_msg(aplayer->connections, &genmsg);
+        players = event_cache_player_add(players, aplayer);
+        break;
+      }
+    } research_players_iterate_end;
   } players_iterate_end;
 
   /* Add to the cache */
@@ -400,7 +476,6 @@ enum event_cache_target {
 /* Events are saved in that structure. */
 struct event_cache_data {
   struct packet_chat_msg packet;
-  int turn;
   time_t timestamp;
   enum server_states server_state;
   enum event_cache_target target_type;
@@ -438,7 +513,7 @@ static void event_cache_data_free(struct event_cache_data *data)
   old entry if needed.
 **************************************************************************/
 static struct event_cache_data *
-event_cache_data_new(const struct packet_chat_msg *packet, int turn,
+event_cache_data_new(const struct packet_chat_msg *packet,
                      time_t timestamp, enum server_states server_status,
                      enum event_cache_target target_type,
                      struct event_cache_players *players)
@@ -470,7 +545,6 @@ event_cache_data_new(const struct packet_chat_msg *packet, int turn,
 
   pdata = fc_malloc(sizeof(*pdata));
   pdata->packet = *packet;
-  pdata->turn = turn;
   pdata->timestamp = timestamp;
   pdata->server_state = server_status;
   pdata->target_type = target_type;
@@ -533,8 +607,8 @@ void event_cache_remove_old(void)
   /* This assumes that entries are in order, the ones to be removed first. */
   current = event_cache_data_list_get(event_cache, 0);
 
-  while (current != NULL
-         && current->turn + game.server.event_cache.turns <= game.info.turn) {
+    while (current != NULL
+           && current->packet.turn + game.server.event_cache.turns <= game.info.turn) {
     event_cache_data_list_pop_front(event_cache);
     current = event_cache_data_list_get(event_cache, 0);
   }
@@ -546,7 +620,7 @@ void event_cache_remove_old(void)
 void event_cache_add_for_all(const struct packet_chat_msg *packet)
 {
   if (0 < game.server.event_cache.turns) {
-    (void) event_cache_data_new(packet, game.info.turn, time(NULL),
+    (void) event_cache_data_new(packet, time(NULL),
                                 server_state(), ECT_ALL, NULL);
   }
 }
@@ -557,7 +631,7 @@ void event_cache_add_for_all(const struct packet_chat_msg *packet)
 void event_cache_add_for_global_observers(const struct packet_chat_msg *packet)
 {
   if (0 < game.server.event_cache.turns) {
-    (void) event_cache_data_new(packet, game.info.turn, time(NULL),
+    (void) event_cache_data_new(packet, time(NULL),
                                 server_state(), ECT_GLOBAL_OBSERVERS, NULL);
   }
 }
@@ -581,7 +655,7 @@ void event_cache_add_for_player(const struct packet_chat_msg *packet,
       && (server_state() > S_S_INITIAL || !game.info.is_new_game)) {
     struct event_cache_data *pdata;
 
-    pdata = event_cache_data_new(packet, game.info.turn, time(NULL),
+    pdata = event_cache_data_new(packet, time(NULL),
                                  server_state(), ECT_PLAYERS, NULL);
     fc_assert_ret(NULL != pdata);
     BV_SET(pdata->target, player_index(pplayer));
@@ -602,7 +676,7 @@ void event_cache_add_for_players(const struct packet_chat_msg *packet,
       && NULL != players
       && BV_ISSET_ANY(players->vector)
       && (server_state() > S_S_INITIAL || !game.info.is_new_game)) {
-    (void) event_cache_data_new(packet, game.info.turn, time(NULL),
+    (void) event_cache_data_new(packet, time(NULL),
                                 server_state(), ECT_PLAYERS, players);
   }
 
@@ -655,8 +729,8 @@ static bool event_cache_match(const struct event_cache_data *pdata,
   }
 
   if (server_state() == S_S_RUNNING
-      && game.info.turn < pdata->turn
-      && game.info.turn > pdata->turn - game.server.event_cache.turns) {
+      && game.info.turn < pdata->packet.turn
+      && game.info.turn > pdata->packet.turn - game.server.event_cache.turns) {
     return FALSE;
   }
 
@@ -693,10 +767,10 @@ void send_pending_events(struct connection *pconn, bool include_public)
                  localtime(&pdata->timestamp));
         pcm = pdata->packet;
         fc_snprintf(pcm.message, sizeof(pcm.message), "(T%d - %s) %s",
-                    pdata->turn, timestr, pdata->packet.message);
-        notify_conn_packet(pconn->self, &pcm);
+                    pdata->packet.turn, timestr, pdata->packet.message);
+        notify_conn_packet(pconn->self, &pcm, FALSE);
       } else {
-        notify_conn_packet(pconn->self, &pdata->packet);
+        notify_conn_packet(pconn->self, &pdata->packet, FALSE);
       }
     }
   } event_cache_iterate_end;
@@ -711,7 +785,7 @@ void event_cache_load(struct section_file *file, const char *section)
   enum event_cache_target target_type;
   enum server_states server_status;
   struct event_cache_players *players = NULL;
-  int i, x, y, turn, event_count;
+  int i, x, y, event_count;
   time_t timestamp, now;
   const char *p, *q;
 
@@ -724,6 +798,9 @@ void event_cache_load(struct section_file *file, const char *section)
 
   now = time(NULL);
   for (i = 0; i < event_count; i++) {
+    int turn;
+    int phase;
+
     /* restore packet */
     x = secfile_lookup_int_default(file, -1, "%s.events%d.x", section, i);
     y = secfile_lookup_int_default(file, -1, "%s.events%d.y", section, i);
@@ -751,6 +828,12 @@ void event_cache_load(struct section_file *file, const char *section)
     /* restore event cache data */
     turn = secfile_lookup_int_default(file, 0, "%s.events%d.turn",
                                       section, i);
+    packet.turn = turn;
+
+    phase = secfile_lookup_int_default(file, PHASE_UNKNOWN, "%s.events%d.phase",
+                                       section, i);
+    packet.phase = phase;
+
     timestamp = secfile_lookup_int_default(file, now,
                                            "%s.events%d.timestamp",
                                            section, i);
@@ -800,7 +883,7 @@ void event_cache_load(struct section_file *file, const char *section)
     }
 
     /* insert event into the cache */
-    (void) event_cache_data_new(&packet, turn, timestamp, server_status,
+    (void) event_cache_data_new(&packet, timestamp, server_status,
                                 target_type, players);
 
     if (NULL != players) {
@@ -833,8 +916,18 @@ void event_cache_save(struct section_file *file, const char *section)
       index_to_map_pos(&tile_x, &tile_y, tile_index(ptile));
     }
 
-    secfile_insert_int(file, pdata->turn, "%s.events%d.turn",
+    secfile_insert_int(file, pdata->packet.turn, "%s.events%d.turn",
                        section, event_count);
+    if (pdata->packet.phase != PHASE_UNKNOWN) {
+      /* Do not save current value of PHASE_UNKNOWN to savegame.
+       * It practically means that "savegame had no phase stored".
+       * Note that the only case where phase might be PHASE_UNKNOWN
+       * may be present is that the event was loaded from previous
+       * savegame created by a freeciv version that did not store event
+       * phases. */
+      secfile_insert_int(file, pdata->packet.phase, "%s.events%d.phase",
+                         section, event_count);
+    }
     secfile_insert_int(file, pdata->timestamp, "%s.events%d.timestamp",
                        section, event_count);
     secfile_insert_int(file, tile_x, "%s.events%d.x", section, event_count);
@@ -875,3 +968,15 @@ void event_cache_save(struct section_file *file, const char *section)
 
   event_cache_status = TRUE;
 }
+
+/***************************************************************
+  Mark all existing phase values in event cache invalid.
+***************************************************************/
+void event_cache_phases_invalidate(void)
+{
+  event_cache_iterate(pdata) {
+    if (pdata->packet.phase >= 0) {
+      pdata->packet.phase = PHASE_INVALIDATED;
+    }
+  } event_cache_iterate_end;
+}
