@@ -54,7 +54,7 @@
 /*****************************************************************************
   Lua virtual machine state.
 *****************************************************************************/
-static struct fc_lua *fcl = NULL;
+static struct fc_lua *fcl_main = NULL;
 
 /*****************************************************************************
   Optional game script code (useful for scenarios).
@@ -70,7 +70,7 @@ static void script_server_code_free(void);
 static void script_server_code_load(struct section_file *file);
 static void script_server_code_save(struct section_file *file);
 
-static void script_server_signal_create(void);
+static void script_server_signals_create(void);
 static void script_server_functions_define(void);
 
 static void script_server_cmd_reply(struct fc_lua *fcl, enum log_level level,
@@ -88,41 +88,71 @@ bool script_server_do_string(struct connection *caller, const char *str)
 
   /* Set a log callback function which allows to send the results of the
    * command to the clients. */
-  save_caller = fcl->caller;
-  save_output_fct = fcl->output_fct;
-  fcl->output_fct = script_server_cmd_reply;
-  fcl->caller = caller;
+  save_caller = fcl_main->caller;
+  save_output_fct = fcl_main->output_fct;
+  fcl_main->output_fct = script_server_cmd_reply;
+  fcl_main->caller = caller;
 
-  status = luascript_do_string(fcl, str, "cmd");
+  status = luascript_do_string(fcl_main, str, "cmd");
 
   /* Reset the changes. */
-  fcl->caller = save_caller;
-  fcl->output_fct = save_output_fct;
+  fcl_main->caller = save_caller;
+  fcl_main->output_fct = save_output_fct;
 
   return (status == 0);
 }
 
+/*****************************************************************************
+  Load script to a buffer
+*****************************************************************************/
+bool script_server_load_file(const char *filename, char **buf)
+{
+  FILE *ffile;
+  struct stat stats;
+  char *buffer;
+
+  fc_stat(filename, &stats);
+  ffile = fc_fopen(filename, "r");
+
+  if (ffile != NULL) {
+    int len;
+
+    buffer = fc_malloc(stats.st_size + 1);
+
+    len = fread(buffer, 1, stats.st_size, ffile);
+
+    if (len == stats.st_size) {
+      buffer[len] = '\0';
+
+      *buf = buffer;
+    }
+    fclose(ffile);
+  }
+
+  return 1;
+}  
+
 /*****************************************************************************
   Parse and execute the script at filename.
 *****************************************************************************/
 bool script_server_do_file(struct connection *caller, const char *filename)
 {
-  int status;
+  int status = 1;
   struct connection *save_caller;
   luascript_log_func_t save_output_fct;
 
   /* Set a log callback function which allows to send the results of the
    * command to the clients. */
-  save_caller = fcl->caller;
-  save_output_fct = fcl->output_fct;
-  fcl->output_fct = script_server_cmd_reply;
-  fcl->caller = caller;
+  save_caller = fcl_main->caller;
+  save_output_fct = fcl_main->output_fct;
+  fcl_main->output_fct = script_server_cmd_reply;
+  fcl_main->caller = caller;
 
-  status = luascript_do_file(fcl, filename);
+  status = luascript_do_file(fcl_main, filename);
 
   /* Reset the changes. */
-  fcl->caller = save_caller;
-  fcl->output_fct = save_output_fct;
+  fcl_main->caller = save_caller;
+  fcl_main->output_fct = save_output_fct;
 
   return (status == 0);
 }
@@ -133,7 +163,7 @@ bool script_server_do_file(struct connection *caller, const char *filename)
 bool script_server_callback_invoke(const char *callback_name, int nargs,
                                    enum api_types *parg_types, va_list args)
 {
-  return luascript_callback_invoke(fcl, callback_name, nargs, parg_types,
+  return luascript_callback_invoke(fcl_main, callback_name, nargs, parg_types,
                                    args);
 }
 
@@ -144,7 +174,7 @@ bool script_server_callback_invoke(const char *callback_name, int nargs,
 *****************************************************************************/
 void script_server_remove_exported_object(void *object)
 {
-  luascript_remove_exported_object(fcl, object);
+  luascript_remove_exported_object(fcl_main, object);
 }
 
 /*****************************************************************************
@@ -168,7 +198,7 @@ static void script_server_vars_free(void)
 *****************************************************************************/
 static void script_server_vars_load(struct section_file *file)
 {
-  luascript_vars_load(fcl, file, "script.vars");
+  luascript_vars_load(fcl_main, file, "script.vars");
 }
 
 /*****************************************************************************
@@ -176,7 +206,7 @@ static void script_server_vars_load(struct section_file *file)
 *****************************************************************************/
 static void script_server_vars_save(struct section_file *file)
 {
-  luascript_vars_save(fcl, file, "script.vars");
+  luascript_vars_save(fcl_main, file, "script.vars");
 }
 
 /*****************************************************************************
@@ -209,7 +239,7 @@ static void script_server_code_load(struct section_file *file)
 
     code = secfile_lookup_str_default(file, "", "%s", section);
     script_server_code = fc_strdup(code);
-    luascript_do_string(fcl, script_server_code, section);
+    luascript_do_string(fcl_main, script_server_code, section);
   }
 }
 
@@ -228,34 +258,34 @@ static void script_server_code_save(struct section_file *file)
 *****************************************************************************/
 bool script_server_init(void)
 {
-  if (fcl != NULL) {
-    fc_assert_ret_val(fcl->state != NULL, FALSE);
+  if (fcl_main != NULL) {
+    fc_assert_ret_val(fcl_main->state != NULL, FALSE);
 
     return TRUE;
   }
 
-  fcl = luascript_new(NULL);
-  if (!fcl) {
-    luascript_destroy(fcl);
-    fcl = NULL;
+  fcl_main = luascript_new(NULL);
+  if (fcl_main == NULL) {
+    luascript_destroy(fcl_main);
+    fcl_main = NULL;
 
     return FALSE;
   }
 
-  tolua_common_a_open(fcl->state);
-  api_specenum_open(fcl->state);
-  tolua_game_open(fcl->state);
-  tolua_signal_open(fcl->state);
-  tolua_server_open(fcl->state);
-  tolua_common_z_open(fcl->state);
+  tolua_common_a_open(fcl_main->state);
+  api_specenum_open(fcl_main->state);
+  tolua_game_open(fcl_main->state);
+  tolua_signal_open(fcl_main->state);
+  tolua_server_open(fcl_main->state);
+  tolua_common_z_open(fcl_main->state);
 
   script_server_code_init();
   script_server_vars_init();
 
-  luascript_signal_init(fcl);
-  script_server_signal_create();
+  luascript_signal_init(fcl_main);
+  script_server_signals_create();
 
-  luascript_func_init(fcl);
+  luascript_func_init(fcl_main);
   script_server_functions_define();
 
   return TRUE;
@@ -266,13 +296,13 @@ bool script_server_init(void)
 *****************************************************************************/
 void script_server_free(void)
 {
-  if (fcl) {
+  if (fcl_main != NULL) {
     script_server_code_free();
     script_server_vars_free();
 
     /* luascript_signal_free() is called by luascript_destroy(). */
-    luascript_destroy(fcl);
-    fcl = NULL;
+    luascript_destroy(fcl_main);
+    fcl_main = NULL;
   }
 }
 
@@ -305,31 +335,38 @@ void script_server_signal_emit(const char *signal_name, int nargs, ...)
   va_list args;
 
   va_start(args, nargs);
-  luascript_signal_emit_valist(fcl, signal_name, nargs, args);
+  luascript_signal_emit_valist(fcl_main, signal_name, nargs, args);
   va_end(args);
 }
 
 /*****************************************************************************
   Declare any new signal types you need here.
 *****************************************************************************/
-static void script_server_signal_create(void)
+static void script_server_signals_create(void)
 {
-  luascript_signal_create(fcl, "turn_started", 2,
+  signal_deprecator *depr;
+
+  luascript_signal_create(fcl_main, "turn_started", 2,
                           API_TYPE_INT, API_TYPE_INT);
-  luascript_signal_create(fcl, "unit_moved", 3,
+  luascript_signal_create(fcl_main, "unit_moved", 3,
                           API_TYPE_UNIT, API_TYPE_TILE, API_TYPE_TILE);
 
   /* Includes all newly-built cities. */
-  luascript_signal_create(fcl, "city_built", 1,
+  luascript_signal_create(fcl_main, "city_built", 1,
                           API_TYPE_CITY);
 
-  luascript_signal_create(fcl, "city_growth", 2,
-                          API_TYPE_CITY, API_TYPE_INT);
+  luascript_signal_create(fcl_main, "city_size_change", 3,
+                          API_TYPE_CITY, API_TYPE_INT, API_TYPE_STRING);
+
+  /* Deprecated form of the 'city_size_change' signal for the case of growth. */
+  depr = luascript_signal_create(fcl_main, "city_growth", 2,
+                                 API_TYPE_CITY, API_TYPE_INT);
+  deprecate_signal(depr, "city_growth", "city_size_change", "2.6");
 
   /* Only includes units built in cities, for now. */
-  luascript_signal_create(fcl, "unit_built", 2,
+  luascript_signal_create(fcl_main, "unit_built", 2,
                           API_TYPE_UNIT, API_TYPE_CITY);
-  luascript_signal_create(fcl, "building_built", 2,
+  luascript_signal_create(fcl_main, "building_built", 2,
                           API_TYPE_BUILDING_TYPE, API_TYPE_CITY);
 
   /* These can happen for various reasons; the third argument gives the
@@ -337,34 +374,63 @@ static void script_server_signal_create(void)
    * "pop_cost", "need_tech", "need_building", "need_special",
    * "need_terrain", "need_government", "need_nation", "never",
    * "unavailable". */
-  luascript_signal_create(fcl, "unit_cant_be_built", 3,
+  luascript_signal_create(fcl_main, "unit_cant_be_built", 3,
                           API_TYPE_UNIT_TYPE, API_TYPE_CITY, API_TYPE_STRING);
-  luascript_signal_create(fcl, "building_cant_be_built", 3,
+  luascript_signal_create(fcl_main, "building_cant_be_built", 3,
                           API_TYPE_BUILDING_TYPE, API_TYPE_CITY,
                           API_TYPE_STRING);
 
   /* The third argument contains the source: "researched", "traded",
    * "stolen", "hut". */
-  luascript_signal_create(fcl, "tech_researched", 3,
+  luascript_signal_create(fcl_main, "tech_researched", 3,
                           API_TYPE_TECH_TYPE, API_TYPE_PLAYER,
                           API_TYPE_STRING);
 
   /* First player is city owner, second is enemy. */
-  luascript_signal_create(fcl, "city_destroyed", 3,
-                          API_TYPE_CITY, API_TYPE_PLAYER, API_TYPE_PLAYER);
-  luascript_signal_create(fcl, "city_lost", 3,
+  luascript_signal_create(fcl_main, "city_destroyed", 3,
                           API_TYPE_CITY, API_TYPE_PLAYER, API_TYPE_PLAYER);
 
-  luascript_signal_create(fcl, "hut_enter", 1,
+  /* First player is former owner, second new one. */
+  luascript_signal_create(fcl_main, "city_transferred", 4,
+                          API_TYPE_CITY, API_TYPE_PLAYER, API_TYPE_PLAYER,
+                          API_TYPE_STRING);
+
+  /* Deprecated form of the 'city_transferred' signal for the case of
+   * conquest. */
+  depr = luascript_signal_create(fcl_main, "city_lost", 3,
+                                 API_TYPE_CITY, API_TYPE_PLAYER, API_TYPE_PLAYER);
+  deprecate_signal(depr, "city_lost", "city_transferred", "2.6");
+
+  luascript_signal_create(fcl_main, "hut_enter", 1,
                           API_TYPE_UNIT);
 
-  luascript_signal_create(fcl, "unit_lost", 3,
+  luascript_signal_create(fcl_main, "unit_lost", 3,
                           API_TYPE_UNIT, API_TYPE_PLAYER, API_TYPE_STRING);
 
-  luascript_signal_create(fcl, "disaster", 2,
-                          API_TYPE_DISASTER, API_TYPE_CITY);
+  luascript_signal_create(fcl_main, "disaster_occurred", 3,
+                          API_TYPE_DISASTER, API_TYPE_CITY, API_TYPE_BOOL);
 
-  luascript_signal_create(fcl, "map_generated", 0);
+  /* Deprecated form of the 'disaster_occurred' signal without 'had_internal_effct'
+   * support. */
+  depr = luascript_signal_create(fcl_main, "disaster", 2,
+                          API_TYPE_DISASTER, API_TYPE_CITY);
+  deprecate_signal(depr, "disaster", "disaster_occurred", "2.6");
+
+  luascript_signal_create(fcl_main, "achievement_gained", 3,
+                          API_TYPE_ACHIEVEMENT, API_TYPE_PLAYER,
+                          API_TYPE_BOOL);
+
+  luascript_signal_create(fcl_main, "map_generated", 0);
+
+  luascript_signal_create(fcl_main, "pulse", 0);
+
+  luascript_signal_create(fcl_main, "action_started_unit_unit", 3,
+                          API_TYPE_ACTION,
+                          API_TYPE_UNIT, API_TYPE_UNIT);
+
+  luascript_signal_create(fcl_main, "action_started_unit_city", 3,
+                          API_TYPE_ACTION,
+                          API_TYPE_UNIT, API_TYPE_CITY);
 }
 
 /*****************************************************************************
@@ -376,7 +442,7 @@ static void script_server_signal_create(void)
 *****************************************************************************/
 static void script_server_functions_define(void)
 {
-  luascript_func_add(fcl, "respawn_callback", FALSE, 1,
+  luascript_func_add(fcl_main, "respawn_callback", FALSE, 1,
                      API_TYPE_PLAYER);
 }
 
@@ -390,7 +456,7 @@ bool script_server_call(const char *func_name, int nargs, ...)
 
   va_list args;
   va_start(args, nargs);
-  success = luascript_func_call_valist(fcl, func_name, &ret, nargs, args);
+  success = luascript_func_call_valist(fcl_main, func_name, &ret, nargs, args);
   va_end(args);
 
   if (!success) {
