@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -109,9 +109,10 @@ int get_unit_vision_at(struct unit *punit, struct tile *ptile,
 void unit_refresh_vision(struct unit *punit);
 void unit_list_refresh_vision(struct unit_list *punitlist);
 void bounce_unit(struct unit *punit, bool verbose);
+bool unit_activity_needs_target_from_client(enum unit_activity activity);
 void unit_assign_specific_activity_target(struct unit *punit,
                                           enum unit_activity *activity,
-                                          struct act_tgt *target);
+                                          struct extra_type **target);
 void unit_forget_last_activity(struct unit *punit);
 
 /* creation/deletion/upgrading */
@@ -136,8 +137,7 @@ struct unit *unit_change_owner(struct unit *punit, struct player *pplayer,
 void package_unit(struct unit *punit, struct packet_unit_info *packet);
 void package_short_unit(struct unit *punit,
 			struct packet_unit_short_info *packet,
-			enum unit_info_use packet_use, int info_city_id,
-			bool new_serial_num);
+                        enum unit_info_use packet_use, int info_city_id);
 void send_unit_info(struct conn_list *dest, struct unit *punit);
 void send_all_known_units(struct conn_list *dest);
 void unit_goes_out_of_sight(struct player *pplayer, struct unit *punit);
@@ -149,10 +149,13 @@ void do_explore(struct unit *punit);
 bool do_paradrop(struct unit *punit, struct tile *ptile);
 void unit_transport_load_send(struct unit *punit, struct unit *ptrans);
 void unit_transport_unload_send(struct unit *punit);
-bool unit_move(struct unit *punit, struct tile *ptile, int move_cost);
-bool execute_orders(struct unit *punit);
+bool unit_move(struct unit *punit, struct tile *ptile, int move_cost,
+               struct unit *embark_to);
+bool execute_orders(struct unit *punit, const bool fresh);
 
 bool unit_can_do_action_now(const struct unit *punit);
 void unit_did_action(struct unit *punit);
 
+bool unit_can_be_retired(struct unit *punit);
+
 #endif  /* FC__UNITTOOLS_H */
