@@ -36,6 +36,7 @@
 #include "support.h"
 
 /* common */
+#include "capstr.h"
 #include "connection.h"
 #include "events.h"
 #include "fc_cmdhelp.h"
@@ -45,6 +46,7 @@
 #include "government.h"
 #include "improvement.h"
 #include "map.h"
+#include "movement.h"
 #include "player.h"
 #include "version.h"
 
@@ -77,6 +79,7 @@ enum manuals {
   MANUAL_BUILDINGS,
   MANUAL_WONDERS,
   MANUAL_GOVS,
+  MANUAL_UNITS,
   MANUAL_COUNT
 };
 
@@ -179,11 +182,17 @@ const char *tileset_description(struct tileset *t)
   return NULL;
 }
 
+/**************************************************************************
+  Mostly a client stub.
+**************************************************************************/
 enum client_states client_state(void)
 {
   return C_S_INITIAL;
 }
 
+/**************************************************************************
+  Mostly a client stub.
+**************************************************************************/
 bool client_nation_is_in_current_set(const struct nation_type *pnation)
 {
   /* Currently, there is no way to select a nation set for freeciv-manual.
@@ -530,6 +539,38 @@ static bool manual_command(void)
       } governments_iterate_end;
       break;
 
+    case MANUAL_UNITS:
+      /* FIXME: this doesn't resemble the wiki manual at all. */
+      fprintf(doc, _("<h1>Freeciv %s unit types help</h1>\n\n"),
+              VERSION_STRING);
+      unit_type_iterate(putype) {
+        char buf[64000];
+        fprintf(doc, "%s%s%s\n\n", SECTION_BEGIN,
+                utype_name_translation(putype), SECTION_END);
+        fprintf(doc,
+                PL_("Cost: %d shield\n",
+                    "Cost: %d shields\n",
+                    utype_build_shield_cost(putype)),
+                utype_build_shield_cost(putype));
+        fprintf(doc, _("Upkeep: %s\n"),
+                helptext_unit_upkeep_str(putype));
+        fprintf(doc, _("Moves: %s\n"),
+                move_points_text(putype->move_rate, TRUE));
+        fprintf(doc, _("Vision: %d\n"),
+                (int)sqrt((double)putype->vision_radius_sq));
+        fprintf(doc, _("Attack: %d\n"),
+                putype->attack_strength);
+        fprintf(doc, _("Defense: %d\n"),
+                putype->defense_strength);
+        fprintf(doc, _("Firepower: %d\n"),
+                putype->firepower);
+        fprintf(doc, _("Hitpoints: %d\n"),
+                putype->hp);
+        helptext_unit(buf, sizeof(buf), NULL, "", putype);
+        fprintf(doc, "%s\n\n", buf);
+      } unit_type_iterate_end;
+      break;
+
     case MANUAL_COUNT:
       break;
 
@@ -604,6 +645,8 @@ int main(int argc, char **argv)
     inx++;
   }
 
+  init_our_capability();
+
   /* must be before con_log_init() */
   init_connections();
   con_log_init(srvarg.log_filename, srvarg.loglevel,
