@@ -21,10 +21,14 @@ struct fcmp_params
 };
 
 #if IS_DEVEL_VERSION && ! IS_FREEZE_VERSION
+#ifndef MODPACK_LIST_URL
 #define MODPACK_LIST_URL  "http://www.cazfi.net/freeciv/modinst/" DATASUBDIR "/modpack.list"
+#endif
 #define DEFAULT_URL_START "http://www.cazfi.net/freeciv/modinst/" DATASUBDIR "/"
 #else  /* IS_DEVEL_VERSION */
+#ifndef MODPACK_LIST_URL
 #define MODPACK_LIST_URL  "http://modpack.freeciv.org/" DATASUBDIR "/modpack.list"
+#endif
 #define DEFAULT_URL_START "http://modpack.freeciv.org/" DATASUBDIR "/"
 #endif /* IS_DEVEL_VERSION */
 
@@ -41,6 +45,8 @@ struct fcmp_params
 #define SPECENUM_VALUE3NAME N_("Scenario")
 #define SPECENUM_VALUE4 MPT_SOUNDSET
 #define SPECENUM_VALUE4NAME N_("Soundset")
+#define SPECENUM_VALUE5 MPT_MUSICSET
+#define SPECENUM_VALUE5NAME N_("Musicset")
 #include "specenum_gen.h"
 
 void fcmp_init(void);
