@@ -1,4 +1,4 @@
-/**********************************************************************
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
    GNU General Public License for more details.
 ***********************************************************************/
 
-/**********************************************************************
+/***********************************************************************
   An IO layer to support transparent compression/uncompression.
   (Currently only "required" functionality is supported.)
 
@@ -27,27 +27,20 @@
 
   FIXME: when zlib support _not_ included, should sanity check whether
   the first few bytes are gzip marker and complain if so.
-**********************************************************************/
+***********************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include <fc_config.h>
 #endif
 
+#include "fc_prehdrs.h"
+
 #include <errno.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
 
-/* Must be before <windows.h> gets included from anywhere */
-#ifdef HAVE_WINSOCK
-#ifdef HAVE_WINSOCK2
-#include <winsock2.h>
-#else  /* HAVE_WINSOCK2 */
-#include <winsock.h>
-#endif /* HAVE_WINSOCK2 */
-#endif /* HAVE_WINSOCK */
-
-#ifdef HAVE_LIBZ
+#ifdef FREECIV_HAVE_LIBZ
 #include <zlib.h>
 #endif
 
@@ -67,7 +60,7 @@
 
 #include "ioz.h"
 
-#ifdef HAVE_LIBBZ2
+#ifdef FREECIV_HAVE_LIBBZ2
 struct bzip2_struct {
   BZFILE *file;
   FILE *plain;
@@ -75,9 +68,9 @@ struct bzip2_struct {
   int firstbyte;
   bool eof;
 };
-#endif /* HAVE_LIBBZ2 */
+#endif /* FREECIV_HAVE_LIBBZ2 */
 
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
 
 #define PLAIN_FILE_BUF_SIZE (8096*1024)    /* 8096kb */
 #define XZ_DECODER_TEST_SIZE (4*1024)      /* 4kb */
@@ -118,20 +111,29 @@ struct xz_struct {
 static bool xz_outbuffer_to_file(fz_FILE *fp, lzma_action action);
 static void xz_action(fz_FILE *fp, lzma_action action);
 
-#endif /* HAVE_LIBLZMA */
+#endif /* FREECIV_HAVE_LIBLZMA */
+
+struct mem_fzFILE {
+  bool control;
+  char *buffer;
+  int pos;
+  int size;
+};
 
 struct fz_FILE_s {
   enum fz_method method;
   char mode;
+  bool memory;
   union {
+    struct mem_fzFILE mem;
     FILE *plain;		/* FZ_PLAIN */
-#ifdef HAVE_LIBZ
+#ifdef FREECIV_HAVE_LIBZ
     gzFile zlib;                 /* FZ_ZLIB */
 #endif
-#ifdef HAVE_LIBBZ2
+#ifdef FREECIV_HAVE_LIBBZ2
     struct bzip2_struct bz2;
 #endif
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
     struct xz_struct xz;
 #endif
   } u;
@@ -144,13 +146,13 @@ static inline bool fz_method_is_valid(enum fz_method method)
 {
   switch (method) {
   case FZ_PLAIN:
-#ifdef HAVE_LIBZ
+#ifdef FREECIV_HAVE_LIBZ
   case FZ_ZLIB:
 #endif
-#ifdef HAVE_LIBBZ2
+#ifdef FREECIV_HAVE_LIBBZ2
   case FZ_BZIP2:
 #endif
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
   case FZ_XZ:
 #endif
     return TRUE;
@@ -164,6 +166,26 @@ static inline bool fz_method_is_valid(enum fz_method method)
                       "Unsupported compress method %d, reverting to plain.",\
                       method), FZ_PLAIN))
 
+
+/***************************************************************
+  Open memory buffer for reading as fz_FILE.
+  If control is TRUE, caller gives up control of the buffer
+  so ioz will free it when fz_FILE closed.
+***************************************************************/
+fz_FILE *fz_from_memory(char *buffer, int size, bool control)
+{
+  fz_FILE *fp;
+
+  fp = (fz_FILE *)fc_malloc(sizeof(*fp));
+  fp->memory = TRUE;
+  fp->u.mem.control = control;
+  fp->u.mem.buffer = buffer;
+  fp->u.mem.pos = 0;
+  fp->u.mem.size = size;
+
+  return fp;
+}
+
 /***************************************************************
   Open file for reading/writing, like fopen.
   Parameters compress_method and compress_level only apply
@@ -184,23 +206,24 @@ fz_FILE *fz_from_file(const char *filename, const char *in_mode,
   }
 
   fp = (fz_FILE *)fc_malloc(sizeof(*fp));
+  fp->memory = FALSE;
   sz_strlcpy(mode, in_mode);
 
   if (mode[0] == 'w') {
     /* Writing: */
     fp->mode = 'w';
   } else {
-#if defined(HAVE_LIBBZ2) || defined(HAVE_LIBLZMA)
+#if defined(FREECIV_HAVE_LIBBZ2) || defined(FREECIV_HAVE_LIBLZMA)
     char test_mode[4];
 
     sz_strlcpy(test_mode, mode);
     sz_strlcat(test_mode, "b");
-#endif /* HAVE_LIBBZ2 || HAVE_LIBLZMA */
+#endif /* FREECIV_HAVE_LIBBZ2 || FREECIV_HAVE_LIBLZMA */
 
     /* Reading: ignore specified method and try each: */
     fp->mode = 'r';
 
-#ifdef HAVE_LIBBZ2
+#ifdef FREECIV_HAVE_LIBBZ2
     /* Try to open as bzip2 file
        This is simplest test, so do it first. */
     method = FZ_BZIP2;
@@ -261,9 +284,9 @@ fz_FILE *fz_from_file(const char *filename, const char *in_mode,
       BZ2_bzReadClose(&tmp_err, fp->u.bz2.file);
       fclose(fp->u.bz2.plain);
     }
-#endif /* HAVE_LIBBZ2 */
+#endif /* FREECIV_HAVE_LIBBZ2 */
 
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
     /* Try to open as xz file */
     fp->u.xz.memlimit = XZ_DECODER_MEMLIMIT;
     memset(&fp->u.xz.stream, 0, sizeof(lzma_stream));
@@ -316,9 +339,9 @@ fz_FILE *fz_from_file(const char *filename, const char *in_mode,
       free(fp);
       return NULL;
     }
-#endif /* HAVE_LIBLZMA */
+#endif /* FREECIV_HAVE_LIBLZMA */
 
-#ifdef HAVE_LIBZ
+#ifdef FREECIV_HAVE_LIBZ
     method = FZ_ZLIB;
 #else
     method = FZ_PLAIN;
@@ -328,7 +351,7 @@ fz_FILE *fz_from_file(const char *filename, const char *in_mode,
   fp->method = fz_method_validate(method);
 
   switch (fp->method) {
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
   case FZ_XZ:
     {
       lzma_ret ret;
@@ -356,8 +379,8 @@ fz_FILE *fz_from_file(const char *filename, const char *in_mode,
       }
     }
     return fp;
-#endif /* HAVE_LIBLZMA */
-#ifdef HAVE_LIBBZ2
+#endif /* FREECIV_HAVE_LIBLZMA */
+#ifdef FREECIV_HAVE_LIBBZ2
   case FZ_BZIP2:
     /*  bz2 files are binary files, so we should add "b" to mode! */
     sz_strlcat(mode,"b");
@@ -385,8 +408,8 @@ fz_FILE *fz_from_file(const char *filename, const char *in_mode,
       fp = NULL;
     }
     return fp;
-#endif /* HAVE_LIBBZ2 */
-#ifdef HAVE_LIBZ
+#endif /* FREECIV_HAVE_LIBBZ2 */
+#ifdef FREECIV_HAVE_LIBZ
   case FZ_ZLIB:
     /*  gz files are binary files, so we should add "b" to mode! */
     sz_strlcat(mode,"b");
@@ -399,7 +422,7 @@ fz_FILE *fz_from_file(const char *filename, const char *in_mode,
       fp = NULL;
     }
     return fp;
-#endif /* HAVE_LIBZ */
+#endif /* FREECIV_HAVE_LIBZ */
   case FZ_PLAIN:
     fp->u.plain = fc_fopen(filename, mode);
     if (!fp->u.plain) {
@@ -429,6 +452,7 @@ fz_FILE *fz_from_stream(FILE *stream)
 
   fp = fc_malloc(sizeof(*fp));
   fp->method = FZ_PLAIN;
+  fp->memory = FALSE;
   fp->u.plain = stream;
   return fp;
 }
@@ -447,8 +471,17 @@ int fz_fclose(fz_FILE *fp)
 
   fc_assert_ret_val(NULL != fp, 1);
 
+  if (fp->memory) {
+    if (fp->u.mem.control) {
+      FC_FREE(fp->u.mem.buffer);
+    }
+    FC_FREE(fp);
+
+    return 0;
+  }
+
   switch (fz_method_validate(fp->method)) {
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
   case FZ_XZ:
     if (fp->mode == 'w' && !xz_outbuffer_to_file(fp, LZMA_FINISH)) {
       error = 1;
@@ -459,8 +492,8 @@ int fz_fclose(fz_FILE *fp)
     fclose(fp->u.xz.plain);
     free(fp);
     return error;
-#endif /* HAVE_LIBLZMA */
-#ifdef HAVE_LIBBZ2
+#endif /* FREECIV_HAVE_LIBLZMA */
+#ifdef FREECIV_HAVE_LIBBZ2
   case FZ_BZIP2:
     if ('w' == fp->mode) {
       BZ2_bzWriteClose(&fp->u.bz2.error, fp->u.bz2.file, 0, NULL, NULL);
@@ -471,13 +504,13 @@ int fz_fclose(fz_FILE *fp)
     fclose(fp->u.bz2.plain);
     free(fp);
     return BZ_OK == error ? 0 : 1;
-#endif /* HAVE_LIBBZ2 */
-#ifdef HAVE_LIBZ
+#endif /* FREECIV_HAVE_LIBBZ2 */
+#ifdef FREECIV_HAVE_LIBZ
   case FZ_ZLIB:
     error = gzclose(fp->u.zlib);
     free(fp);
     return 0 > error ? error : 0; /* Only negative Z values are errors. */
-#endif /* HAVE_LIBZ */
+#endif /* FREECIV_HAVE_LIBZ */
   case FZ_PLAIN:
     error = fclose(fp->u.plain);
     free(fp);
@@ -500,8 +533,44 @@ char *fz_fgets(char *buffer, int size, fz_FILE *fp)
 {
   fc_assert_ret_val(NULL != fp, NULL);
 
+  if (fp->memory) {
+    int i, j;
+
+    for (i = fp->u.mem.pos, j = 0;
+         i < fp->u.mem.size && j < size - 1 /* Space for '\0' */
+           && fp->u.mem.buffer[i] != '\n'
+           && (fp->u.mem.buffer[i] != '\r'
+               || fp->u.mem.size == i + 1
+               || fp->u.mem.buffer[i + 1] != '\n'); i++) {
+      buffer[j++] = fp->u.mem.buffer[i];
+    }
+
+    if (j < size - 2) {
+      /* Space for both newline and terminating '\0' */
+      if (i + 1 < fp->u.mem.size 
+          && fp->u.mem.buffer[i] == '\r'
+          && fp->u.mem.buffer[i + 1] == '\n') {
+        i += 2;
+        buffer[j++] = '\n';
+      } else if (i < fp->u.mem.size
+                 && fp->u.mem.buffer[i] == '\n') {
+        i++;
+        buffer[j++] = '\n';
+      }
+    }
+
+    if (j == 0) {
+      return NULL;
+    }
+
+    fp->u.mem.pos = i;
+    buffer[j] = '\0';
+
+    return buffer;
+  }
+
   switch (fz_method_validate(fp->method)) {
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
   case FZ_XZ:
     {
       int i, j;
@@ -588,8 +657,8 @@ char *fz_fgets(char *buffer, int size, fz_FILE *fp)
       return buffer;
     }
     break;
-#endif /* HAVE_LIBLZMA */
-#ifdef HAVE_LIBBZ2
+#endif /* FREECIV_HAVE_LIBLZMA */
+#ifdef FREECIV_HAVE_LIBBZ2
   case FZ_BZIP2:
     {
       char *retval = NULL;
@@ -630,11 +699,11 @@ char *fz_fgets(char *buffer, int size, fz_FILE *fp)
       buffer[i] = '\0';
       return retval;
     }
-#endif /* HAVE_LIBBZ2 */
-#ifdef HAVE_LIBZ
+#endif /* FREECIV_HAVE_LIBBZ2 */
+#ifdef FREECIV_HAVE_LIBZ
   case FZ_ZLIB:
     return gzgets(fp->u.zlib, buffer, size);
-#endif /* HAVE_LIBZ */
+#endif /* FREECIV_HAVE_LIBZ */
   case FZ_PLAIN:
     return fgets(buffer, size, fp->u.plain);
   }
@@ -645,7 +714,7 @@ char *fz_fgets(char *buffer, int size, fz_FILE *fp)
   return NULL;
 }
 
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
 
 /***************************************************************
   Helper function to do given compression action and writing
@@ -700,7 +769,7 @@ static void xz_action(fz_FILE *fp, lzma_action action)
 
   fp->u.xz.error = lzma_code(&fp->u.xz.stream, action);
 }
-#endif /* HAVE_LIBLZMA */
+#endif /* FREECIV_HAVE_LIBLZMA */
 
 /***************************************************************
   Print formated, like fprintf.
@@ -719,9 +788,10 @@ int fz_fprintf(fz_FILE *fp, const char *format, ...)
   va_list ap;
 
   fc_assert_ret_val(NULL != fp, 0);
+  fc_assert_ret_val(!fp->memory, 0);
 
   switch (fz_method_validate(fp->method)) {
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
   case FZ_XZ:
     {
       va_start(ap, format);
@@ -743,8 +813,8 @@ int fz_fprintf(fz_FILE *fp, const char *format, ...)
       }
     }
     break;
-#endif /* HAVE_LIBLZMA */
-#ifdef HAVE_LIBBZ2
+#endif /* FREECIV_HAVE_LIBLZMA */
+#ifdef FREECIV_HAVE_LIBBZ2
   case FZ_BZIP2:
     {
       char buffer[65536];
@@ -763,8 +833,8 @@ int fz_fprintf(fz_FILE *fp, const char *format, ...)
         return strlen(buffer);
       }
     }
-#endif /* HAVE_LIBBZ2 */
-#ifdef HAVE_LIBZ
+#endif /* FREECIV_HAVE_LIBBZ2 */
+#ifdef FREECIV_HAVE_LIBZ
   case FZ_ZLIB:
     {
       char buffer[65536];
@@ -778,7 +848,7 @@ int fz_fprintf(fz_FILE *fp, const char *format, ...)
       }
       return gzwrite(fp->u.zlib, buffer, (unsigned int)strlen(buffer));
     }
-#endif /* HAVE_LIBZ */
+#endif /* FREECIV_HAVE_LIBZ */
   case FZ_PLAIN:
     va_start(ap, format);
     num = vfprintf(fp->u.plain, format, ap);
@@ -800,8 +870,12 @@ int fz_ferror(fz_FILE *fp)
 {
   fc_assert_ret_val(NULL != fp, 0);
 
+  if (fp->memory) {
+    return 0;
+  }
+
   switch (fz_method_validate(fp->method)) {
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
   case FZ_XZ:
     if (fp->u.xz.error != LZMA_OK
         && fp->u.xz.error != LZMA_STREAM_END) {
@@ -810,13 +884,13 @@ int fz_ferror(fz_FILE *fp)
       return 0;
     }
     break;
-#endif /* HAVE_LZMA */
-#ifdef HAVE_LIBBZ2
+#endif /* FREECIV_HAVE_LZMA */
+#ifdef FREECIV_HAVE_LIBBZ2
   case FZ_BZIP2:
     return (BZ_OK != fp->u.bz2.error
             && BZ_STREAM_END != fp->u.bz2.error);
-#endif /* HAVE_LIBBZ2 */
-#ifdef HAVE_LIBZ
+#endif /* FREECIV_HAVE_LIBBZ2 */
+#ifdef FREECIV_HAVE_LIBZ
   case FZ_ZLIB:
     {
       int error;
@@ -824,7 +898,7 @@ int fz_ferror(fz_FILE *fp)
       (void) gzerror(fp->u.zlib, &error); /* Ignore string result here. */
       return 0 > error ? error : 0; /* Only negative Z values are errors. */
     }
-#endif /* HAVE_LIBZ */
+#endif /* FREECIV_HAVE_LIBZ */
   case FZ_PLAIN:
     return ferror(fp->u.plain);
     break;
@@ -847,9 +921,10 @@ int fz_ferror(fz_FILE *fp)
 const char *fz_strerror(fz_FILE *fp)
 {
   fc_assert_ret_val(NULL != fp, NULL);
+  fc_assert_ret_val(!fp->memory, NULL);
 
   switch (fz_method_validate(fp->method)) {
-#ifdef HAVE_LIBLZMA
+#ifdef FREECIV_HAVE_LIBLZMA
   case FZ_XZ:
     {
       static char xzerror[50];
@@ -900,8 +975,8 @@ const char *fz_strerror(fz_FILE *fp)
       return xzerror;
     }
     break;
-#endif /* HAVE_LIBLZMA */
-#ifdef HAVE_LIBBZ2
+#endif /* FREECIV_HAVE_LIBLZMA */
+#ifdef FREECIV_HAVE_LIBBZ2
   case FZ_BZIP2:
     {
       static char bzip2error[50];
@@ -967,8 +1042,8 @@ const char *fz_strerror(fz_FILE *fp)
       }
       return bzip2error;
     }
-#endif /* HAVE_LIBBZ2 */
-#ifdef HAVE_LIBZ
+#endif /* FREECIV_HAVE_LIBBZ2 */
+#ifdef FREECIV_HAVE_LIBZ
   case FZ_ZLIB:
     {
       int errnum;
@@ -976,7 +1051,7 @@ const char *fz_strerror(fz_FILE *fp)
 
       return Z_ERRNO == errnum ? fc_strerror(fc_get_errno()) : estr;
     }
-#endif /* HAVE_LIBZ */
+#endif /* FREECIV_HAVE_LIBZ */
   case FZ_PLAIN:
     return fc_strerror(fc_get_errno());
   }
