@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,57 +18,38 @@
 extern "C" {
 #endif /* __cplusplus */
 
-/********************************************************************** 
+#include <freeciv_config.h>
+
+/***********************************************************************
   Common network interface.
 ***********************************************************************/
 
-#ifdef HAVE_NETINET_IN_H
+#ifdef FREECIV_HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
-#ifdef HAVE_SYS_SELECT_H
+#ifdef FREECIV_HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
-#ifdef HAVE_SYS_SOCKET_H
+#ifdef FREECIV_HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
-#ifdef HAVE_SYS_TIME_H
+#ifdef FREECIV_HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
-#ifdef HAVE_SYS_TYPES_H
+#ifdef FREECIV_HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
-#ifdef HAVE_UNISTD_H
+#ifdef FREECIV_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#ifdef HAVE_WINSOCK
-#ifdef HAVE_WINSOCK2
-#include <winsock2.h>
-#else  /* HAVE_WINSOCK2 */
-#include <winsock.h>
-#endif /* HAVE_WINSOCK2 */
-#endif /* HAVE_WINSOCK */
+#ifdef FREECIV_HAVE_WS2TCPIP_H
+#include <ws2tcpip.h>
+#endif
 
 /* utility */
 #include "ioz.h"
-#include "support.h"            /* bool type */
-
-/* map symbolic Winsock error names to symbolic errno names */
-#ifdef HAVE_WINSOCK
-#undef EINTR
-#undef EINPROGRESS
-#undef EWOULDBLOCK
-#undef ECONNRESET
-#undef ECONNREFUSED
-#undef EADDRNOTAVAIL
-#undef ETIMEDOUT
-#define EINTR         WSAEINTR
-#define EINPROGRESS   WSAEWOULDBLOCK
-#define EWOULDBLOCK   WSAEWOULDBLOCK
-#define ECONNRESET    WSAECONNRESET
-#define ECONNREFUSED  WSAECONNREFUSED
-#define EADDRNOTAVAIL WSAEADDRNOTAVAIL
-#define ETIMEDOUT     WSAETIMEDOUT
-#endif /* HAVE_WINSOCK */
+#include "net_types.h"
+#include "support.h"   /* bool type */
 
 #ifdef FD_ZERO
 #define FC_FD_ZERO FD_ZERO
@@ -82,16 +63,16 @@ extern "C" {
 #define FC_IPV6_ADD_MEMBERSHIP IPV6_JOIN_GROUP
 #endif
 
-#ifndef HAVE_SOCKLEN_T
+#ifndef FREECIV_HAVE_SOCKLEN_T
 typedef int socklen_t;
-#endif
+#endif  /* FREECIV_HAVE_SOCKLEN_T */
 
 union fc_sockaddr {
   struct sockaddr saddr;
   struct sockaddr_in saddr_in4;
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   struct sockaddr_in6 saddr_in6;
-#endif
+#endif /* FREECIV_IPV6_SUPPORT */
 };
 
 /* get 'struct sockaddr_list' and related functions: */
@@ -103,26 +84,11 @@ union fc_sockaddr {
     TYPED_LIST_ITERATE(union fc_sockaddr, sockaddrlist, paddr)
 #define fc_sockaddr_list_iterate_end  LIST_ITERATE_END
 
-/* Which protocol will be used for LAN announcements */
-enum announce_type {
-  ANNOUNCE_NONE,
-  ANNOUNCE_IPV4,
-  ANNOUNCE_IPV6
-};
-
-#define ANNOUNCE_DEFAULT ANNOUNCE_IPV4
-
-enum fc_addr_family {
-  FC_ADDR_IPV4,
-  FC_ADDR_IPV6,
-  FC_ADDR_ANY
-};
-
-#ifdef WIN32_NATIVE
+#ifdef FREECIV_MSWINDOWS
 typedef TIMEVAL fc_timeval;
-#else  /* WIN32_NATIVE */
+#else  /* FREECIV_MSWINDOWS */
 typedef struct timeval fc_timeval;
-#endif /* WIN32_NATIVE */
+#endif /* FREECIV_MSWINDOWS */
 
 int fc_connect(int sockfd, const struct sockaddr *serv_addr, socklen_t addrlen);
 int fc_select(int n, fd_set *readfds, fd_set *writefds, fd_set *exceptfds,
@@ -130,8 +96,6 @@ int fc_select(int n, fd_set *readfds, fd_set *writefds, fd_set *exceptfds,
 int fc_readsocket(int sock, void *buf, size_t size);
 int fc_writesocket(int sock, const void *buf, size_t size);
 void fc_closesocket(int sock);
-void fc_init_network(void);
-void fc_shutdown_network(void);
 
 void fc_nonblock(int sockfd);
 struct fc_sockaddr_list *net_lookup_service(const char *name, int port,
