@@ -2,4 +2,4 @@
 
 # ./create-freeciv-gtk2-nsi.sh <Freeciv files directory> <version>
 
-./create-freeciv-gtk-nsi.sh $1 $2 "gtk2" "GTK+2"
+./create-freeciv-gtk-qt-nsi.sh $1 $2 "gtk2" "GTK+2"
