@@ -2,4 +2,4 @@
 
 # ./create-freeciv-gtk3-nsi.sh <Freeciv files directory> <version>
 
-./create-freeciv-gtk-nsi.sh $1 $2 "gtk3" "GTK+3"
+./create-freeciv-gtk-qt-nsi.sh $1 $2 "gtk3" "GTK+3"
